@@ -14,10 +14,8 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-import networkx as nx
-from pm4py.util import exec_utils
+from pm4py.util import exec_utils, nx_utils
 from enum import Enum
-from pm4py.objects.petri_net.obj import PetriNet
 from pm4py.objects.petri_net.utils import petri_utils
 import copy
 import numpy as np
@@ -49,6 +47,9 @@ from pm4py.algo.analysis.woflan.graphs.restricted_coverability_graph.restricted_
 # reachability Graph Creation
 from pm4py.algo.analysis.woflan.graphs.reachability_graph.reachability_graph import apply as reachability_graph
 
+from typing import Optional, Dict, Any, Union
+from pm4py.objects.petri_net.obj import PetriNet, Marking
+
 
 class Parameters(Enum):
     RETURN_ASAP_WHEN_NOT_SOUND = "return_asap_when_not_sound"
@@ -73,6 +74,7 @@ class Outputs(Enum):
     R_G = "r_g"
     LOCKING_SCENARIOS = "locking_scenarios"
     RESTRICTED_COVERABILITY_TREE = "restricted_coverability_tree"
+    DIAGNOSTIC_MESSAGES = "diagnostic_messages"
 
 
 class woflan:
@@ -97,6 +99,7 @@ class woflan:
         self.r_g = None
         self.locking_scenarios = None
         self.restricted_coverability_tree = None
+        self.diagnostic_messages = list()
 
     def set_s_c_net(self, s_c_net):
         self.s_c_net = s_c_net
@@ -241,6 +244,7 @@ class woflan:
             ret[Outputs.LOCKING_SCENARIOS] = self.locking_scenarios
         if self.restricted_coverability_tree is not None:
             ret[Outputs.RESTRICTED_COVERABILITY_TREE] = self.restricted_coverability_tree
+        ret[Outputs.DIAGNOSTIC_MESSAGES] = self.diagnostic_messages
         return ret
 
 
@@ -270,24 +274,24 @@ def short_circuit_petri_net(net, print_diagnostics=False):
         # add arcs in short-circuited net
         petri_utils.add_arc_from_to(sink, t_1, s_c_net)
         petri_utils.add_arc_from_to(t_1, source, s_c_net)
-        return s_c_net
+        return s_c_net, []
     else:
         if sink is None:
             if print_diagnostics:
                 print("There is no sink place.")
-            return None
+            return None, ["There is no sink place."]
         elif source is None:
             if print_diagnostics:
                 print("There is no source place.")
-            return None
+            return None, ["There is no source place."]
         elif no_source_places > 1:
             if print_diagnostics:
                 print("There is more than one source place.")
-            return None
+            return None, ["There is more than one source place."]
         elif no_sink_places > 1:
             if print_diagnostics:
                 print("There is more than one sink place.")
-            return None
+            return None, ["There is more than one sink place."]
 
 
 def step_1(woflan_object, return_asap_when_unsound=False):
@@ -312,14 +316,17 @@ def step_1(woflan_object, return_asap_when_unsound=False):
 
     if isinstance(woflan_object.get_net(), PetriNet):
         if len(woflan_object.get_initial_marking()) != 1 or len(woflan_object.get_final_marking()) != 1:
+            woflan_object.diagnostic_messages.append('There is more than one initial or final marking.')
             if woflan_object.print_diagnostics:
                 print('There is more than one initial or final marking.')
             return False
         if check_if_marking_in_net(woflan_object.get_initial_marking(), woflan_object.get_net()):
             if check_if_marking_in_net(woflan_object.get_final_marking(), woflan_object.get_net()):
+                woflan_object.diagnostic_messages.append('Input is ok.')
                 if woflan_object.print_diagnostics:
-                    print("Input is ok.")
+                    print('Input is ok.')
                 return step_2(woflan_object, return_asap_when_unsound=return_asap_when_unsound)
+    woflan_object.diagnostic_messages.append('The Petri Net is not PM4Py Petri Net represenatation.')
     if woflan_object.print_diagnostics:
         print('The Petri Net is not PM4Py Petri Net represenatation.')
     return False
@@ -340,7 +347,7 @@ def step_2(woflan_object, return_asap_when_unsound=False):
         :param still_need_to_discover: set of places and transition that are not fully added to graph
         :return:
         """
-        G = nx.DiGraph()
+        G = nx_utils.DiGraph()
         while len(still_need_to_discover) > 0:
             element = still_need_to_discover.pop()
             G.add_node(element.name)
@@ -352,19 +359,23 @@ def step_2(woflan_object, return_asap_when_unsound=False):
                 G.add_edge(element.name, out_arc.target.name)
         return G
 
-    woflan_object.set_s_c_net(short_circuit_petri_net(woflan_object.get_net(),
-                                                      print_diagnostics=woflan_object.print_diagnostics))
+    s_c_net, diagnostic_messages = short_circuit_petri_net(woflan_object.get_net(),
+                                                           print_diagnostics=woflan_object.print_diagnostics)
+    woflan_object.set_s_c_net(s_c_net)
+    woflan_object.diagnostic_messages += diagnostic_messages
     if woflan_object.get_s_c_net() == None:
         return False
     to_discover = woflan_object.get_s_c_net().places | woflan_object.get_s_c_net().transitions
     graph = transform_petri_net_into_regular_graph(to_discover)
-    if not nx.algorithms.components.is_strongly_connected(graph):
+    if not nx_utils.is_strongly_connected(graph):
+        woflan_object.diagnostic_messages.append('Petri Net is a not a worflow net.')
         if woflan_object.print_diagnostics:
             print('Petri Net is a not a worflow net.')
         return False
     else:
+        woflan_object.diagnostic_messages.append('Petri Net is a workflow net.')
         if woflan_object.print_diagnostics:
-            print("Petri Net is a workflow net.")
+            print('Petri Net is a workflow net.')
         return step_3(woflan_object, return_asap_when_unsound=return_asap_when_unsound)
 
 
@@ -377,10 +388,13 @@ def step_3(woflan_object, return_asap_when_unsound=False):
         compute_uncovered_places_in_component(woflan_object.get_s_components(), woflan_object.get_s_c_net()))
     if len(woflan_object.get_uncovered_places_s_component()) == 0:
         woflan_object.set_left(True)
+        woflan_object.diagnostic_messages.append('Every place is covered by s-components.')
         if woflan_object.print_diagnostics:
             print('Every place is covered by s-components.')
         return step_10(woflan_object, return_asap_when_unsound=return_asap_when_unsound)
     else:
+        woflan_object.diagnostic_messages.append('The following places are not covered by an s-component: {}.'.format(
+                woflan_object.get_uncovered_places_s_component()))
         if woflan_object.print_diagnostics:
             print('The following places are not covered by an s-component: {}.'.format(
                 woflan_object.get_uncovered_places_s_component()))
@@ -392,13 +406,16 @@ def step_3(woflan_object, return_asap_when_unsound=False):
 def step_4(woflan_object, return_asap_when_unsound=False):
     woflan_object.set_not_well_handled_pairs(compute_not_well_handled_pairs(woflan_object.get_s_c_net()))
     if len(woflan_object.get_not_well_handled_pairs()) == 0:
+        woflan_object.diagnostic_messages.append('Petri Net is unsound.')
         if woflan_object.print_diagnostics:
-            print('Petri Net is unsound')
+            print('Petri Net is unsound.')
         woflan_object.set_left(False)
         if return_asap_when_unsound:
             return False
         return step_5(woflan_object, return_asap_when_unsound=return_asap_when_unsound)
     else:
+        woflan_object.diagnostic_messages.append('Not well-handled pairs are: {}.'.format(
+            woflan_object.get_not_well_handled_pairs()))
         if woflan_object.print_diagnostics:
             print('Not well-handled pairs are: {}.'.format(woflan_object.get_not_well_handled_pairs()))
         woflan_object.set_left(True)
@@ -410,10 +427,13 @@ def step_5(woflan_object, return_asap_when_unsound=False):
         compute_uncovered_place_in_invariants(woflan_object.get_uniform_place_invariants(),
                                               woflan_object.get_s_c_net()))
     if len(woflan_object.get_uncovered_places_uniform()) == 0:
+        woflan_object.diagnostic_messages.append('There are no uncovered places in uniform invariants.')
         if woflan_object.print_diagnostics:
             print('There are no uncovered places in uniform invariants.')
         return step_10(woflan_object, return_asap_when_unsound=return_asap_when_unsound)
     else:
+        woflan_object.diagnostic_messages.append('The following places are uncovered in uniform invariants: {}'.format(
+            woflan_object.get_uncovered_places_uniform()))
         if woflan_object.print_diagnostics:
             print('The following places are uncovered in uniform invariants: {}'.format(
                 woflan_object.get_uncovered_places_uniform()))
@@ -426,10 +446,13 @@ def step_6(woflan_object, return_asap_when_unsound=False):
         compute_uncovered_place_in_invariants(woflan_object.get_weighted_place_invariants(),
                                               woflan_object.get_s_c_net()))
     if len(woflan_object.get_uncovered_places_weighted()) == 0:
+        woflan_object.diagnostic_messages.append('There are no uncovered places in weighted invariants.')
         if woflan_object.print_diagnostics:
             print('There are no uncovered places in weighted invariants.')
         return step_10(woflan_object, return_asap_when_unsound=return_asap_when_unsound)
     else:
+        woflan_object.diagnostic_messages.append('The following places are uncovered in weighted invariants: {}'.format(
+            woflan_object.get_uncovered_places_weighted()))
         if woflan_object.print_diagnostics:
             print('The following places are uncovered in weighted invariants: {}'.format(
                 woflan_object.get_uncovered_places_weighted()))
@@ -440,13 +463,16 @@ def step_7(woflan_object, return_asap_when_unsound=False):
     woflan_object.set_mcg(minimal_coverability_graph(woflan_object.get_s_c_net(), woflan_object.get_initial_marking(),
                                                      woflan_object.get_net()))
     if len(check_for_improper_conditions(woflan_object.get_mcg())) == 0:
+        woflan_object.diagnostic_messages.append('No improper coditions.')
         if woflan_object.print_diagnostics:
-            print('No improper coditions.')
+            print('No improper conditions.')
         if woflan_object.get_left == True:
             return step_8(woflan_object, return_asap_when_unsound=return_asap_when_unsound)
         else:
             return step_10(woflan_object, return_asap_when_unsound=return_asap_when_unsound)
     else:
+        woflan_object.diagnostic_messages.append('Improper WPD. The following are the improper conditions: {}.'.format(
+            check_for_improper_conditions(woflan_object.get_mcg())))
         if woflan_object.print_diagnostics:
             print('Improper WPD. The following are the improper conditions: {}.'.format(
                 check_for_improper_conditions(woflan_object.get_mcg())))
@@ -463,6 +489,8 @@ def step_8(woflan_object, return_asap_when_unsound=False):
 
 
 def step_9(woflan_object, return_asap_when_unsound=False):
+    woflan_object.diagnostic_messages.append('The following sequences are unbounded: {}'.format(
+        compute_unbounded_sequences(woflan_object)))
     if woflan_object.print_diagnostics:
         print('The following sequences are unbounded: {}'.format(compute_unbounded_sequences(woflan_object)))
     return False
@@ -475,6 +503,7 @@ def step_10(woflan_object, return_asap_when_unsound=False):
                                        woflan_object.get_net()))
     woflan_object.set_dead_tasks(check_for_dead_tasks(woflan_object.get_s_c_net(), woflan_object.get_mcg()))
     if len(woflan_object.get_dead_tasks()) == 0:
+        woflan_object.diagnostic_messages.append('There are no dead tasks.')
         if woflan_object.print_diagnostics:
             print('There are no dead tasks.')
         if woflan_object.get_left() == True:
@@ -484,6 +513,8 @@ def step_10(woflan_object, return_asap_when_unsound=False):
                 return False
             return step_12(woflan_object, return_asap_when_unsound=return_asap_when_unsound)
     else:
+        woflan_object.diagnostic_messages.append('The following tasks are dead: {}'.format(
+            woflan_object.get_dead_tasks()))
         if woflan_object.print_diagnostics:
             print('The following tasks are dead: {}'.format(woflan_object.get_dead_tasks()))
         return False
@@ -492,7 +523,8 @@ def step_10(woflan_object, return_asap_when_unsound=False):
 def step_11(woflan_object, return_asap_when_unsound=False):
     woflan_object.set_r_g_s_c(
         reachability_graph(woflan_object.get_s_c_net(), woflan_object.get_initial_marking(), woflan_object.get_net()))
-    if nx.is_strongly_connected(woflan_object.get_r_g_s_c()):
+    if nx_utils.is_strongly_connected(woflan_object.get_r_g_s_c()):
+        woflan_object.diagnostic_messages.append('All tasks are live.')
         if woflan_object.print_diagnostics:
             print('All tasks are live.')
         return True
@@ -505,6 +537,7 @@ def step_11(woflan_object, return_asap_when_unsound=False):
 def step_12(woflan_object, return_asap_when_unsound=False):
     woflan_object.set_r_g_s_c(
         reachability_graph(woflan_object.get_s_c_net(), woflan_object.get_initial_marking(), woflan_object.get_net()))
+    woflan_object.diagnostic_messages.append('There are non-live tasks.')
     if woflan_object.print_diagnostics:
         print('There are non-live tasks.')
     if return_asap_when_unsound:
@@ -514,12 +547,14 @@ def step_12(woflan_object, return_asap_when_unsound=False):
 
 def step_13(woflan_object, return_asap_when_unsound=False):
     woflan_object.set_locking_scenarios(compute_non_live_sequences(woflan_object))
+    woflan_object.diagnostic_messages.append('The following sequences lead to deadlocks: {}.'.format(
+        woflan_object.get_locking_scenarios()))
     if woflan_object.print_diagnostics:
         print('The following sequences lead to deadlocks: {}.'.format(woflan_object.get_locking_scenarios()))
     return False
 
 
-def apply(net, i_m, f_m, parameters=None):
+def apply(net: PetriNet, i_m: Marking, f_m: Marking, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> Union[bool, Any]:
     """
     Apply the Woflan Soundness check. Trough this process, different steps are executed.
     :param net: Petri Net representation of PM4Py
@@ -562,10 +597,10 @@ def compute_non_live_sequences(woflan_object):
     # red nodes are those from which the final marking is not reachable
     red_nodes = []
     for node in woflan_object.get_r_g().nodes:
-        if not nx.has_path(woflan_object.get_r_g(), node, sucessfull_terminate_state):
+        if not nx_utils.has_path(woflan_object.get_r_g(), node, sucessfull_terminate_state):
             red_nodes.append(node)
     # Compute directed spanning tree
-    spanning_tree = nx.algorithms.tree.Edmonds(woflan_object.get_r_g()).find_optimum()
+    spanning_tree = nx_utils.Edmonds(woflan_object.get_r_g()).find_optimum()
     queue = set()
     paths = {}
     # root node
@@ -616,10 +651,10 @@ def compute_unbounded_sequences(woflan_object):
     for node in woflan_object.get_restricted_coverability_tree().nodes:
         add_to_green = True
         for marking in infinite_markings:
-            if nx.has_path(woflan_object.get_restricted_coverability_tree(), node, marking):
+            if nx_utils.has_path(woflan_object.get_restricted_coverability_tree(), node, marking):
                 add_to_green = False
         for marking in larger_markings:
-            if nx.has_path(woflan_object.get_restricted_coverability_tree(), node, marking):
+            if nx_utils.has_path(woflan_object.get_restricted_coverability_tree(), node, marking):
                 add_to_green = False
         if add_to_green:
             green_markings.append(node)
@@ -627,7 +662,7 @@ def compute_unbounded_sequences(woflan_object):
     for node in woflan_object.get_restricted_coverability_tree().nodes:
         add_to_red = True
         for node_green in green_markings:
-            if nx.has_path(woflan_object.get_restricted_coverability_tree(), node, node_green):
+            if nx_utils.has_path(woflan_object.get_restricted_coverability_tree(), node, node_green):
                 add_to_red = False
                 break
         if add_to_red:
