@@ -14,21 +14,7 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-
-'''
-    This file is part of PM4Py (More Info: https://pm4py.fit.fraunhofer.de).
-    PM4Py is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-    PM4Py is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-    You should have received a copy of the GNU General Public License
-    along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
-'''
-import pkgutil
+import importlib.util
 import warnings
 from enum import Enum
 from typing import Optional, Dict, Any, Union
@@ -92,7 +78,7 @@ def apply(log: EventLog, parameters: Optional[Dict[Union[str, Parameters], Any]]
 
     show_progress_bar = exec_utils.get_param_value(Parameters.SHOW_PROGRESS_BAR, parameters, True)
     progress = None
-    if pkgutil.find_loader("tqdm") and show_progress_bar:
+    if importlib.util.find_loader("tqdm") and show_progress_bar:
         from tqdm.auto import tqdm
         progress = tqdm(total=k, desc="prefix tree construction, completed prefixes of length :: ")
 
