@@ -14,7 +14,7 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-import pkgutil
+import importlib.util
 import sys
 import time
 from copy import copy
@@ -29,12 +29,13 @@ from pm4py.util import exec_utils
 from pm4py.util import variants_util
 
 from enum import Enum
-from pm4py.util import constants
+from pm4py.util import constants, nx_utils
 
-from typing import Optional, Dict, Any, Union, Tuple
+from typing import Optional, Dict, Any, Union
 from pm4py.objects.log.obj import EventLog
 from pm4py.objects.petri_net.obj import PetriNet, Marking
 from pm4py.util import typing
+from pm4py.objects.conversion.log import converter as log_converter
 
 
 class Parameters(Enum):
@@ -142,6 +143,8 @@ def apply(log: EventLog, net: PetriNet, im: Marking, fm: Marking, parameters: Op
     if parameters is None:
         parameters = {}
 
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
+
     best_worst_cost = get_best_worst_cost(net, im, fm, parameters=parameters)
     parameters[Parameters.BEST_WORST_COST] = best_worst_cost
 
@@ -172,7 +175,7 @@ def apply_log(log, list_nets, parameters=None):
     if parameters is None:
         parameters = {}
 
-    show_progress_bar = exec_utils.get_param_value(Parameters.SHOW_PROGRESS_BAR, parameters, True)
+    show_progress_bar = exec_utils.get_param_value(Parameters.SHOW_PROGRESS_BAR, parameters, constants.SHOW_PROGRESS_BAR)
     icache = exec_utils.get_param_value(Parameters.ICACHE, parameters, dict())
     mcache = exec_utils.get_param_value(Parameters.MCACHE, parameters, dict())
 
@@ -182,7 +185,7 @@ def apply_log(log, list_nets, parameters=None):
     variants_idxs = variants_module.get_variants_from_log_trace_idx(log, parameters=parameters)
 
     progress = None
-    if pkgutil.find_loader("tqdm") and show_progress_bar:
+    if importlib.util.find_spec("tqdm") and show_progress_bar:
         from tqdm.auto import tqdm
         progress = tqdm(total=len(variants_idxs),
                         desc="aligning log with decomposition/recomposition, completed variants :: ")
@@ -329,9 +332,7 @@ def recompose_alignment(cons_nets, cons_nets_result):
     alignment
         Recomposed alignment
     """
-    import networkx as nx
-
-    G0 = nx.DiGraph()
+    G0 = nx_utils.DiGraph()
     for i in range(len(cons_nets_result)):
         if cons_nets_result[i] is not None:
             G0.add_node(i)
