@@ -27,11 +27,11 @@ from pm4py.util import exec_utils
 from enum import Enum
 import sys
 from pm4py.util.constants import PARAMETER_CONSTANT_ACTIVITY_KEY, PARAMETER_CONSTANT_CASEID_KEY, CASE_CONCEPT_NAME
-import pkgutil
-from typing import Optional, Dict, Any, Union, Tuple
+import importlib.util
+from typing import Optional, Dict, Any, Union
 from pm4py.objects.log.obj import EventLog, EventStream, Trace
 from pm4py.objects.petri_net.obj import PetriNet, Marking
-from pm4py.util import typing
+from pm4py.util import typing, constants, pandas_utils
 import pandas as pd
 
 
@@ -62,20 +62,7 @@ class Parameters(Enum):
     FITNESS_ROUND_DIGITS = "fitness_round_digits"
     SYNCHRONOUS = "synchronous_dijkstra"
     EXPONENT="theta"
-
-
-
-DEFAULT_VARIANT = Variants.VERSION_DIJKSTRA_LESS_MEMORY
-if solver.DEFAULT_LP_SOLVER_VARIANT is not None:
-    DEFAULT_VARIANT = Variants.VERSION_STATE_EQUATION_A_STAR
-
-VERSION_STATE_EQUATION_A_STAR = Variants.VERSION_STATE_EQUATION_A_STAR
-VERSION_DIJKSTRA_NO_HEURISTICS = Variants.VERSION_DIJKSTRA_NO_HEURISTICS
-VERSION_DIJKSTRA_LESS_MEMORY = Variants.VERSION_DIJKSTRA_LESS_MEMORY
-VERSION_DISCOUNTED_A_STAR = Variants.VERSION_DISCOUNTED_A_STAR
-
-VERSIONS = {Variants.VERSION_DIJKSTRA_NO_HEURISTICS, Variants.VERSION_DIJKSTRA_NO_HEURISTICS,
-            Variants.VERSION_DIJKSTRA_LESS_MEMORY,VERSION_DISCOUNTED_A_STAR}
+    ENABLE_BEST_WORST_COST = "enable_best_worst_cost"
 
 
 def __variant_mapper(variant):
@@ -92,6 +79,18 @@ def __variant_mapper(variant):
     return variant
 
 
+DEFAULT_VARIANT = Variants.VERSION_DIJKSTRA_LESS_MEMORY
+if solver.DEFAULT_LP_SOLVER_VARIANT is not None:
+    DEFAULT_VARIANT = __variant_mapper(constants.DEFAULT_ALIGNMENTS_VARIANT)
+
+VERSION_STATE_EQUATION_A_STAR = Variants.VERSION_STATE_EQUATION_A_STAR
+VERSION_DIJKSTRA_NO_HEURISTICS = Variants.VERSION_DIJKSTRA_NO_HEURISTICS
+VERSION_DIJKSTRA_LESS_MEMORY = Variants.VERSION_DIJKSTRA_LESS_MEMORY
+
+VERSIONS = {Variants.VERSION_DIJKSTRA_NO_HEURISTICS, Variants.VERSION_DIJKSTRA_NO_HEURISTICS,
+            Variants.VERSION_DIJKSTRA_LESS_MEMORY}
+
+
 def apply(obj: Union[EventLog, EventStream, pd.DataFrame, Trace], petri_net: PetriNet, initial_marking: Marking, final_marking: Marking, parameters: Optional[Dict[Any, Any]] = None, variant=DEFAULT_VARIANT) -> Union[typing.AlignmentResult, typing.ListAlignments]:
     if parameters is None:
         parameters = {}
@@ -140,8 +139,8 @@ def apply_trace(trace, petri_net, initial_marking, final_marking, parameters=Non
 
     variant = __variant_mapper(variant)
     parameters = copy(parameters)
-    best_worst_cost = exec_utils.get_param_value(Parameters.BEST_WORST_COST_INTERNAL, parameters,
-                                                 __get_best_worst_cost(petri_net, initial_marking, final_marking, variant, parameters))
+
+    enable_best_worst_cost = exec_utils.get_param_value(Parameters.ENABLE_BEST_WORST_COST, parameters, True)
 
     ali = exec_utils.get_variant(variant).apply(trace, petri_net, initial_marking, final_marking,
                                                  parameters=parameters)
@@ -150,32 +149,20 @@ def apply_trace(trace, petri_net, initial_marking, final_marking, parameters=Non
     # Instead of using the length of the trace, use the sum of the trace cost function
     trace_cost_function_sum = sum(trace_cost_function)
 
-    if ali is not None and best_worst_cost is not None:
-        ltrace_bwc = trace_cost_function_sum + best_worst_cost
+    if enable_best_worst_cost:
+        best_worst_cost = exec_utils.get_param_value(Parameters.BEST_WORST_COST_INTERNAL, parameters,
+                                                     __get_best_worst_cost(petri_net, initial_marking, final_marking, variant, parameters))
 
-        fitness_num = ali['cost'] // align_utils.STD_MODEL_LOG_MOVE_COST
-        fitness_den = ltrace_bwc // align_utils.STD_MODEL_LOG_MOVE_COST
-        fitness = 1 - fitness_num / fitness_den if fitness_den > 0 else 0
+        if ali is not None and best_worst_cost is not None:
+            ltrace_bwc = trace_cost_function_sum + best_worst_cost
 
-        # other possibility: avoid integer division but proceed to rounding.
-        # could lead to small differences with respect to the adopted-since-now fitness
-        # (since it is rounded)
+            fitness_num = ali['cost'] // align_utils.STD_MODEL_LOG_MOVE_COST
+            fitness_den = ltrace_bwc // align_utils.STD_MODEL_LOG_MOVE_COST
+            fitness = 1 - fitness_num / fitness_den if fitness_den > 0 else 0
 
-        """
-        initial_trace_cost_function = exec_utils.get_param_value(Parameters.PARAM_TRACE_COST_FUNCTION, parameters, None)
-        initial_model_cost_function = exec_utils.get_param_value(Parameters.PARAM_MODEL_COST_FUNCTION, parameters, None)
-        initial_sync_cost_function = exec_utils.get_param_value(Parameters.PARAM_SYNC_COST_FUNCTION, parameters, None)
-        uses_standard_cost_function = initial_trace_cost_function is None and initial_model_cost_function is None and \
-                                    initial_sync_cost_function is None
-            
-        fitness = 1 - ali['cost'] / ltrace_bwc if ltrace_bwc > 0 else 0
-        fitness_round_digits = exec_utils.get_param_value(Parameters.FITNESS_ROUND_DIGITS, parameters, 3)
-        fitness = round(fitness, fitness_round_digits)
-        """
-
-        ali["fitness"] = fitness
-        # returning also the best worst cost, for log fitness computation
-        ali["bwc"] = ltrace_bwc
+            ali["fitness"] = fitness
+            # returning also the best worst cost, for log fitness computation
+            ali["bwc"] = ltrace_bwc
 
     return ali
 
@@ -213,6 +200,8 @@ def apply_log(log, petri_net, initial_marking, final_marking, parameters=None, v
         if not check_soundness.check_easy_soundness_net_in_fin_marking(petri_net, initial_marking, final_marking):
             raise Exception("trying to apply alignments on a Petri net that is not a easy sound net!!")
 
+    enable_best_worst_cost = exec_utils.get_param_value(Parameters.ENABLE_BEST_WORST_COST, parameters, True)
+
     variant = __variant_mapper(variant)
 
     start_time = time.time()
@@ -221,10 +210,12 @@ def apply_log(log, petri_net, initial_marking, final_marking, parameters=None, v
     max_align_time_case = exec_utils.get_param_value(Parameters.PARAM_MAX_ALIGN_TIME_TRACE, parameters,
                                                      sys.maxsize)
 
-    best_worst_cost = __get_best_worst_cost(petri_net, initial_marking, final_marking, variant, parameters)
     variants_idxs, one_tr_per_var = __get_variants_structure(log, parameters)
     progress = __get_progress_bar(len(one_tr_per_var), parameters)
-    parameters[Parameters.BEST_WORST_COST_INTERNAL] = best_worst_cost
+
+    if enable_best_worst_cost:
+        best_worst_cost = __get_best_worst_cost(petri_net, initial_marking, final_marking, variant, parameters)
+        parameters[Parameters.BEST_WORST_COST_INTERNAL] = best_worst_cost
 
     all_alignments = []
     for trace in one_tr_per_var:
@@ -272,9 +263,13 @@ def apply_multiprocessing(log, petri_net, initial_marking, final_marking, parame
 
     num_cores = exec_utils.get_param_value(Parameters.CORES, parameters, multiprocessing.cpu_count() - 2)
 
-    best_worst_cost = __get_best_worst_cost(petri_net, initial_marking, final_marking, variant, parameters)
+    enable_best_worst_cost = exec_utils.get_param_value(Parameters.ENABLE_BEST_WORST_COST, parameters, True)
+
     variants_idxs, one_tr_per_var = __get_variants_structure(log, parameters)
-    parameters[Parameters.BEST_WORST_COST_INTERNAL] = best_worst_cost
+
+    if enable_best_worst_cost:
+        best_worst_cost = __get_best_worst_cost(petri_net, initial_marking, final_marking, variant, parameters)
+        parameters[Parameters.BEST_WORST_COST_INTERNAL] = best_worst_cost
 
     all_alignments = []
 
@@ -321,9 +316,9 @@ def __get_variants_structure(log, parameters):
     variants_idxs = {}
     one_tr_per_var = []
 
-    if type(log) is pd.DataFrame:
+    if pandas_utils.check_is_pandas_dataframe(log):
         case_id_key = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, CASE_CONCEPT_NAME)
-        traces = list(log.groupby(case_id_key)[activity_key].apply(tuple))
+        traces = [tuple(x) for x in log.groupby(case_id_key)[activity_key].agg(list).to_dict().values()]
         for idx, trace in enumerate(traces):
             if trace not in variants_idxs:
                 variants_idxs[trace] = [idx]
@@ -347,9 +342,9 @@ def __get_variants_structure(log, parameters):
 
 
 def __get_progress_bar(num_variants, parameters):
-    show_progress_bar = exec_utils.get_param_value(Parameters.SHOW_PROGRESS_BAR, parameters, True)
+    show_progress_bar = exec_utils.get_param_value(Parameters.SHOW_PROGRESS_BAR, parameters, constants.SHOW_PROGRESS_BAR)
     progress = None
-    if pkgutil.find_loader("tqdm") and show_progress_bar and num_variants > 1:
+    if importlib.util.find_spec("tqdm") and show_progress_bar and num_variants > 1:
         from tqdm.auto import tqdm
         progress = tqdm(total=num_variants, desc="aligning log, completed variants :: ")
     return progress
@@ -408,4 +403,4 @@ def get_diagnostics_dataframe(log, align_output, parameters=None):
 
         diagn_stream.append({"case_id": case_id, "cost": cost, "fitness": fitness, "is_fit": is_fit})
 
-    return pd.DataFrame(diagn_stream)
+    return pandas_utils.instantiate_dataframe(diagn_stream)
