@@ -21,17 +21,15 @@ from pm4py.objects.log import obj as log_implementation
 from pm4py.util.constants import PARAMETER_CONSTANT_ACTIVITY_KEY
 from pm4py.util.xes_constants import DEFAULT_NAME_KEY
 from pm4py.util import exec_utils
-from pm4py.objects.petri_net.obj import Marking
 from pm4py.objects.petri_net.semantics import enabled_transitions
 from pm4py.util import variants_util
 from enum import Enum
 from copy import copy
 import heapq
-from typing import Optional, Dict, Any, Union, Tuple
-from pm4py.objects.log.obj import EventLog, EventStream, Trace
+from typing import Optional, Dict, Any, Union
+from pm4py.objects.log.obj import Trace
 from pm4py.objects.petri_net.obj import PetriNet, Marking
 from pm4py.util import typing
-import pandas as pd
 
 
 class Parameters(Enum):
