@@ -20,7 +20,7 @@ from pm4py import util as pm4pyutil
 from pm4py.objects import petri_net
 from pm4py.objects.log import obj as log_implementation
 from pm4py.util.xes_constants import DEFAULT_NAME_KEY
-from pm4py.objects.petri_net.utils.synchronous_product import construct_cost_aware
+from pm4py.objects.petri_net.utils.synchronous_product import construct, construct_cost_aware
 from pm4py.objects.petri_net.utils.petri_utils import construct_trace_net_cost_aware, decorate_places_preset_trans, \
     decorate_transitions_prepostset
 from pm4py.objects.petri_net.utils import align_utils as utils
@@ -245,7 +245,7 @@ def apply_from_variants_list_petri_string(var_list, petri_net_string, parameters
     if parameters is None:
         parameters = {}
 
-    from pm4py.objects.petri.importer.variants import pnml as petri_importer
+    from pm4py.objects.petri_net.importer.variants import pnml as petri_importer
 
     petri_net, initial_marking, final_marking = petri_importer.import_petri_from_string(petri_net_string)
 
@@ -299,11 +299,11 @@ def apply_trace_net(petri_net, initial_marking, final_marking, trace_net, trace_
     trace_net_costs = exec_utils.get_param_value(Parameters.PARAM_TRACE_NET_COSTS, parameters, None)
 
     if trace_cost_function is None or model_cost_function is None or sync_cost_function is None:
-        sync_prod, sync_initial_marking, sync_final_marking = petri.synchronous_product.construct(trace_net, trace_im,
-                                                                                                  trace_fm, petri_net,
-                                                                                                  initial_marking,
-                                                                                                  final_marking,
-                                                                                                  utils.SKIP)
+        sync_prod, sync_initial_marking, sync_final_marking = construct(trace_net, trace_im,
+                                                                        trace_fm, petri_net,
+                                                                        initial_marking,
+                                                                        final_marking,
+                                                                        utils.SKIP)
         cost_function = utils.construct_standard_cost_function(sync_prod, utils.SKIP)
     else:
         revised_sync = dict()
