@@ -16,20 +16,18 @@
 '''
 import copy
 import heapq
-import pkgutil
+import importlib.util
 from enum import Enum
-from typing import List, Any, Optional
+from typing import List
 
 import pandas as pd
 
 from pm4py.algo.conformance.alignments.process_tree.util import search_graph_pt_replay_semantics as pt_sem
-from pm4py.objects.log.obj import Trace
 from pm4py.objects.petri_net.utils import align_utils
 from pm4py.objects.process_tree.obj import Operator
-from pm4py.objects.process_tree.obj import ProcessTree
 from pm4py.objects.process_tree.utils import generic as pt_util
-from pm4py.util import exec_utils, constants, xes_constants
-from typing import Optional, Dict, Any, Union, Tuple
+from pm4py.util import exec_utils, constants, xes_constants, pandas_utils
+from typing import Optional, Dict, Any, Union
 from pm4py.objects.process_tree.obj import ProcessTree
 from pm4py.objects.log.obj import EventLog, Trace
 from pm4py.util import typing
@@ -233,7 +231,7 @@ def apply_variant(variant, tree, parameters=None):
 
 
 def _construct_progress_bar(progress_length, parameters):
-    if exec_utils.get_param_value(Parameters.SHOW_PROGRESS_BAR, parameters, True) and pkgutil.find_loader("tqdm"):
+    if exec_utils.get_param_value(Parameters.SHOW_PROGRESS_BAR, parameters, constants.SHOW_PROGRESS_BAR) and importlib.util.find_spec("tqdm"):
         if progress_length > 1:
             from tqdm.auto import tqdm
             return tqdm(total=progress_length, desc="aligning log, completed variants :: ")
@@ -322,10 +320,10 @@ def apply_multiprocessing(obj: Union[EventLog, Trace, pd.DataFrame], pt: Process
             futures = {}
             align_dict = {}
 
-            if type(obj) is pd.DataFrame:
+            if pandas_utils.check_is_pandas_dataframe(obj):
                 case_id_key = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters,
                                                          constants.CASE_CONCEPT_NAME)
-                traces = list(obj.groupby(case_id_key)[activity_key].apply(tuple))
+                traces = [tuple(x) for x in obj.groupby(case_id_key)[activity_key].agg(list).to_dict().values()]
             else:
                 obj = log_converter.apply(obj, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
                 traces = [tuple(x[activity_key] for x in case) for case in obj]
@@ -385,9 +383,9 @@ def apply(obj: Union[EventLog, Trace, pd.DataFrame], pt: ProcessTree, parameters
         return align_variant(variant, leaves, pt)
     else:
         ret = []
-        if type(obj) is pd.DataFrame:
+        if pandas_utils.check_is_pandas_dataframe(obj):
             case_id_key = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, constants.CASE_CONCEPT_NAME)
-            traces = list(obj.groupby(case_id_key)[activity_key].apply(tuple))
+            traces = [tuple(x) for x in obj.groupby(case_id_key)[activity_key].agg(list).to_dict().values()]
         else:
             obj = log_converter.apply(obj, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
             traces = [tuple(x[activity_key] for x in case) for case in obj]
