@@ -15,9 +15,14 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.algo.conformance.tokenreplay.variants import token_replay, backwards
-from pm4py.objects.conversion.log import converter as log_converter
 from enum import Enum
 from pm4py.util import exec_utils
+from typing import Optional, Dict, Any, Union
+from pm4py.objects.log.obj import EventLog, EventStream
+import pandas as pd
+from pm4py.objects.petri_net.obj import PetriNet, Marking
+from pm4py.util import typing
+
 
 class Variants(Enum):
     TOKEN_REPLAY = token_replay
@@ -27,7 +32,7 @@ VERSIONS = {Variants.TOKEN_REPLAY, Variants.BACKWARDS}
 DEFAULT_VARIANT = Variants.TOKEN_REPLAY
 
 
-def apply(log, net, initial_marking, final_marking, parameters=None, variant=DEFAULT_VARIANT):
+def apply(log: Union[EventLog, EventStream, pd.DataFrame], net: PetriNet, initial_marking: Marking, final_marking: Marking, parameters: Optional[Dict[Any, Any]] = None, variant=DEFAULT_VARIANT) -> typing.ListAlignments:
     """
     Method to apply token-based replay
     
@@ -51,11 +56,11 @@ def apply(log, net, initial_marking, final_marking, parameters=None, variant=DEF
     """
     if parameters is None:
         parameters = {}
-    return exec_utils.get_variant(variant).apply(log_converter.apply(log, parameters, log_converter.TO_EVENT_LOG), net, initial_marking,
+    return exec_utils.get_variant(variant).apply(log, net, initial_marking,
                              final_marking, parameters=parameters)
 
 
-def get_diagnostics_dataframe(log, tbr_output, variant=DEFAULT_VARIANT, parameters=None):
+def get_diagnostics_dataframe(log: Union[EventLog, EventStream, pd.DataFrame], tbr_output: typing.ListAlignments, variant=DEFAULT_VARIANT, parameters: Optional[Dict[Any, Any]] = None) -> pd.DataFrame:
     """
     Gets the results of token-based replay in a dataframe
 
