@@ -15,14 +15,14 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from copy import deepcopy
+from enum import Enum
 
 import numpy as np
 
-from pm4py.objects.log.util import basic_filter
 from pm4py.objects.log.obj import EventLog, Trace, Event
-from enum import Enum
+from pm4py.objects.log.util import basic_filter
 from pm4py.util import exec_utils
-from pm4py.util import constants
+from pm4py.objects.conversion.log import converter as log_converter
 
 
 class Parameters(Enum):
@@ -103,12 +103,14 @@ def form_representation_from_dictio_couple(first_cases_repr, second_cases_repr,
     feature_names
         Array of feature names
     """
-    from pm4py.objects.log.util import get_log_representation
+    from pm4py.algo.transformation.log_to_features import algorithm as log_to_features
 
     log = form_log_from_dictio_couple(first_cases_repr, second_cases_repr,
                                       enable_multiplier=enable_multiplier)
 
-    data, feature_names = get_log_representation.get_representation(log, [], string_attributes, [], numeric_attributes)
+    data, feature_names = log_to_features.apply(log, variant=log_to_features.Variants.TRACE_BASED,
+                                                parameters={"str_tr_attr": [], "str_ev_attr": string_attributes,
+                                                            "num_tr_attr": [], "num_ev_attr": numeric_attributes})
 
     return data, feature_names
 
@@ -138,11 +140,13 @@ def diagnose_from_trans_fitness(log, trans_fitness, parameters=None):
             - feature names
             - classes
     """
-    from sklearn import tree
+    from pm4py.util import ml_utils
 
     if parameters is None:
         parameters = {}
 
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
+
     diagnostics = {}
     string_attributes = exec_utils.get_param_value(Parameters.STRING_ATTRIBUTES, parameters, [])
     numeric_attributes = exec_utils.get_param_value(Parameters.NUMERIC_ATTRIBUTES, parameters, [])
@@ -183,8 +187,10 @@ def diagnose_from_trans_fitness(log, trans_fitness, parameters=None):
                         target.append(1)
                 classes.append("underfed")
 
+                data = np.array([np.array(x) for x in data])
+
                 target = np.asarray(target)
-                clf = tree.DecisionTreeClassifier(max_depth=7)
+                clf = ml_utils.DecisionTreeClassifier(max_depth=7)
                 clf.fit(data, target)
                 diagn_dict = {"clf": clf, "data": data, "feature_names": feature_names, "target": target,
                               "classes": classes}
@@ -219,11 +225,13 @@ def diagnose_from_notexisting_activities(log, notexisting_activities_in_model, p
             - feature names
             - classes
     """
-    from sklearn import tree
+    from pm4py.util import ml_utils
 
     if parameters is None:
         parameters = {}
 
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
+
     diagnostics = {}
     string_attributes = exec_utils.get_param_value(Parameters.STRING_ATTRIBUTES, parameters, [])
     numeric_attributes = exec_utils.get_param_value(Parameters.NUMERIC_ATTRIBUTES, parameters, [])
@@ -269,8 +277,10 @@ def diagnose_from_notexisting_activities(log, notexisting_activities_in_model, p
                     target.append(1)
             classes.append("containing")
 
+            data = np.array([np.array(x) for x in data])
+
             target = np.asarray(target)
-            clf = tree.DecisionTreeClassifier(max_depth=7)
+            clf = ml_utils.DecisionTreeClassifier(max_depth=7)
             clf.fit(data, target)
             diagn_dict = {"clf": clf, "data": data, "feature_names": feature_names, "target": target,
                           "classes": classes}
