@@ -18,17 +18,16 @@ from pm4py.statistics.variants.log import get as variants_filter
 from pm4py.objects.petri_net.semantics import is_enabled, weak_execute
 from pm4py.objects.petri_net.utils.align_utils import get_visible_transitions_eventually_enabled_by_marking
 from copy import copy
-from pm4py.objects.petri_net.obj import Marking
 from collections import Counter
-from pm4py.util import exec_utils, constants, xes_constants
+from pm4py.util import exec_utils, constants, xes_constants, pandas_utils
+import warnings
 from enum import Enum
 from pm4py.util import variants_util
-from typing import Optional, Dict, Any, Union, Tuple
-from pm4py.objects.log.obj import EventLog, EventStream
+from typing import Optional, Dict, Any, Union
+from pm4py.objects.log.obj import EventLog
 import pandas as pd
 from pm4py.objects.petri_net.obj import PetriNet, Marking
 from pm4py.util import typing
-import warnings
 
 
 class Parameters(Enum):
@@ -292,7 +291,8 @@ def apply(log: EventLog, net: PetriNet, initial_marking: Marking, final_marking:
     if parameters is None:
         parameters = {}
 
-    warnings.warn("the backwards variant of TBR will be removed in a future version.")
+    if constants.SHOW_INTERNAL_WARNINGS:
+        warnings.warn("the backwards variant of TBR will be removed in a future version.")
 
     for t in net.transitions:
         ma = Marking()
@@ -372,4 +372,4 @@ def get_diagnostics_dataframe(log: EventLog, tbr_output: typing.ListAlignments,
 
         diagn_stream.append({"case_id": case_id, "is_fit": is_fit, "trace_fitness": trace_fitness, "missing": missing, "remaining": remaining, "produced": produced, "consumed": consumed})
 
-    return pd.DataFrame(diagn_stream)
+    return pandas_utils.instantiate_dataframe(diagn_stream)
