@@ -14,20 +14,18 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.util import variants_util
 from pm4py.util import xes_constants as xes_util
 from pm4py.objects.petri_net import semantics
-from pm4py.objects.petri_net.obj import Marking
 from pm4py.objects.petri_net.utils.petri_utils import get_places_shortest_path_by_hidden, get_s_components_from_petri
 from pm4py.objects.log import obj as log_implementation
 from pm4py.objects.petri_net.utils import align_utils
 from copy import copy
 from enum import Enum
 from pm4py.util import exec_utils, constants
-from pm4py.util import variants_util
-import pkgutil
-from typing import Optional, Dict, Any, Union, Tuple
-from pm4py.objects.log.obj import EventLog, EventStream
+from pm4py.util import variants_util, pandas_utils
+import importlib.util
+from typing import Optional, Dict, Any, Union
+from pm4py.objects.log.obj import EventLog
 import pandas as pd
 from pm4py.objects.petri_net.obj import PetriNet, Marking
 from pm4py.util import typing
@@ -914,6 +912,42 @@ def get_variant_from_trace(trace, activity_key, disable_variants=False):
     return variants_util.get_variant_from_trace(trace, parameters=parameters)
 
 
+def transcribe_result(t, return_object_names=True):
+    corr_value = {"trace_is_fit": copy(t.t_fit),
+                  "trace_fitness": float(copy(t.t_value)),
+                  "activated_transitions": copy(t.act_trans),
+                  "reached_marking": copy(t.reached_marking),
+                  "enabled_transitions_in_marking": copy(
+                      t.enabled_trans_in_mark),
+                  "transitions_with_problems": copy(
+                      t.trans_probl),
+                  "missing_tokens": int(t.missing),
+                  "consumed_tokens": int(t.consumed),
+                  "remaining_tokens": int(t.remaining),
+                  "produced_tokens": int(t.produced)}
+
+    if return_object_names:
+        corr_value["activated_transitions_labels"] = [x.label for x in
+                                                      corr_value[
+                                                          "activated_transitions"]]
+        corr_value["activated_transitions"] = [x.name for x in corr_value[
+            "activated_transitions"]]
+        corr_value["enabled_transitions_in_marking_labels"] = [x.label for x in
+                                                               corr_value[
+                                                                   "enabled_transitions_in_marking"]]
+        corr_value["enabled_transitions_in_marking"] = [x.name for x in
+                                                        corr_value[
+                                                            "enabled_transitions_in_marking"]]
+        corr_value["transitions_with_problems"] = [x.name for x in
+                                                   corr_value[
+                                                       "transitions_with_problems"]]
+        corr_value["reached_marking"] = {x.name: y for x, y in
+                                         corr_value[
+                                             "reached_marking"].items()}
+
+    return corr_value
+
+
 def apply_log(log, net, initial_marking, final_marking, enable_pltr_fitness=False, consider_remaining_in_fitness=False,
               activity_key="concept:name", reach_mark_through_hidden=True, stop_immediately_unfit=False,
               walk_through_hidden_trans=True, places_shortest_path_by_hidden=None,
@@ -988,87 +1022,95 @@ def apply_log(log, net, initial_marking, final_marking, enable_pltr_fitness=Fals
     for t in net.transitions:
         trans_map[t.label] = t
 
-    if type(log) is pd.DataFrame:
-        traces = list(log.groupby(case_id_key)[activity_key].apply(tuple))
+    if pandas_utils.check_is_pandas_dataframe(log):
+        traces = [(tuple(x), y) for y, x in log.groupby(case_id_key)[activity_key].agg(list).to_dict().items()]
+        traces = [(traces[i][0], i) for i in range(len(traces))]
     else:
-        traces = [tuple(x[activity_key] for x in trace) for trace in log]
+        traces = [(tuple(x[activity_key] for x in log[i]), i) for i in range(len(log))]
 
-    variants = Counter(traces)
+    variants = dict()
+    for t in traces:
+        if t[0] not in variants:
+            variants[t[0]] = list()
+        variants[t[0]].append(t[1])
+
+    traces = [t[0] for t in traces]
 
     vc = [(k, v) for k, v in variants.items()]
-    vc = list(sorted(vc, key=lambda x: (x[1], x[0]), reverse=True))
+    vc = list(sorted(vc, key=lambda x: (len(x[1]), x[0]), reverse=True))
+
+    threads_results = {}
 
     progress = None
-    if pkgutil.find_loader("tqdm") and show_progress_bar and len(variants) > 1:
-        from tqdm.auto import tqdm
-        progress = tqdm(total=len(variants), desc="replaying log with TBR, completed variants :: ")
 
-    threads = {}
-    threads_results = {}
+    if importlib.util.find_spec("tqdm") and show_progress_bar and len(variants) > 1:
+        from tqdm.auto import tqdm
+
+        if disable_variants and not pandas_utils.check_is_pandas_dataframe(log):
+            progress = tqdm(total=len(traces), desc="replaying log with TBR, completed traces :: ")
+        else:
+            progress = tqdm(total=len(variants), desc="replaying log with TBR, completed traces :: ")
 
     for i in range(len(vc)):
         variant = vc[i][0]
-        considered_case = variants_util.variant_to_trace(variant, parameters={constants.PARAMETER_CONSTANT_ACTIVITY_KEY: activity_key})
+        all_cases = vc[i][1]
 
-        threads[variant] = ApplyTraceTokenReplay(considered_case, net, initial_marking, final_marking,
-                                                 trans_map, enable_pltr_fitness, place_fitness_per_trace,
-                                                 transition_fitness_per_trace,
-                                                 notexisting_activities_in_model,
-                                                 places_shortest_path_by_hidden,
-                                                 consider_remaining_in_fitness,
-                                                 activity_key=activity_key,
-                                                 reach_mark_through_hidden=reach_mark_through_hidden,
-                                                 stop_immediately_when_unfit=stop_immediately_unfit,
-                                                 walk_through_hidden_trans=walk_through_hidden_trans,
-                                                 post_fix_caching=post_fix_cache,
-                                                 marking_to_activity_caching=marking_to_activity_cache,
-                                                 is_reduction=is_reduction,
-                                                 thread_maximum_ex_time=thread_maximum_ex_time,
-                                                 cleaning_token_flood=cleaning_token_flood,
-                                                 s_components=s_components, trace_occurrences=vc[i][1],
-                                                 consider_activities_not_in_model_in_fitness=consider_activities_not_in_model_in_fitness)
-        threads[variant].run()
-        if progress is not None:
-            progress.update()
+        if disable_variants and not pandas_utils.check_is_pandas_dataframe(log):
+            for j in range(len(all_cases)):
+                case_position = all_cases[j]
+                considered_case = log[case_position]
+                t = ApplyTraceTokenReplay(considered_case, net, initial_marking, final_marking,
+                                          trans_map, enable_pltr_fitness, place_fitness_per_trace,
+                                          transition_fitness_per_trace,
+                                          notexisting_activities_in_model,
+                                          places_shortest_path_by_hidden,
+                                          consider_remaining_in_fitness,
+                                          activity_key=activity_key,
+                                          reach_mark_through_hidden=reach_mark_through_hidden,
+                                          stop_immediately_when_unfit=stop_immediately_unfit,
+                                          walk_through_hidden_trans=walk_through_hidden_trans,
+                                          post_fix_caching=post_fix_cache,
+                                          marking_to_activity_caching=marking_to_activity_cache,
+                                          is_reduction=is_reduction,
+                                          thread_maximum_ex_time=thread_maximum_ex_time,
+                                          cleaning_token_flood=cleaning_token_flood,
+                                          s_components=s_components, trace_occurrences=1,
+                                          consider_activities_not_in_model_in_fitness=consider_activities_not_in_model_in_fitness)
+                t.run()
+                threads_results[case_position] = transcribe_result(t, return_object_names=return_object_names)
+                if progress is not None:
+                    progress.update()
+        else:
+            considered_case = variants_util.variant_to_trace(variant, parameters={constants.PARAMETER_CONSTANT_ACTIVITY_KEY: activity_key})
+            t = ApplyTraceTokenReplay(considered_case, net, initial_marking, final_marking,
+                                                     trans_map, enable_pltr_fitness, place_fitness_per_trace,
+                                                     transition_fitness_per_trace,
+                                                     notexisting_activities_in_model,
+                                                     places_shortest_path_by_hidden,
+                                                     consider_remaining_in_fitness,
+                                                     activity_key=activity_key,
+                                                     reach_mark_through_hidden=reach_mark_through_hidden,
+                                                     stop_immediately_when_unfit=stop_immediately_unfit,
+                                                     walk_through_hidden_trans=walk_through_hidden_trans,
+                                                     post_fix_caching=post_fix_cache,
+                                                     marking_to_activity_caching=marking_to_activity_cache,
+                                                     is_reduction=is_reduction,
+                                                     thread_maximum_ex_time=thread_maximum_ex_time,
+                                                     cleaning_token_flood=cleaning_token_flood,
+                                                     s_components=s_components, trace_occurrences=len(vc[i][1]),
+                                                     consider_activities_not_in_model_in_fitness=consider_activities_not_in_model_in_fitness)
+            t.run()
 
-        t = threads[variant]
-        threads_results[variant] = {"trace_is_fit": copy(t.t_fit),
-                                    "trace_fitness": float(copy(t.t_value)),
-                                    "activated_transitions": copy(t.act_trans),
-                                    "reached_marking": copy(t.reached_marking),
-                                    "enabled_transitions_in_marking": copy(
-                                        t.enabled_trans_in_mark),
-                                    "transitions_with_problems": copy(
-                                        t.trans_probl),
-                                    "missing_tokens": int(t.missing),
-                                    "consumed_tokens": int(t.consumed),
-                                    "remaining_tokens": int(t.remaining),
-                                    "produced_tokens": int(t.produced)}
+            for j in range(len(all_cases)):
+                case_position = all_cases[j]
 
-        if return_object_names:
-            threads_results[variant]["activated_transitions_labels"] = [x.label for x in
-                                                                        threads_results[variant][
-                                                                            "activated_transitions"]]
-            threads_results[variant]["activated_transitions"] = [x.name for x in threads_results[variant][
-                "activated_transitions"]]
-            threads_results[variant]["enabled_transitions_in_marking_labels"] = [x.label for x in
-                                                                                 threads_results[variant][
-                                                                                     "enabled_transitions_in_marking"]]
-            threads_results[variant]["enabled_transitions_in_marking"] = [x.name for x in
-                                                                          threads_results[variant][
-                                                                              "enabled_transitions_in_marking"]]
-            threads_results[variant]["transitions_with_problems"] = [x.name for x in
-                                                                     threads_results[variant][
-                                                                         "transitions_with_problems"]]
-            threads_results[variant]["reached_marking"] = {x.name: y for x, y in
-                                                           threads_results[variant][
-                                                               "reached_marking"].items()}
-        del threads[variant]
+                threads_results[case_position] = transcribe_result(t, return_object_names=return_object_names)
 
-    for trace_variant in traces:
-        if trace_variant in threads_results:
-            t = threads_results[trace_variant]
-            aligned_traces.append(t)
+            if progress is not None:
+                progress.update()
+
+    for i in range(len(traces)):
+        aligned_traces.append(threads_results[i])
 
     # gracefully close progress bar
     if progress is not None:
@@ -1120,7 +1162,7 @@ def apply(log: EventLog, net: PetriNet, initial_marking: Marking, final_marking:
     activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes_util.DEFAULT_NAME_KEY)
     consider_activities_not_in_model_in_fitness = exec_utils.get_param_value(Parameters.CONSIDER_ACTIVITIES_NOT_IN_MODEL_IN_FITNESS, parameters, False)
 
-    show_progress_bar = exec_utils.get_param_value(Parameters.SHOW_PROGRESS_BAR, parameters, True)
+    show_progress_bar = exec_utils.get_param_value(Parameters.SHOW_PROGRESS_BAR, parameters, constants.SHOW_PROGRESS_BAR)
     case_id_key = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, constants.CASE_CONCEPT_NAME)
 
     if type(log) is not pd.DataFrame:
@@ -1217,4 +1259,4 @@ def get_diagnostics_dataframe(log: EventLog, tbr_output: typing.ListAlignments,
 
         diagn_stream.append({"case_id": case_id, "is_fit": is_fit, "trace_fitness": trace_fitness, "missing": missing, "remaining": remaining, "produced": produced, "consumed": consumed})
 
-    return pd.DataFrame(diagn_stream)
+    return pandas_utils.instantiate_dataframe(diagn_stream)
