@@ -15,3 +15,9 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.algo.decision_mining import algorithm
+
+from pm4py.util import constants
+import warnings
+
+if constants.SHOW_INTERNAL_WARNINGS:
+    warnings.warn("The decision_mining package will be removed in a future release.")
