@@ -16,7 +16,6 @@
 '''
 from pm4py.util import xes_constants, pandas_utils, constants
 from pm4py.util.business_hours import soj_time_business_hours_diff
-import numpy as np
 
 
 def get_dfg_graph(df, measure="frequency", activity_key="concept:name", case_id_glue="case:concept:name",
@@ -70,7 +69,8 @@ def get_dfg_graph(df, measure="frequency", activity_key="concept:name", case_id_
     st_eq_ct = start_timestamp_key == timestamp_key
     if start_timestamp_key is None:
         start_timestamp_key = xes_constants.DEFAULT_START_TIMESTAMP_KEY
-        df[start_timestamp_key] = df[timestamp_key]
+        if start_timestamp_key not in df.columns:
+            df[start_timestamp_key] = df[timestamp_key]
         st_eq_ct = True
 
     # to increase the speed of the approaches reduce dataframe to case, activity (and possibly complete timestamp)
@@ -103,7 +103,7 @@ def get_dfg_graph(df, measure="frequency", activity_key="concept:name", case_id_
     # change column names to shifted dataframe
     df_shifted.columns = [str(col) + '_2' for col in df_shifted.columns]
     # concate the two dataframe to get a unique dataframe
-    df_successive_rows = pd.concat([df, df_shifted], axis=1)
+    df_successive_rows = pandas_utils.concat([df, df_shifted], axis=1)
     # as successive rows in the sorted dataframe may belong to different case IDs we have to restrict ourselves to
     # successive rows belonging to same case ID
     df_successive_rows = df_successive_rows[df_successive_rows[case_id_glue] == df_successive_rows[case_id_glue + '_2']]
@@ -126,8 +126,8 @@ def get_dfg_graph(df, measure="frequency", activity_key="concept:name", case_id_
             df_successive_rows[constants.DEFAULT_FLOW_TIME] = df_successive_rows.apply(
             lambda x: soj_time_business_hours_diff(x[timestamp_key], x[start_timestamp_key + '_2'], business_hours_slot, workcalendar), axis=1)
         else:
-            df_successive_rows[constants.DEFAULT_FLOW_TIME] = (
-                    df_successive_rows[start_timestamp_key + '_2'] - df_successive_rows[timestamp_key]).dt.total_seconds()
+            difference = df_successive_rows[start_timestamp_key + '_2'] - df_successive_rows[timestamp_key]
+            df_successive_rows[constants.DEFAULT_FLOW_TIME] = pandas_utils.get_total_seconds(difference)
         # groups couple of attributes (directly follows relation, we can measure the frequency and the performance)
         directly_follows_grouping = df_successive_rows.groupby([activity_key, target_activity_key + '_2'])[
             constants.DEFAULT_FLOW_TIME]
@@ -156,7 +156,7 @@ def get_dfg_graph(df, measure="frequency", activity_key="concept:name", case_id_
             for key in dfg_performance_mean:
                 dfg_performance[key] = {"mean": dfg_performance_mean[key], "median": dfg_performance_median[key], "max": dfg_performance_max[key], "min": dfg_performance_min[key], "sum": dfg_performance_sum[key], "stdev": dfg_performance_std[key]}
         elif perf_aggregation_key == "raw_values":
-            dfg_performance = directly_follows_grouping.apply(list).to_dict()
+            dfg_performance = directly_follows_grouping.agg(list).to_dict()
         else:
             dfg_performance = directly_follows_grouping.agg(perf_aggregation_key).to_dict()
 
@@ -227,18 +227,18 @@ def get_partial_order_dataframe(df, start_timestamp_key=None, timestamp_key="tim
             df = df.sort_values([case_id_glue, start_timestamp_key, timestamp_key])
         else:
             df = df.sort_values(case_id_glue)
-        df.reset_index(drop=True, inplace=True)
+        df = df.reset_index(drop=True)
 
     if event_index not in df.columns:
-        df[event_index] = df.index
+        df = pandas_utils.insert_index(df, event_index, copy_dataframe=False, reset_index=False)
 
-    df.set_index(case_id_glue, inplace=True)
+    df = df.set_index(case_id_glue)
 
     df = df.join(df, rsuffix="_2")
     df = df[df[event_index] < df[event_index + "_2"]]
     df = df[df[timestamp_key] <= df[start_timestamp_key + '_2']]
 
-    df.reset_index(inplace=True)
+    df = df.reset_index()
 
     if business_hours:
         if business_hours_slot is None:
@@ -246,7 +246,7 @@ def get_partial_order_dataframe(df, start_timestamp_key=None, timestamp_key="tim
         df[constants.DEFAULT_FLOW_TIME] = df.apply(
             lambda x: soj_time_business_hours_diff(x[timestamp_key], x[start_timestamp_key + '_2'], business_hours_slot, workcalendar), axis=1)
     else:
-        df[constants.DEFAULT_FLOW_TIME] = (df[start_timestamp_key + "_2"] - df[timestamp_key]).dt.total_seconds()
+        df[constants.DEFAULT_FLOW_TIME] = pandas_utils.get_total_seconds(df[start_timestamp_key + "_2"] - df[timestamp_key])
 
     if keep_first_following:
         df = df.groupby(constants.DEFAULT_INDEX_KEY).first().reset_index()
