@@ -38,8 +38,8 @@ from pm4py.statistics.end_activities.log import get as log_ea
 from pm4py.statistics.end_activities.pandas import get as pd_ea
 from pm4py.statistics.eventually_follows.log import get as efg_get
 from pm4py.statistics.eventually_follows.pandas import get as pd_efg
-from pm4py.statistics.sojourn_time.log import get as soj_get
-from pm4py.statistics.sojourn_time.pandas import get as pd_soj_time
+from pm4py.statistics.service_time.log import get as soj_get
+from pm4py.statistics.service_time.pandas import get as pd_soj_time
 from pm4py.statistics.start_activities.log import get as log_sa
 from pm4py.statistics.start_activities.pandas import get as pd_sa
 from pm4py.util import exec_utils, constants, xes_constants as xes
@@ -433,7 +433,7 @@ def calculate(heu_net: HeuristicsNet, dependency_thresh: float, and_measure_thre
             heu_net.performance_matrix[act1] = {}
         heu_net.dfg_matrix[act1][act2] = heu_net.dfg[el]
         heu_net.dependency_matrix[act1][act2] = -1
-        heu_net.performance_matrix[act1][act2] = heu_net.performance_dfg[el] if heu_net.performance_dfg else 0.0
+        heu_net.performance_matrix[act1][act2] = heu_net.performance_dfg[el] if heu_net.performance_dfg and el in heu_net.performance_dfg else 0.0
     for act1 in heu_net.activities:
         heu_net.nodes[act1] = Node(heu_net, act1, heu_net.activities_occurrences[act1], node_type=heu_net.node_type)
     # calculates the dependencies between the activities
