@@ -16,9 +16,11 @@
 '''
 from pm4py.algo.discovery.performance_spectrum.variants import dataframe, log, dataframe_disconnected, log_disconnected
 from pm4py.util import exec_utils
-import pkgutil
 from enum import Enum
-from pm4py.util import constants
+from pm4py.util import constants, pandas_utils
+from typing import Optional, Dict, Any, Union, List
+from pm4py.objects.log.obj import EventLog, EventStream
+import pandas as pd
 
 
 class Parameters(Enum):
@@ -41,7 +43,7 @@ class Variants(Enum):
     LOG_DISCONNECTED = log_disconnected
 
 
-def apply(log, list_activities, variant=None, parameters=None):
+def apply(log: Union[EventLog, EventStream, pd.DataFrame], list_activities: List[str], variant=None, parameters: Optional[Dict[Any, Any]] = None) -> Dict[str, Any]:
     """
     Finds the performance spectrum provided a log/dataframe
     and a list of activities
@@ -76,19 +78,17 @@ def apply(log, list_activities, variant=None, parameters=None):
 
     points = None
 
-    if pkgutil.find_loader("pandas"):
-        import pandas as pd
-        if type(log) is pd.DataFrame:
-            if variant is None:
-                variant = Variants.DATAFRAME
+    if pandas_utils.check_is_pandas_dataframe(log):
+        if variant is None:
+            variant = Variants.DATAFRAME
 
-            points = exec_utils.get_variant(variant).apply(log, list_activities, sample_size, parameters)
+        points = exec_utils.get_variant(variant).apply(log, list_activities, sample_size, parameters)
 
     if points is None:
         if variant is None:
             variant = Variants.LOG
 
-        points = exec_utils.get_variant(variant).apply(log_conversion.apply(log), list_activities, sample_size,
+        points = exec_utils.get_variant(variant).apply(log_conversion.apply(log, variant=log_conversion.Variants.TO_EVENT_LOG, parameters=parameters), list_activities, sample_size,
                                                             parameters)
 
     ps = {Outputs.LIST_ACTIVITIES.value: list_activities, Outputs.POINTS.value: points}
