@@ -16,6 +16,8 @@
 '''
 from pm4py.algo.evaluation.earth_mover_distance import algorithm, variants
 
+from pm4py.util import constants
 import warnings
 
-warnings.warn("The earth_mover_distance package will be removed in a future release.")
+if constants.SHOW_INTERNAL_WARNINGS:
+    warnings.warn("The earth_mover_distance package will be removed in a future release.")
