@@ -15,10 +15,9 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.algo.evaluation.generalization.variants import token_based
-from pm4py.objects.conversion.log import converter as log_conversion
 from enum import Enum
 from pm4py.util import exec_utils
-from typing import Optional, Dict, Any, Union, Tuple
+from typing import Optional, Dict, Any, Union
 from pm4py.objects.log.obj import EventLog, EventStream
 from pm4py.objects.petri_net.obj import PetriNet, Marking
 import pandas as pd
@@ -36,6 +35,6 @@ def apply(log: Union[EventLog, EventStream, pd.DataFrame], petri_net: PetriNet,
     if parameters is None:
         parameters = {}
 
-    return exec_utils.get_variant(variant).apply(log_conversion.apply(log, parameters, log_conversion.TO_EVENT_LOG),
+    return exec_utils.get_variant(variant).apply(log,
                                                  petri_net,
                                                  initial_marking, final_marking, parameters=parameters)
