@@ -16,11 +16,10 @@
 '''
 from pm4py.algo.evaluation.precision.variants import etconformance_token
 from pm4py.algo.evaluation.precision.variants import align_etconformance
-from pm4py.objects.conversion.log import converter as log_conversion
 from pm4py.objects.petri_net.utils.check_soundness import check_easy_soundness_net_in_fin_marking
 from enum import Enum
 from pm4py.util import exec_utils
-from typing import Optional, Dict, Any, Union, Tuple
+from typing import Optional, Dict, Any, Union
 from pm4py.objects.log.obj import EventLog, EventStream
 from pm4py.objects.petri_net.obj import PetriNet, Marking
 import pandas as pd
@@ -62,8 +61,6 @@ def apply(log: Union[EventLog, EventStream, pd.DataFrame], net: PetriNet, markin
     if parameters is None:
         parameters = {}
 
-    log = log_conversion.apply(log, parameters, log_conversion.TO_EVENT_LOG)
-
     # execute the following part of code when the variant is not specified by the user
     if variant is None:
         if not (check_easy_soundness_net_in_fin_marking(
