@@ -15,7 +15,7 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from datetime import datetime
-import pytz
+from pm4py.util.dt_parsing.variants import strpfromiso
 
 
 def get_dt_from_string(dt):
@@ -35,5 +35,5 @@ def get_dt_from_string(dt):
     if type(dt) is str:
         dt = datetime.strptime(dt, "%Y-%m-%d %H:%M:%S")
 
-    #dt = dt.replace(tzinfo=pytz.utc)
+    dt = strpfromiso.fix_naivety(dt)
     return dt
