@@ -16,6 +16,8 @@
 '''
 from pm4py.algo.filtering.log.attr_value_repetition import filter
 
+from pm4py.util import constants
 import warnings
 
-warnings.warn("The attr_value_repetition filter package will be removed in a future release.")
+if constants.SHOW_INTERNAL_WARNINGS:
+    warnings.warn("The attr_value_repetition filter package will be removed in a future release.")
