@@ -17,14 +17,13 @@
 from enum import Enum
 
 from pm4py.objects.conversion.log import converter as log_converter
-from pm4py.objects.log.obj import EventLog
 from pm4py.util import exec_utils
 from pm4py.util.constants import PARAMETER_CONSTANT_ATTRIBUTE_KEY, PARAMETER_CONSTANT_RESOURCE_KEY, \
     PARAMETER_CONSTANT_TIMESTAMP_KEY
 from pm4py.util.xes_constants import DEFAULT_NAME_KEY, DEFAULT_RESOURCE_KEY, DEFAULT_TIMESTAMP_KEY
 
-from typing import Optional, Dict, Any, Union, Tuple, List
-from pm4py.objects.log.obj import EventLog, EventStream, Trace
+from typing import Optional, Dict, Any, Union, List
+from pm4py.objects.log.obj import EventLog
 import itertools
 
 
