@@ -16,17 +16,17 @@
 '''
 import datetime
 from enum import Enum
-from typing import Union, Dict, Optional, Any
 
 from pm4py.algo.filtering.common.timestamp.timestamp_common import get_dt_from_string
 from pm4py.objects.conversion.log import converter as log_converter
-from pm4py.objects.log.obj import EventLog, EventStream, Trace
+from pm4py.objects.log.obj import Trace
 from pm4py.util import exec_utils
 from pm4py.util.constants import PARAMETER_CONSTANT_TIMESTAMP_KEY
 from pm4py.util.xes_constants import DEFAULT_TIMESTAMP_KEY
 
-from typing import Optional, Dict, Any, Union, Tuple
+from typing import Optional, Dict, Any, Union
 from pm4py.objects.log.obj import EventLog, EventStream
+from pm4py.util.dt_parsing.variants import strpfromiso
 
 
 class Parameters(Enum):
@@ -55,7 +55,7 @@ def trace_attr_is_contained(trace: Trace, dt1: Union[str, datetime.datetime], dt
         Boolean value
     """
     if trace_attr in trace.attributes:
-        if dt1 <= trace.attributes[trace_attr].replace(tzinfo=None) <= dt2:
+        if dt1 <= strpfromiso.fix_naivety(trace.attributes[trace_attr]) <= dt2:
             return True
     return False
 
@@ -118,7 +118,7 @@ def is_contained(trace, dt1, dt2, timestamp_key):
         Is true if the trace is contained
     """
     if trace:
-        if trace[0][timestamp_key].replace(tzinfo=None) >= dt1 and trace[-1][timestamp_key].replace(tzinfo=None) <= dt2:
+        if strpfromiso.fix_naivety(trace[0][timestamp_key]) >= dt1 and strpfromiso.fix_naivety(trace[-1][timestamp_key]) <= dt2:
             return True
     return False
 
@@ -179,12 +179,10 @@ def is_intersecting(trace, dt1, dt2, timestamp_key):
         Is true if the trace is contained
     """
     if trace:
-        condition1 = dt1 <= trace[0][timestamp_key].replace(tzinfo=None) <= dt2
-        condition2 = dt1 <= trace[-1][timestamp_key].replace(tzinfo=None) <= dt2
-        condition3 = trace[0][timestamp_key].replace(tzinfo=None) <= dt1 <= trace[-1][timestamp_key].replace(
-            tzinfo=None)
-        condition4 = trace[0][timestamp_key].replace(tzinfo=None) <= dt2 <= trace[-1][timestamp_key].replace(
-            tzinfo=None)
+        condition1 = dt1 <= strpfromiso.fix_naivety(trace[0][timestamp_key]) <= dt2
+        condition2 = dt1 <= strpfromiso.fix_naivety(trace[-1][timestamp_key]) <= dt2
+        condition3 = strpfromiso.fix_naivety(trace[0][timestamp_key]) <= dt1 <= strpfromiso.fix_naivety(trace[-1][timestamp_key])
+        condition4 = strpfromiso.fix_naivety(trace[0][timestamp_key]) <= dt2 <= strpfromiso.fix_naivety(trace[-1][timestamp_key])
 
         if condition1 or condition2 or condition3 or condition4:
             return True
@@ -255,7 +253,7 @@ def apply_events(log: EventLog, dt1: Union[str, datetime.datetime], dt2: Union[s
     dt2 = get_dt_from_string(dt2)
 
     stream = log_converter.apply(log, variant=log_converter.TO_EVENT_STREAM, parameters={"deepcopy": False})
-    filtered_stream = EventStream([x for x in stream if dt1 <= x[timestamp_key].replace(tzinfo=None) <= dt2],
+    filtered_stream = EventStream([x for x in stream if dt1 <= strpfromiso.fix_naivety(x[timestamp_key]) <= dt2],
                                   attributes=log.attributes, extensions=log.extensions, omni_present=log.omni_present,
                                   classifiers=log.classifiers, properties=log.properties)
     filtered_log = log_converter.apply(filtered_stream, variant=log_converter.Variants.TO_EVENT_LOG)
@@ -265,7 +263,7 @@ def apply_events(log: EventLog, dt1: Union[str, datetime.datetime], dt2: Union[s
 
 def has_attribute_in_timeframe(trace, attribute, attribute_value, dt1, dt2, timestamp_key):
     for e in trace:
-        if attribute in e and e[attribute] == attribute_value and dt1 <= e[timestamp_key].replace(tzinfo=None) <= dt2:
+        if attribute in e and e[attribute] == attribute_value and dt1 <= strpfromiso.fix_naivety(e[timestamp_key]) <= dt2:
             return True
     return False
 
