@@ -16,16 +16,13 @@
 '''
 from enum import Enum
 
-from pm4py.algo.filtering.common import filtering_constants
-from pm4py.objects.log.obj import EventLog
 from pm4py.statistics.variants.log.get import get_variants, \
-    get_variants_sorted_by_count, get_variants_along_with_case_durations
+    get_variants_sorted_by_count
 from pm4py.util import exec_utils
 from pm4py.util.constants import PARAMETER_CONSTANT_ACTIVITY_KEY
-from pm4py.util.xes_constants import DEFAULT_NAME_KEY
 
-from typing import Optional, Dict, Any, Union, Tuple, List
-from pm4py.objects.log.obj import EventLog, EventStream, Trace
+from typing import Optional, Dict, Any, Union, List
+from pm4py.objects.log.obj import EventLog
 from pm4py.objects.conversion.log import converter as log_converter
 
 
