@@ -14,17 +14,14 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-import pandas as pd
-import pytz
-
 from pm4py.util.constants import CASE_CONCEPT_NAME
 from pm4py.algo.filtering.common.timestamp.timestamp_common import get_dt_from_string
 from pm4py.util.xes_constants import DEFAULT_TIMESTAMP_KEY
 from pm4py.util.constants import PARAMETER_CONSTANT_TIMESTAMP_KEY, PARAMETER_CONSTANT_CASEID_KEY
 from enum import Enum
-from pm4py.util import exec_utils
+from pm4py.util import exec_utils, pandas_utils, constants
 from copy import copy
-from typing import Optional, Dict, Any, Union, Tuple, List
+from typing import Optional, Dict, Any, Union
 import pandas as pd
 import datetime
 
@@ -62,15 +59,12 @@ def filter_traces_contained(df: pd.DataFrame, dt1: Union[str, datetime.datetime]
     case_id_glue = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, CASE_CONCEPT_NAME)
     dt1 = get_dt_from_string(dt1)
     dt2 = get_dt_from_string(dt2)
-    dt1 = dt1.replace(tzinfo=pytz.utc)
-    dt2 = dt2.replace(tzinfo=pytz.utc)
-    dt1 = pd.to_datetime(dt1, utc=True)
-    dt2 = pd.to_datetime(dt2, utc=True)
+
     grouped_df = df[[case_id_glue, timestamp_key]].groupby(df[case_id_glue])
     first = grouped_df.first()
     last = grouped_df.last()
     last.columns = [str(col) + '_2' for col in last.columns]
-    stacked = pd.concat([first, last], axis=1)
+    stacked = pandas_utils.concat([first, last], axis=1)
     stacked = stacked[stacked[timestamp_key] >= dt1]
     stacked = stacked[stacked[timestamp_key + "_2"] <= dt2]
     i1 = df.set_index(case_id_glue).index
@@ -109,22 +103,18 @@ def filter_traces_intersecting(df: pd.DataFrame, dt1: Union[str, datetime.dateti
     case_id_glue = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, CASE_CONCEPT_NAME)
     dt1 = get_dt_from_string(dt1)
     dt2 = get_dt_from_string(dt2)
-    dt1 = dt1.replace(tzinfo=pytz.utc)
-    dt2 = dt2.replace(tzinfo=pytz.utc)
-    dt1 = pd.to_datetime(dt1, utc=True)
-    dt2 = pd.to_datetime(dt2, utc=True)
     grouped_df = df[[case_id_glue, timestamp_key]].groupby(df[case_id_glue])
     first = grouped_df.first()
     last = grouped_df.last()
     last.columns = [str(col) + '_2' for col in last.columns]
-    stacked = pd.concat([first, last], axis=1)
+    stacked = pandas_utils.concat([first, last], axis=1)
     stacked1 = stacked[stacked[timestamp_key] > dt1]
     stacked1 = stacked1[stacked1[timestamp_key] < dt2]
     stacked2 = stacked[stacked[timestamp_key + "_2"] > dt1]
     stacked2 = stacked2[stacked2[timestamp_key + "_2"] < dt2]
     stacked3 = stacked[stacked[timestamp_key] < dt1]
     stacked3 = stacked3[stacked3[timestamp_key + "_2"] > dt2]
-    stacked = pd.concat([stacked1, stacked2, stacked3], axis=0)
+    stacked = pandas_utils.concat([stacked1, stacked2, stacked3], axis=0)
     i1 = df.set_index(case_id_glue).index
     i2 = stacked.set_index(case_id_glue).index
     ret = df[i1.isin(i2)]
@@ -160,10 +150,6 @@ def apply_events(df: pd.DataFrame, dt1: Union[str, datetime.datetime], dt2: Unio
     timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, DEFAULT_TIMESTAMP_KEY)
     dt1 = get_dt_from_string(dt1)
     dt2 = get_dt_from_string(dt2)
-    dt1 = dt1.replace(tzinfo=pytz.utc)
-    dt2 = dt2.replace(tzinfo=pytz.utc)
-    dt1 = pd.to_datetime(dt1, utc=True)
-    dt2 = pd.to_datetime(dt2, utc=True)
 
     ret = df[df[timestamp_key] >= dt1]
     ret = ret[ret[timestamp_key] <= dt2]
@@ -205,10 +191,6 @@ def filter_traces_attribute_in_timeframe(df: pd.DataFrame, attribute: str, attri
     
     dt1 = get_dt_from_string(dt1)
     dt2 = get_dt_from_string(dt2)
-    dt1 = dt1.replace(tzinfo=pytz.utc)
-    dt2 = dt2.replace(tzinfo=pytz.utc)
-    dt1 = pd.to_datetime(dt1, utc=True)
-    dt2 = pd.to_datetime(dt2, utc=True)
     
     filtered = df[df[attribute] == attribute_value]
     filtered = filtered[filtered[timestamp_key] >= dt1]
