@@ -18,6 +18,7 @@ from pm4py.algo.organizational_mining.resource_profiles.variants import pandas,
 import pandas as pd
 from pm4py.objects.log.obj import EventLog
 from typing import Union, Optional, Dict, Any
+from pm4py.util import pandas_utils
 from datetime import datetime
 
 
@@ -45,7 +46,7 @@ def distinct_activities(log_obj: Union[pd.DataFrame, EventLog], t1: Union[dateti
     distinct_activities
         Distinct activities
     """
-    if type(log_obj) is pd.DataFrame:
+    if pandas_utils.check_is_pandas_dataframe(log_obj):
         return pandas.distinct_activities(log_obj, t1, t2, r, parameters=parameters)
     else:
         return log.distinct_activities(log_obj, t1, t2, r, parameters=parameters)
@@ -78,7 +79,7 @@ def activity_frequency(log_obj: Union[pd.DataFrame, EventLog], t1: Union[datetim
     metric
         Value of the metric
     """
-    if type(log_obj) is pd.DataFrame:
+    if pandas_utils.check_is_pandas_dataframe(log_obj):
         return pandas.activity_frequency(log_obj, t1, t2, r, a, parameters=parameters)
     else:
         return log.activity_frequency(log_obj, t1, t2, r, a, parameters=parameters)
@@ -108,7 +109,7 @@ def activity_completions(log_obj: Union[pd.DataFrame, EventLog], t1: Union[datet
     metric
         Value of the metric
     """
-    if type(log_obj) is pd.DataFrame:
+    if pandas_utils.check_is_pandas_dataframe(log_obj):
         return pandas.activity_completions(log_obj, t1, t2, r, parameters=parameters)
     else:
         return log.activity_completions(log_obj, t1, t2, r, parameters=parameters)
@@ -138,7 +139,7 @@ def case_completions(log_obj: Union[pd.DataFrame, EventLog], t1: Union[datetime,
     metric
         Value of the metric
     """
-    if type(log_obj) is pd.DataFrame:
+    if pandas_utils.check_is_pandas_dataframe(log_obj):
         return pandas.case_completions(log_obj, t1, t2, r, parameters=parameters)
     else:
         return log.case_completions(log_obj, t1, t2, r, parameters=parameters)
@@ -169,7 +170,7 @@ def fraction_case_completions(log_obj: Union[pd.DataFrame, EventLog], t1: Union[
     metric
         Value of the metric
     """
-    if type(log_obj) is pd.DataFrame:
+    if pandas_utils.check_is_pandas_dataframe(log_obj):
         return pandas.fraction_case_completions(log_obj, t1, t2, r, parameters=parameters)
     else:
         return log.fraction_case_completions(log_obj, t1, t2, r, parameters=parameters)
@@ -199,7 +200,7 @@ def average_workload(log_obj: Union[pd.DataFrame, EventLog], t1: Union[datetime,
     metric
         Value of the metric
     """
-    if type(log_obj) is pd.DataFrame:
+    if pandas_utils.check_is_pandas_dataframe(log_obj):
         return pandas.average_workload(log_obj, t1, t2, r, parameters=parameters)
     else:
         return log.average_workload(log_obj, t1, t2, r, parameters=parameters)
@@ -230,7 +231,7 @@ def multitasking(log_obj: Union[pd.DataFrame, EventLog], t1: Union[datetime, str
     metric
         Value of the metric
     """
-    if type(log_obj) is pd.DataFrame:
+    if pandas_utils.check_is_pandas_dataframe(log_obj):
         return pandas.multitasking(log_obj, t1, t2, r, parameters=parameters)
     else:
         return log.multitasking(log_obj, t1, t2, r, parameters=parameters)
@@ -262,7 +263,7 @@ def average_duration_activity(log_obj: Union[pd.DataFrame, EventLog], t1: Union[
     metric
         Value of the metric
     """
-    if type(log_obj) is pd.DataFrame:
+    if pandas_utils.check_is_pandas_dataframe(log_obj):
         return pandas.average_duration_activity(log_obj, t1, t2, r, a, parameters=parameters)
     else:
         return log.average_duration_activity(log_obj, t1, t2, r, a, parameters=parameters)
@@ -292,7 +293,7 @@ def average_case_duration(log_obj: Union[pd.DataFrame, EventLog], t1: Union[date
     metric
         Value of the metric
     """
-    if type(log_obj) is pd.DataFrame:
+    if pandas_utils.check_is_pandas_dataframe(log_obj):
         return pandas.average_case_duration(log_obj, t1, t2, r, parameters=parameters)
     else:
         return log.average_case_duration(log_obj, t1, t2, r, parameters=parameters)
@@ -324,7 +325,7 @@ def interaction_two_resources(log_obj: Union[pd.DataFrame, EventLog], t1: Union[
     metric
         Value of the metric
     """
-    if type(log_obj) is pd.DataFrame:
+    if pandas_utils.check_is_pandas_dataframe(log_obj):
         return pandas.interaction_two_resources(log_obj, t1, t2, r1, r2, parameters=parameters)
     else:
         return log.interaction_two_resources(log_obj, t1, t2, r1, r2, parameters=parameters)
@@ -355,7 +356,7 @@ def social_position(log_obj: Union[pd.DataFrame, EventLog], t1: Union[datetime,
     metric
         Value of the metric
     """
-    if type(log_obj) is pd.DataFrame:
+    if pandas_utils.check_is_pandas_dataframe(log_obj):
         return pandas.social_position(log_obj, t1, t2, r, parameters=parameters)
     else:
         return log.social_position(log_obj, t1, t2, r, parameters=parameters)
