@@ -19,9 +19,9 @@ from enum import Enum
 from typing import Union, Optional, Dict, Any, Tuple
 
 import pandas as pd
-import pytz
+from pm4py.algo.filtering.common.timestamp.timestamp_common import get_dt_from_string
 
-from pm4py.util import exec_utils, constants, xes_constants
+from pm4py.util import exec_utils, constants, xes_constants, pandas_utils
 from statistics import mean
 
 
@@ -33,29 +33,6 @@ class Parameters(Enum):
     CASE_ID_KEY = constants.PARAMETER_CONSTANT_CASEID_KEY
 
 
-def get_dt_from_string(dt: Union[datetime, str]) -> datetime:
-    """
-    If the date is expressed as string, do the conversion to a datetime.datetime object
-
-    Parameters
-    -----------
-    dt
-        Date (string or datetime.datetime)
-
-    Returns
-    -----------
-    dt
-        Datetime object
-    """
-    if type(dt) is str:
-        dt = datetime.strptime(dt, "%Y-%m-%d %H:%M:%S")
-
-    dt = dt.replace(tzinfo=pytz.utc)
-    dt = pd.to_datetime(dt, utc=True)
-
-    return dt
-
-
 def distinct_activities(df: pd.DataFrame, t1: Union[datetime, str], t2: Union[datetime, str], r: str,
                         parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> int:
     """
@@ -330,7 +307,7 @@ def __insert_start_from_previous_event(df: pd.DataFrame, parameters: Optional[Di
     shifted_df = df[[case_id_key, timestamp_key]].shift(1)
     shifted_df.columns = [x + "_2" for x in shifted_df.columns]
 
-    concat_df = pd.concat([df, shifted_df], axis=1)
+    concat_df = pandas_utils.concat([df, shifted_df], axis=1)
     concat_df = concat_df[concat_df[case_id_key] == concat_df[case_id_key + "_2"]][
         [constants.DEFAULT_INDEX_KEY, timestamp_key + "_2"]]
 
@@ -529,7 +506,7 @@ def average_duration_activity(df: pd.DataFrame, t1: Union[datetime, str], t2: Un
     df = df[df[timestamp_key] >= t1]
     df = df[df[timestamp_key] < t2]
 
-    return float((df[timestamp_key] - df[start_timestamp_key]).dt.total_seconds().mean())
+    return float(pandas_utils.get_total_seconds(df[timestamp_key] - df[start_timestamp_key]).mean())
 
 
 def average_case_duration(df: pd.DataFrame, t1: Union[datetime, str], t2: Union[datetime, str], r: str,
@@ -620,7 +597,7 @@ def interaction_two_resources(df: pd.DataFrame, t1: Union[datetime, str], t2: Un
     last_df = df.groupby(case_id_key).last().reset_index()
     last_df = last_df[last_df[timestamp_key] >= t1]
     last_df = last_df[last_df[timestamp_key] < t2]
-    cases = set(last_df[case_id_key].unique())
+    cases = pandas_utils.format_unique(last_df[case_id_key].unique())
     df = df[df[case_id_key].isin(cases)]
 
     return df[case_id_key].nunique()
