@@ -16,6 +16,8 @@
 '''
 from pm4py.algo.reduction import process_tree
 
+from pm4py.util import constants
 import warnings
 
-warnings.warn("The reduction package will be removed in a future release.")
+if constants.SHOW_INTERNAL_WARNINGS:
+    warnings.warn("The reduction package will be removed in a future release.")
