@@ -17,6 +17,8 @@
 
 from pm4py.algo.simulation.montecarlo import algorithm, variants, utils
 
+from pm4py.util import constants
 import warnings
 
-warnings.warn("The simulation.montecarlo package will be removed in a future release.")
+if constants.SHOW_INTERNAL_WARNINGS:
+    warnings.warn("The simulation.montecarlo package will be removed in a future release.")
