@@ -19,9 +19,10 @@ from pm4py.algo.simulation.montecarlo.utils import replay
 from pm4py.objects.petri_net.semantics import enabled_transitions, weak_execute
 from threading import Thread, Semaphore
 from statistics import median
-from pm4py.objects.log.obj import EventLog, Trace, Event
+from pm4py.objects.log.obj import Trace, Event
 from pm4py.util import xes_constants
 from pm4py.objects.stochastic_petri import utils as stochastic_utils
+from pm4py.util.dt_parsing.variants import strpfromiso
 import datetime
 from time import sleep, time
 import logging
@@ -30,6 +31,10 @@ from pm4py.util import exec_utils
 from enum import Enum
 from pm4py.util import constants
 
+from typing import Optional, Dict, Any, Union, Tuple
+from pm4py.objects.log.obj import EventLog
+from pm4py.objects.petri_net.obj import PetriNet, Marking
+
 
 class Parameters(Enum):
     ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
@@ -234,7 +239,7 @@ class SimulationThread(Thread):
 
             if ct.label is not None:
                 eve = Event({xes_constants.DEFAULT_NAME_KEY: ct.label,
-                             xes_constants.DEFAULT_TIMESTAMP_KEY: datetime.datetime.fromtimestamp(current_time)})
+                             xes_constants.DEFAULT_TIMESTAMP_KEY: strpfromiso.fix_naivety(datetime.datetime.fromtimestamp(current_time))})
                 last_event = eve
                 if first_event is None:
                     first_event = last_event
@@ -278,7 +283,7 @@ class SimulationThread(Thread):
             diagnostics.diagn_open = False
 
 
-def apply(log, net, im, fm, parameters=None):
+def apply(log: EventLog, net: PetriNet, im: Marking, fm: Marking, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> Tuple[EventLog, Dict[str, Any]]:
     """
     Performs a Monte Carlo simulation of an accepting Petri net without duplicate transitions and where the preset is always
     distinct from the postset (FIFO variant; the semaphores pile up if waiting is needed, and the first in is the first to win
