@@ -16,6 +16,8 @@
 '''
 from pm4py.algo.transformation.log_to_interval_tree import algorithm, variants
 
+from pm4py.util import constants
 import warnings
 
-warnings.warn("The log_to_interval_tree package will be removed in a future release.")
+if constants.SHOW_INTERNAL_WARNINGS:
+    warnings.warn("The log_to_interval_tree package will be removed in a future release.")
