@@ -14,4 +14,5 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.transformation.ocel.features.events import algorithm, event_activity, event_timestamp, event_num_rel_objs_type, event_num_rel_objs, event_str_attributes, event_num_attributes, event_start_ot, event_end_ot, related_objects_features
+
+from pm4py.algo.transformation.ocel.features.events import algorithm, event_activity, event_timestamp, event_num_rel_objs_type, event_num_rel_objs, event_str_attributes, event_num_attributes, event_start_ot, event_end_ot, related_objects_features, new_interactions
