@@ -18,10 +18,12 @@ from pm4py.objects.ocel.obj import OCEL
 from typing import Optional, Dict, Any, List
 from enum import Enum
 from pm4py.util import exec_utils
-from pm4py.algo.transformation.ocel.features.objects import object_lifecycle_length, object_lifecycle_duration, object_degree_centrality, object_general_descendants_graph, object_general_interaction_graph, object_general_inheritance_graph, object_cobirth_graph, object_codeath_graph, object_lifecycle_activities, object_str_attributes, object_num_attributes, objects_interaction_graph_ot, object_work_in_progress, related_events_features, related_activities_features, obj_con_in_graph_features, object_lifecycle_unq_act
+import time
+from pm4py.algo.transformation.ocel.features.objects import object_lifecycle_length, object_lifecycle_duration, object_degree_centrality, object_general_descendants_graph, object_general_interaction_graph, object_general_inheritance_graph, object_cobirth_graph, object_codeath_graph, object_lifecycle_activities, object_str_attributes, object_num_attributes, objects_interaction_graph_ot, object_work_in_progress, related_events_features, related_activities_features, obj_con_in_graph_features, object_lifecycle_unq_act, object_lifecycle_paths
 
 
 class Parameters(Enum):
+    DEBUG = "debug"
     ENABLE_ALL = "enable_all"
     ENABLE_LIFECYCLE_METRICS = "enable_lifecycle_metrics"
     ENABLE_OBJECT_LIFECYCLE_LENGTH = "enable_object_lifecycle_length"
@@ -34,6 +36,7 @@ class Parameters(Enum):
     ENABLE_OBJECT_COBIRTH_GRAPH = "enable_object_cobirth_graph"
     ENABLE_OBJECT_CODEATH_GRAPH = "enable_object_codeath_graph"
     ENABLE_OBJECT_LIFECYCLE_ACTIVITIES = "enable_object_lifecycle_activities"
+    ENABLE_OBJECT_LIFECYCLE_PATHS = "enable_object_lifecycle_paths"
     ENABLE_OBJECT_STR_ATTRIBUTES = "enable_object_str_attributes"
     ENABLE_OBJECT_NUM_ATTRIBUTES = "enable_object_num_attributes"
     ENABLE_OBJECT_INTERACTION_GRAPH_OT = "enable_object_interaction_graph_ot"
@@ -48,6 +51,9 @@ def apply(ocel: OCEL, parameters: Optional[Dict[Any, Any]] = None):
     """
     Extract a feature table related to the objects of an OCEL
 
+    Implements the approach described in:
+    Berti, A., Herforth, J., Qafari, M.S. et al. Graph-based feature extraction on object-centric event logs. Int J Data Sci Anal (2023). https://doi.org/10.1007/s41060-023-00428-2
+
     Parameters
     ------------------
     ocel
@@ -80,6 +86,8 @@ def apply(ocel: OCEL, parameters: Optional[Dict[Any, Any]] = None):
                                                         of an activity in the events related to the object.
         - Parameters.ENABLE_OBJ_CON_IN_GRAPH_FEATURES => enables the extraction of features from the neighboring
                                                         objects.
+        - Parameters.ENABLE_OBJECT_LIFECYCLE_PATHS => enables the features associated to the paths in the
+                                                            lifecycle of an object
 
     Returns
     ------------------
@@ -91,6 +99,7 @@ def apply(ocel: OCEL, parameters: Optional[Dict[Any, Any]] = None):
     if parameters is None:
         parameters = {}
 
+    debug = exec_utils.get_param_value(Parameters.DEBUG, parameters, False)
     enable_all = exec_utils.get_param_value(Parameters.ENABLE_ALL, parameters, True)
     enable_lifecycle_metrics = exec_utils.get_param_value(Parameters.ENABLE_LIFECYCLE_METRICS, parameters, enable_all)
     enable_object_lifecycle_length = exec_utils.get_param_value(Parameters.ENABLE_OBJECT_LIFECYCLE_LENGTH, parameters, enable_lifecycle_metrics)
@@ -110,112 +119,230 @@ def apply(ocel: OCEL, parameters: Optional[Dict[Any, Any]] = None):
     enable_related_events_features = exec_utils.get_param_value(Parameters.ENABLE_RELATED_EVENTS_FEATURES, parameters, False)
     enable_related_activities_features = exec_utils.get_param_value(Parameters.ENABLE_RELATED_ACTIVITIES_FEATURES, parameters, False)
     enable_obj_con_in_graph_features = exec_utils.get_param_value(Parameters.ENABLE_OBJ_CON_IN_GRAPH_FEATURES, parameters, False)
+    enable_object_lifecycle_paths = exec_utils.get_param_value(Parameters.ENABLE_OBJECT_LIFECYCLE_PATHS, parameters, False)
 
     filter_per_type = exec_utils.get_param_value(Parameters.FILTER_PER_TYPE, parameters, None)
 
-    ordered_objects = list(ocel.objects[ocel.object_id_column])
+    T0 = time.time_ns()
+
+    ordered_objects = ocel.objects[ocel.object_id_column].to_numpy()
+    parameters["ordered_objects"] = ordered_objects
 
     datas = [[] for x in ordered_objects]
     feature_namess = []
 
     if enable_object_lifecycle_length:
+        if debug:
+            print("computing enable_object_lifecycle_length")
+        t0 = time.time_ns()
         data, feature_names = object_lifecycle_length.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_object_lifecycle_length", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_object_lifecycle_duration:
+        if debug:
+            print("computing enable_object_lifecycle_duration")
+        t0 = time.time_ns()
         data, feature_names = object_lifecycle_duration.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_object_lifecycle_duration", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_object_degree_centrality:
+        if debug:
+            print("computing enable_object_degree_centrality")
+        t0 = time.time_ns()
         data, feature_names = object_degree_centrality.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_object_degree_centrality", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_object_general_interaction_graph:
+        if debug:
+            print("computing enable_object_general_interaction_graph")
+        t0 = time.time_ns()
         data, feature_names = object_general_interaction_graph.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_object_general_interaction_graph", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_object_general_descendants_graph:
+        if debug:
+            print("computing enable_object_general_descendants_graph")
+        t0 = time.time_ns()
         data, feature_names = object_general_descendants_graph.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_object_general_descendants_graph", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_object_general_inheritance_graph:
+        if debug:
+            print("computing enable_object_general_inheritance_graph")
+        t0 = time.time_ns()
         data, feature_names = object_general_inheritance_graph.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_object_general_inheritance_graph", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_object_cobirth_graph:
+        if debug:
+            print("computing enable_object_cobirth_graph")
+        t0 = time.time_ns()
         data, feature_names = object_cobirth_graph.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_object_cobirth_graph", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_object_codeath_graph:
+        if debug:
+            print("computing enable_object_codeath_graph")
+        t0 = time.time_ns()
         data, feature_names = object_codeath_graph.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_object_codeath_graph", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_object_lifecycle_activities:
+        if debug:
+            print("computing enable_object_lifecycle_activities")
+        t0 = time.time_ns()
         data, feature_names = object_lifecycle_activities.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_object_lifecycle_activities", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_object_str_attributes:
+        if debug:
+            print("computing enable_object_str_attributes")
+        t0 = time.time_ns()
         data, feature_names = object_str_attributes.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_object_str_attributes", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_object_num_attributes:
+        if debug:
+            print("computing enable_object_num_attributes")
+        t0 = time.time_ns()
         data, feature_names = object_num_attributes.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_object_num_attributes", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_object_interaction_graph_ot:
+        if debug:
+            print("computing enable_object_interaction_graph_ot")
+        t0 = time.time_ns()
         data, feature_names = objects_interaction_graph_ot.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_object_interaction_graph_ot", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_work_in_progress:
+        if debug:
+            print("computing enable_work_in_progress")
+        t0 = time.time_ns()
         data, feature_names = object_work_in_progress.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_work_in_progress", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_object_lifecycle_unq_act:
+        if debug:
+            print("computing enable_object_lifecycle_unq_act")
+        t0 = time.time_ns()
         data, feature_names = object_lifecycle_unq_act.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_object_lifecycle_unq_act", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_related_events_features:
+        if debug:
+            print("computing enable_related_events_features")
+        t0 = time.time_ns()
         data, feature_names = related_events_features.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_related_events_features", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_related_activities_features:
+        if debug:
+            print("computing enable_related_activities_features")
+        t0 = time.time_ns()
         data, feature_names = related_activities_features.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_related_activities_features", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
 
     if enable_obj_con_in_graph_features:
+        if debug:
+            print("computing enable_obj_con_in_graph_features")
+        t0 = time.time_ns()
         data, feature_names = obj_con_in_graph_features.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_obj_con_in_graph_features", "%.4f" % ((t1-t0)/10**9))
+        feature_namess = feature_namess + feature_names
+        for i in range(len(data)):
+            datas[i] = datas[i] + data[i]
+
+    if enable_object_lifecycle_paths:
+        if debug:
+            print("computing enable_object_lifecycle_paths")
+        t0 = time.time_ns()
+        data, feature_names = object_lifecycle_paths.apply(ocel, parameters=parameters)
+        t1 = time.time_ns()
+        if debug:
+            print("computed enable_object_lifecycle_paths", "%.4f" % ((t1-t0)/10**9))
         feature_namess = feature_namess + feature_names
         for i in range(len(data)):
             datas[i] = datas[i] + data[i]
@@ -226,6 +353,10 @@ def apply(ocel: OCEL, parameters: Optional[Dict[Any, Any]] = None):
         idxs = [i for i in range(len(ordered_objects)) if object_type[ordered_objects[i]] == filter_per_type]
         datas = [datas[i] for i in idxs]
 
+    T1 = time.time_ns()
+    if debug:
+        print("Total time: %.4f" % ((T1-T0)/10**9))
+
     return datas, feature_namess
 
 
@@ -251,7 +382,7 @@ def transform_features_to_dict_dict(ocel: OCEL, data: List[List[float]], feature
     if parameters is None:
         parameters = {}
 
-    objects = list(ocel.objects[ocel.object_id_column])
+    objects = ocel.objects[ocel.object_id_column].to_numpy()
     ret = {}
     i = 0
     while i < len(data):
