@@ -18,12 +18,11 @@ __doc__ = """
 The ``pm4py.conformance`` module contains the conformance checking algorithms implemented in ``pm4py``
 """
 
-import warnings
 from typing import List, Dict, Any, Union, Optional, Tuple, Set
 
 from pm4py.objects.log.obj import EventLog, Trace, Event, EventStream
 from pm4py.objects.petri_net.obj import PetriNet, Marking
-from collections import Counter
+from pm4py.convert import convert_to_event_log
 from pm4py.objects.process_tree.obj import ProcessTree
 from pm4py.util import xes_constants, constants
 from pm4py.utils import get_properties, __event_log_deprecation_warning
@@ -33,7 +32,7 @@ import deprecation
 
 
 def conformance_diagnostics_token_based_replay(log: Union[EventLog, pd.DataFrame], petri_net: PetriNet, initial_marking: Marking,
-                                               final_marking: Marking, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> List[Dict[str, Any]]:
+                                               final_marking: Marking, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name", return_diagnostics_dataframe: bool = constants.DEFAULT_RETURN_DIAGNOSTICS_DATAFRAME, opt_parameters: Optional[Dict[Any, Any]] = None) -> List[Dict[str, Any]]:
     """
     Apply token-based replay for conformance checking analysis.
     The methods return the full token-based-replay diagnostics.
@@ -61,6 +60,17 @@ def conformance_diagnostics_token_based_replay(log: Union[EventLog, pd.DataFrame
     :param activity_key: attribute to be used for the activity
     :param timestamp_key: attribute to be used for the timestamp
     :param case_id_key: attribute to be used as case identifier
+    :param return_diagnostics_dataframe: if possible, returns a dataframe with the diagnostics (instead of the usual output)
+    :param opt_parameters: optional parameters of the token-based replay, including:
+        * reach_mark_through_hidden: boolean value that decides if we shall try to reach the final marking through hidden transitions
+        * stop_immediately_unfit: boolean value that decides if we shall stop immediately when a non-conformance is detected
+        * walk_through_hidden_trans: boolean value that decides if we shall walk through hidden transitions in order to enable visible transitions
+        * places_shortest_path_by_hidden: shortest paths between places by hidden transitions
+        * is_reduction: expresses if the token-based replay is called in a reduction attempt
+        * thread_maximum_ex_time: alignment threads maximum allowed execution time
+        * cleaning_token_flood: decides if a cleaning of the token flood shall be operated
+        * disable_variants: disable variants grouping
+        * return_object_names: decides whether names instead of object pointers shall be returned
     :rtype: ``List[Dict[str, Any]]``
 
     .. code-block:: python3
@@ -70,19 +80,33 @@ def conformance_diagnostics_token_based_replay(log: Union[EventLog, pd.DataFrame
         net, im, fm = pm4py.discover_petri_net_inductive(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
         tbr_diagnostics = pm4py.conformance_diagnostics_token_based_replay(dataframe, net, im, fm, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
 
+    if return_diagnostics_dataframe:
+        log = convert_to_event_log(log, case_id_key=case_id_key)
+        case_id_key = None
+
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
 
+    if opt_parameters is None:
+        opt_parameters = {}
+
+    for k, v in opt_parameters.items():
+        properties[k] = v
+
     from pm4py.algo.conformance.tokenreplay import algorithm as token_replay
-    return token_replay.apply(log, petri_net, initial_marking, final_marking, parameters=properties)
+    result = token_replay.apply(log, petri_net, initial_marking, final_marking, parameters=properties)
+
+    if return_diagnostics_dataframe:
+        return token_replay.get_diagnostics_dataframe(log, result, parameters=properties)
+
+    return result
 
 
-def conformance_diagnostics_alignments(log: Union[EventLog, pd.DataFrame], *args, multi_processing: bool = constants.ENABLE_MULTIPROCESSING_DEFAULT, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> List[Dict[str, Any]]:
+def conformance_diagnostics_alignments(log: Union[EventLog, pd.DataFrame], *args, multi_processing: bool = constants.ENABLE_MULTIPROCESSING_DEFAULT, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name", variant_str : Optional[str] = None, return_diagnostics_dataframe: bool = constants.DEFAULT_RETURN_DIAGNOSTICS_DATAFRAME, **kwargs) -> List[Dict[str, Any]]:
     """
     Apply the alignments algorithm between a log and a process model.
     The methods return the full alignment diagnostics.
@@ -107,6 +131,8 @@ def conformance_diagnostics_alignments(log: Union[EventLog, pd.DataFrame], *args
     :param activity_key: attribute to be used for the activity
     :param timestamp_key: attribute to be used for the timestamp
     :param case_id_key: attribute to be used as case identifier
+    :param variant_str: variant specification (for Petri net alignments)
+    :param return_diagnostics_dataframe: if possible, returns a dataframe with the diagnostics (instead of the usual output)
     :rtype: ``List[Dict[str, Any]]``
 
     .. code-block:: python3
@@ -116,42 +142,71 @@ def conformance_diagnostics_alignments(log: Union[EventLog, pd.DataFrame], *args
         net, im, fm = pm4py.discover_petri_net_inductive(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
         alignments_diagnostics = pm4py.conformance_diagnostics_alignments(dataframe, net, im, fm, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
 
+    if return_diagnostics_dataframe:
+        log = convert_to_event_log(log, case_id_key=case_id_key)
+        case_id_key = None
+
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
+    if kwargs is not None:
+        for k, v in kwargs.items():
+            properties[k] = v
 
     if len(args) == 3:
         if type(args[0]) is PetriNet:
             # Petri net alignments
             from pm4py.algo.conformance.alignments.petri_net import algorithm as alignments
+            variant = alignments.DEFAULT_VARIANT
+            if variant_str is not None:
+                variant = variant_str
             if multi_processing:
-                return alignments.apply_multiprocessing(log, args[0], args[1], args[2], parameters=properties)
+                result = alignments.apply_multiprocessing(log, args[0], args[1], args[2], parameters=properties, variant=variant)
             else:
-                return alignments.apply(log, args[0], args[1], args[2], parameters=properties)
+                result = alignments.apply(log, args[0], args[1], args[2], parameters=properties, variant=variant)
+
+            if return_diagnostics_dataframe:
+                return alignments.get_diagnostics_dataframe(log, result, parameters=properties)
+
+            return result
         elif isinstance(args[0], dict):
             # DFG alignments
             from pm4py.algo.conformance.alignments.dfg import algorithm as dfg_alignment
-            return dfg_alignment.apply(log, args[0], args[1], args[2], parameters=properties)
+            result = dfg_alignment.apply(log, args[0], args[1], args[2], parameters=properties)
+
+            return result
     elif len(args) == 1:
         if type(args[0]) is ProcessTree:
             # process tree alignments
             from pm4py.algo.conformance.alignments.process_tree.variants import search_graph_pt
             if multi_processing:
-                return search_graph_pt.apply_multiprocessing(log, args[0], parameters=properties)
+                result = search_graph_pt.apply_multiprocessing(log, args[0], parameters=properties)
             else:
-                return search_graph_pt.apply(log, args[0], parameters=properties)
+                result = search_graph_pt.apply(log, args[0], parameters=properties)
+
+            return result
+        elif type(args[0]) in [EventLog, pd.DataFrame]:
+            # edit distance alignments (log2log)
+            from pm4py.algo.conformance.alignments.edit_distance import algorithm as edit_distance_alignments
+            result = edit_distance_alignments.apply(log, args[0], parameters=properties)
+
+            return result
     # try to convert to Petri net
     import pm4py
     from pm4py.algo.conformance.alignments.petri_net import algorithm as alignments
     net, im, fm = pm4py.convert_to_petri_net(*args)
     if multi_processing:
-        return alignments.apply_multiprocessing(log, net, im, fm, parameters=properties)
+        result = alignments.apply_multiprocessing(log, net, im, fm, parameters=properties)
     else:
-        return alignments.apply(log, net, im, fm, parameters=properties)
+        result = alignments.apply(log, net, im, fm, parameters=properties)
+
+    if return_diagnostics_dataframe:
+        return alignments.get_diagnostics_dataframe(log, result, parameters=properties)
+
+    return result
 
 
 def fitness_token_based_replay(log: Union[EventLog, pd.DataFrame], petri_net: PetriNet, initial_marking: Marking, final_marking: Marking, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> \
@@ -187,7 +242,6 @@ def fitness_token_based_replay(log: Union[EventLog, pd.DataFrame], petri_net: Pe
         net, im, fm = pm4py.discover_petri_net_inductive(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
         fitness_tbr = pm4py.fitness_token_based_replay(dataframe, net, im, fm, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     if check_is_pandas_dataframe(log):
@@ -196,11 +250,13 @@ def fitness_token_based_replay(log: Union[EventLog, pd.DataFrame], petri_net: Pe
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
 
     from pm4py.algo.evaluation.replay_fitness import algorithm as replay_fitness
-    return replay_fitness.apply(log, petri_net, initial_marking, final_marking,
+    result = replay_fitness.apply(log, petri_net, initial_marking, final_marking,
                                 variant=replay_fitness.Variants.TOKEN_BASED, parameters=properties)
 
+    return result
 
-def fitness_alignments(log: Union[EventLog, pd.DataFrame], petri_net: PetriNet, initial_marking: Marking, final_marking: Marking, multi_processing: bool = constants.ENABLE_MULTIPROCESSING_DEFAULT, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> \
+
+def fitness_alignments(log: Union[EventLog, pd.DataFrame], petri_net: PetriNet, initial_marking: Marking, final_marking: Marking, multi_processing: bool = constants.ENABLE_MULTIPROCESSING_DEFAULT, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name", variant_str : Optional[str] = None) -> \
         Dict[str, float]:
     """
     Calculates the fitness using alignments
@@ -225,6 +281,7 @@ def fitness_alignments(log: Union[EventLog, pd.DataFrame], petri_net: PetriNet,
     :param activity_key: attribute to be used for the activity
     :param timestamp_key: attribute to be used for the timestamp
     :param case_id_key: attribute to be used as case identifier
+    :param variant_str: variant specification
     :rtype: ``Dict[str, float]``
 
     .. code-block:: python3
@@ -234,7 +291,6 @@ def fitness_alignments(log: Union[EventLog, pd.DataFrame], petri_net: PetriNet,
         net, im, fm = pm4py.discover_petri_net_inductive(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
         fitness_alignments = pm4py.fitness_alignments(dataframe, net, im, fm, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     if check_is_pandas_dataframe(log):
@@ -243,8 +299,10 @@ def fitness_alignments(log: Union[EventLog, pd.DataFrame], petri_net: PetriNet,
     from pm4py.algo.evaluation.replay_fitness import algorithm as replay_fitness
     parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
     parameters["multiprocessing"] = multi_processing
-    return replay_fitness.apply(log, petri_net, initial_marking, final_marking,
-                                variant=replay_fitness.Variants.ALIGNMENT_BASED, parameters=parameters)
+    result = replay_fitness.apply(log, petri_net, initial_marking, final_marking,
+                                variant=replay_fitness.Variants.ALIGNMENT_BASED, align_variant=variant_str, parameters=parameters)
+
+    return result
 
 
 def precision_token_based_replay(log: Union[EventLog, pd.DataFrame], petri_net: PetriNet, initial_marking: Marking,
@@ -279,7 +337,6 @@ def precision_token_based_replay(log: Union[EventLog, pd.DataFrame], petri_net:
         net, im, fm = pm4py.discover_petri_net_inductive(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
         precision_tbr = pm4py.precision_token_based_replay(dataframe, net, im, fm, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     if check_is_pandas_dataframe(log):
@@ -288,9 +345,11 @@ def precision_token_based_replay(log: Union[EventLog, pd.DataFrame], petri_net:
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
 
     from pm4py.algo.evaluation.precision import algorithm as precision_evaluator
-    return precision_evaluator.apply(log, petri_net, initial_marking, final_marking,
+    result = precision_evaluator.apply(log, petri_net, initial_marking, final_marking,
                                      variant=precision_evaluator.Variants.ETCONFORMANCE_TOKEN, parameters=properties)
 
+    return result
+
 
 def precision_alignments(log: Union[EventLog, pd.DataFrame], petri_net: PetriNet, initial_marking: Marking,
                          final_marking: Marking, multi_processing: bool = constants.ENABLE_MULTIPROCESSING_DEFAULT, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> float:
@@ -327,7 +386,6 @@ def precision_alignments(log: Union[EventLog, pd.DataFrame], petri_net: PetriNet
         net, im, fm = pm4py.discover_petri_net_inductive(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
         precision_alignments = pm4py.precision_alignments(dataframe, net, im, fm, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     if check_is_pandas_dataframe(log):
@@ -336,10 +394,85 @@ def precision_alignments(log: Union[EventLog, pd.DataFrame], petri_net: PetriNet
     from pm4py.algo.evaluation.precision import algorithm as precision_evaluator
     parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
     parameters["multiprocessing"] = multi_processing
-    return precision_evaluator.apply(log, petri_net, initial_marking, final_marking,
+    result = precision_evaluator.apply(log, petri_net, initial_marking, final_marking,
                                      variant=precision_evaluator.Variants.ALIGN_ETCONFORMANCE,
                                      parameters=parameters)
 
+    return result
+
+
+def generalization_tbr(log: Union[EventLog, pd.DataFrame], petri_net: PetriNet, initial_marking: Marking,
+                                 final_marking: Marking, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> float:
+    """
+    Computes the generalization of the model (against the event log). The approach is described in the paper:
+
+    Buijs, Joos CAM, Boudewijn F. van Dongen, and Wil MP van der Aalst. "Quality dimensions in process discovery: The importance of fitness, precision, generalization and simplicity." International Journal of Cooperative Information Systems 23.01 (2014): 1440001.
+
+
+    :param log: event log
+    :param petri_net: petri net
+    :param initial_marking: initial marking
+    :param final_marking: final marking
+    :param multi_processing: boolean value that enables the multiprocessing
+    :param activity_key: attribute to be used for the activity
+    :param timestamp_key: attribute to be used for the timestamp
+    :param case_id_key: attribute to be used as case identifier
+    :rtype: ``float``
+
+    .. code-block:: python3
+
+        import pm4py
+
+        net, im, fm = pm4py.discover_petri_net_inductive(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
+        generalization_tbr = pm4py.generalization_tbr(dataframe, net, im, fm)
+    """
+    __event_log_deprecation_warning(log)
+
+    if check_is_pandas_dataframe(log):
+        check_pandas_dataframe_columns(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
+
+    from pm4py.algo.evaluation.generalization import algorithm as generalization_evaluator
+    parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
+    result = generalization_evaluator.apply(log, petri_net, initial_marking, final_marking, variant=generalization_evaluator.Variants.GENERALIZATION_TOKEN, parameters=parameters)
+
+    return result
+
+
+def replay_prefix_tbr(prefix: List[str], net: PetriNet, im: Marking, fm: Marking, activity_key: str = "concept:name") -> Marking:
+    """
+    Replays a prefix (list of activities) on a given accepting Petri net, using Token-Based Replay.
+
+    :param prefix: list of activities
+    :param net: Petri net
+    :param im: initial marking
+    :param fm: final marking
+    :param activity_key: attribute to be used as activity
+    :rtype:  ``Marking``
+
+    .. code-block:: python3
+
+        import pm4py
+
+        net, im, fm = pm4py.read_pnml('tests/input_data/running-example.pnml')
+        marking = pm4py.replay_prefix_tbr(['register request', 'check ticket'], net, im, fm)
+    """
+    purpose_log = EventLog()
+    trace = Trace()
+    for act in prefix:
+        trace.append(Event({activity_key: act}))
+    purpose_log.append(trace)
+
+    from pm4py.algo.conformance.tokenreplay.variants import token_replay
+    parameters_tr = {
+        token_replay.Parameters.CONSIDER_REMAINING_IN_FITNESS: False,
+        token_replay.Parameters.TRY_TO_REACH_FINAL_MARKING_THROUGH_HIDDEN: False,
+        token_replay.Parameters.STOP_IMMEDIATELY_UNFIT: True,
+        token_replay.Parameters.WALK_THROUGH_HIDDEN_TRANS: True,
+        token_replay.Parameters.ACTIVITY_KEY: activity_key
+    }
+    res = token_replay.apply(purpose_log, net, im, fm, parameters=parameters_tr)[0]
+    return res["reached_marking"]
+
 
 @deprecation.deprecated(deprecated_in="2.3.0", removed_in="3.0.0", details="conformance checking using footprints will not be exposed in a future release")
 def __convert_to_fp(*args) -> Union[List[Dict[str, Any]], Dict[str, Any]]:
@@ -382,9 +515,11 @@ def conformance_diagnostics_footprints(*args) -> Union[List[Dict[str, Any]], Dic
     fp2 = __convert_to_fp(args[1:])
     from pm4py.algo.conformance.footprints import algorithm as footprints_conformance
     if isinstance(fp1, list):
-        return footprints_conformance.apply(fp1, fp2, variant=footprints_conformance.Variants.TRACE_EXTENSIVE)
+        result = footprints_conformance.apply(fp1, fp2, variant=footprints_conformance.Variants.TRACE_EXTENSIVE)
     else:
-        return footprints_conformance.apply(fp1, fp2, variant=footprints_conformance.Variants.LOG_EXTENSIVE)
+        result = footprints_conformance.apply(fp1, fp2, variant=footprints_conformance.Variants.LOG_EXTENSIVE)
+
+    return result
 
 
 @deprecation.deprecated(deprecated_in="2.3.0", removed_in="3.0.0", details="conformance checking using footprints will not be exposed in a future release")
@@ -408,7 +543,9 @@ def fitness_footprints(*args) -> Dict[str, float]:
     fp1 = __convert_to_fp(args[0])
     fp2 = __convert_to_fp(args[1:])
     from pm4py.algo.conformance.footprints.util import evaluation
-    return evaluation.fp_fitness(fp1, fp2, fp_conf)
+    result = evaluation.fp_fitness(fp1, fp2, fp_conf)
+
+    return result
 
 
 @deprecation.deprecated(deprecated_in="2.3.0", removed_in="3.0.0", details="conformance checking using footprints will not be exposed in a future release")
@@ -429,7 +566,9 @@ def precision_footprints(*args) -> float:
     fp1 = __convert_to_fp(args[0])
     fp2 = __convert_to_fp(args[1:])
     from pm4py.algo.conformance.footprints.util import evaluation
-    return evaluation.fp_precision(fp1, fp2)
+    result = evaluation.fp_precision(fp1, fp2)
+
+    return result
 
 
 @deprecation.deprecated(removed_in="2.3.0", deprecated_in="3.0.0", details="this method will be removed in a future release.")
@@ -456,14 +595,14 @@ def __check_is_fit_process_tree(trace, tree) -> bool:
     else:
         from pm4py.convert import convert_to_petri_net
         net, im, fm = convert_to_petri_net(tree)
-        tbr_conf_res = conformance_diagnostics_token_based_replay(log, net, im, fm)[0]
+        tbr_conf_res = conformance_diagnostics_token_based_replay(log, net, im, fm, return_diagnostics_dataframe=False)[0]
         # CHECK 2) if TBR says that is fit, then return True
         # (if they say False, it might be a false negative)
         if tbr_conf_res["trace_is_fit"]:
             return True
         else:
             # CHECK 3) alignments definitely say if the trace is fit or not if the previous methods fail
-            align_conf_res = conformance_diagnostics_alignments(log, tree)[0]
+            align_conf_res = conformance_diagnostics_alignments(log, tree, return_diagnostics_dataframe=False)[0]
             return align_conf_res["fitness"] == 1.0
 
 
@@ -491,14 +630,14 @@ def __check_is_fit_petri_net(trace, net, im, fm, activity_key=xes_constants.DEFA
     else:
         log = EventLog()
         log.append(trace)
-        tbr_conf_res = conformance_diagnostics_token_based_replay(log, net, im, fm)[0]
+        tbr_conf_res = conformance_diagnostics_token_based_replay(log, net, im, fm, return_diagnostics_dataframe=False)[0]
         # CHECK 2) if TBR says that is fit, then return True
         # (if they say False, it might be a false negative)
         if tbr_conf_res["trace_is_fit"]:
             return True
         else:
             # CHECK 3) alignments definitely say if the trace is fit or not if the previous methods fail
-            align_conf_res = conformance_diagnostics_alignments(log, net, im, fm)[0]
+            align_conf_res = conformance_diagnostics_alignments(log, net, im, fm, return_diagnostics_dataframe=False)[0]
             return align_conf_res["fitness"] == 1.0
 
 
@@ -534,7 +673,7 @@ def check_is_fitting(*args, activity_key=xes_constants.DEFAULT_NAME_KEY) -> bool
         return __check_is_fit_petri_net(trace, model[0], model[1], model[2], activity_key=activity_key)
 
 
-def conformance_temporal_profile(log: Union[EventLog, pd.DataFrame], temporal_profile: Dict[Tuple[str, str], Tuple[float, float]], zeta: float = 1.0, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> List[List[Tuple[float, float, float, float]]]:
+def conformance_temporal_profile(log: Union[EventLog, pd.DataFrame], temporal_profile: Dict[Tuple[str, str], Tuple[float, float]], zeta: float = 1.0, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name", return_diagnostics_dataframe: bool = constants.DEFAULT_RETURN_DIAGNOSTICS_DATAFRAME) -> List[List[Tuple[float, float, float, float]]]:
     """
     Performs conformance checking on the provided log with the provided temporal profile.
     The result is a list of time-based deviations for every case.
@@ -551,6 +690,7 @@ def conformance_temporal_profile(log: Union[EventLog, pd.DataFrame], temporal_pr
     :param activity_key: attribute to be used for the activity
     :param timestamp_key: attribute to be used for the timestamp
     :param case_id_key: attribute to be used as case identifier
+    :param return_diagnostics_dataframe: if possible, returns a dataframe with the diagnostics (instead of the usual output)
     :rtype: ``List[List[Tuple[float, float, float, float]]]``
 
     .. code-block:: python3
@@ -560,7 +700,6 @@ def conformance_temporal_profile(log: Union[EventLog, pd.DataFrame], temporal_pr
         temporal_profile = pm4py.discover_temporal_profile(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
         conformance_temporal_profile = pm4py.conformance_temporal_profile(dataframe, temporal_profile, zeta=1, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     if check_is_pandas_dataframe(log):
@@ -570,10 +709,59 @@ def conformance_temporal_profile(log: Union[EventLog, pd.DataFrame], temporal_pr
     properties["zeta"] = zeta
 
     from pm4py.algo.conformance.temporal_profile import algorithm as temporal_profile_conformance
-    return temporal_profile_conformance.apply(log, temporal_profile, parameters=properties)
+    result = temporal_profile_conformance.apply(log, temporal_profile, parameters=properties)
+
+    if return_diagnostics_dataframe:
+        return temporal_profile_conformance.get_diagnostics_dataframe(log, result, parameters=properties)
+
+    return result
 
 
-def conformance_log_skeleton(log: Union[EventLog, pd.DataFrame], log_skeleton: Dict[str, Any], activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> List[Set[Any]]:
+def conformance_declare(log: Union[EventLog, pd.DataFrame], declare_model: Dict[str, Dict[Any, Dict[str, int]]], activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name", return_diagnostics_dataframe: bool = constants.DEFAULT_RETURN_DIAGNOSTICS_DATAFRAME) -> List[Dict[str, Any]]:
+    """
+    Applies conformance checking against a DECLARE model.
+
+    Reference paper:
+    F. M. Maggi, A. J. Mooij and W. M. P. van der Aalst, "User-guided discovery of declarative process models," 2011 IEEE Symposium on Computational Intelligence and Data Mining (CIDM), Paris, France, 2011, pp. 192-199, doi: 10.1109/CIDM.2011.5949297.
+
+    :param log: event log
+    :param declare_model: DECLARE model
+    :param activity_key: attribute to be used for the activity
+    :param timestamp_key: attribute to be used for the timestamp
+    :param case_id_key: attribute to be used as case identifier
+    :param return_diagnostics_dataframe: if possible, returns a dataframe with the diagnostics (instead of the usual output)
+    :rtype: ``List[Dict[str, Any]]``
+
+    .. code-block:: python3
+
+        import pm4py
+
+        log = pm4py.read_xes("C:/receipt.xes")
+        declare_model = pm4py.discover_declare(log)
+        conf_result = pm4py.conformance_declare(log, declare_model)
+    """
+    __event_log_deprecation_warning(log)
+
+    if check_is_pandas_dataframe(log):
+        check_pandas_dataframe_columns(log, activity_key=activity_key, timestamp_key=timestamp_key,
+                                       case_id_key=case_id_key)
+
+    if return_diagnostics_dataframe:
+        log = convert_to_event_log(log, case_id_key=case_id_key)
+        case_id_key = None
+
+    properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
+
+    from pm4py.algo.conformance.declare import algorithm as declare_conformance
+    result = declare_conformance.apply(log, declare_model, parameters=properties)
+
+    if return_diagnostics_dataframe:
+        return declare_conformance.get_diagnostics_dataframe(log, result, parameters=properties)
+
+    return result
+
+
+def conformance_log_skeleton(log: Union[EventLog, pd.DataFrame], log_skeleton: Dict[str, Any], activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name", return_diagnostics_dataframe: bool = constants.DEFAULT_RETURN_DIAGNOSTICS_DATAFRAME) -> List[Set[Any]]:
     """
     Performs conformance checking using the log skeleton
 
@@ -602,6 +790,7 @@ def conformance_log_skeleton(log: Union[EventLog, pd.DataFrame], log_skeleton: D
     :param activity_key: attribute to be used for the activity
     :param timestamp_key: attribute to be used for the timestamp
     :param case_id_key: attribute to be used as case identifier
+    :param return_diagnostics_dataframe: if possible, returns a dataframe with the diagnostics (instead of the usual output)
     :rtype: ``List[Set[Any]]``
 
     .. code-block:: python3
@@ -611,13 +800,21 @@ def conformance_log_skeleton(log: Union[EventLog, pd.DataFrame], log_skeleton: D
         log_skeleton = pm4py.discover_log_skeleton(dataframe, noise_threshold=0.1, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
         conformance_lsk = pm4py.conformance_log_skeleton(dataframe, log_skeleton, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
 
+    if return_diagnostics_dataframe:
+        log = convert_to_event_log(log, case_id_key=case_id_key)
+        case_id_key = None
+
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
 
     from pm4py.algo.conformance.log_skeleton import algorithm as log_skeleton_conformance
-    return log_skeleton_conformance.apply(log, log_skeleton, parameters=properties)
+    result = log_skeleton_conformance.apply(log, log_skeleton, parameters=properties)
+
+    if return_diagnostics_dataframe:
+        return log_skeleton_conformance.get_diagnostics_dataframe(log, result, parameters=properties)
+
+    return result
