@@ -18,14 +18,13 @@ __doc__ = """
 The ``pm4py.filtering`` module contains the filtering features offered in ``pm4py``
 """
 
-import warnings
-from typing import List, Union, Set, List, Tuple, Collection, Any, Dict, Optional
+from typing import Union, Set, List, Tuple, Collection, Any, Dict, Optional
 
 import pandas as pd
 
-from pm4py.meta import VERSION as PM4PY_CURRENT_VERSION
 from pm4py.objects.log.obj import EventLog, EventStream
-from pm4py.util import constants, xes_constants
+from pm4py.util import constants, xes_constants, pandas_utils, nx_utils
+import warnings
 from pm4py.util.pandas_utils import check_is_pandas_dataframe, check_pandas_dataframe_columns
 from pm4py.utils import get_properties, __event_log_deprecation_warning
 from pm4py.objects.ocel.obj import OCEL
@@ -52,7 +51,6 @@ def filter_log_relative_occurrence_event_attribute(log: Union[EventLog, pd.DataF
 
         filtered_dataframe = pm4py.filter_log_relative_occurrence_event_attribute(dataframe, 0.5, level='cases', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, timestamp_key=timestamp_key, case_id_key=case_id_key, activity_key=attribute_key)
@@ -88,7 +86,6 @@ Union[EventLog, pd.DataFrame]:
 
         filtered_dataframe = pm4py.filter_start_activities(dataframe, ['Act. A'], activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -124,7 +121,6 @@ def filter_end_activities(log: Union[EventLog, pd.DataFrame], activities:  Union
 
         filtered_dataframe = pm4py.filter_end_activities(dataframe, ['Act. Z'], activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -160,7 +156,6 @@ def filter_event_attribute_values(log: Union[EventLog, pd.DataFrame], attribute_
 
         filtered_dataframe = pm4py.filter_event_attribute_values(dataframe, 'concept:name', ['Act. A', 'Act. Z'], case_id_key='case:concept:name')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, case_id_key=case_id_key)
@@ -204,7 +199,6 @@ def filter_trace_attribute_values(log: Union[EventLog, pd.DataFrame], attribute_
 
         filtered_dataframe = pm4py.filter_trace_attribute_values(dataframe, 'case:creator', ['Mike'], case_id_key='case:concept:name')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, case_id_key=case_id_key)
@@ -221,7 +215,7 @@ def filter_trace_attribute_values(log: Union[EventLog, pd.DataFrame], attribute_
         return attributes_filter.apply_trace_attribute(log, values, parameters=parameters)
 
 
-def filter_variants(log: Union[EventLog, pd.DataFrame], variants:  Union[Set[str], List[str]], retain: bool = True, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> Union[
+def filter_variants(log: Union[EventLog, pd.DataFrame], variants:  Union[Set[str], List[str], List[Tuple[str]]], retain: bool = True, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> Union[
     EventLog, pd.DataFrame]:
     """
     Filter a log on a specified set of variants
@@ -240,7 +234,6 @@ def filter_variants(log: Union[EventLog, pd.DataFrame], variants:  Union[Set[str
 
         filtered_dataframe = pm4py.filter_variants(dataframe, [('Act. A', 'Act. B', 'Act. Z'), ('Act. A', 'Act. C', 'Act. Z')], activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     from pm4py.util import variants_util
@@ -279,7 +272,6 @@ def filter_directly_follows_relation(log: Union[EventLog, pd.DataFrame], relatio
 
         filtered_dataframe = pm4py.filter_directly_follows_relation(dataframe, [('A','B'),('A','C')], activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -323,11 +315,11 @@ def filter_eventually_follows_relation(log: Union[EventLog, pd.DataFrame], relat
         if retain:
             cases = set()
         else:
-            cases = set(log[case_id_key])
+            cases = set(log[case_id_key].to_numpy().tolist())
         for path in relations:
             filt_log = ltl_checker.eventually_follows(log, path,
                                                       parameters=parameters)
-            this_traces = set(filt_log[case_id_key])
+            this_traces = set(filt_log[case_id_key].to_numpy().tolist())
             if retain:
                 cases = cases.union(this_traces)
             else:
@@ -377,7 +369,6 @@ def filter_time_range(log: Union[EventLog, pd.DataFrame], dt1: str, dt2: str, mo
         filtered_dataframe1 = pm4py.filter_time_range(dataframe, '2010-01-01 00:00:00', '2011-01-01 00:00:00', mode='traces_intersecting', case_id_key='case:concept:name', timestamp_key='time:timestamp')
         filtered_dataframe1 = pm4py.filter_time_range(dataframe, '2010-01-01 00:00:00', '2011-01-01 00:00:00', mode='events', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     properties = get_properties(log, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -390,7 +381,8 @@ def filter_time_range(log: Union[EventLog, pd.DataFrame], dt1: str, dt2: str, mo
         elif mode == "traces_intersecting":
             return timestamp_filter.filter_traces_intersecting(log, dt1, dt2, parameters=properties)
         else:
-            warnings.warn('mode provided: ' + mode + ' is not recognized; original log returned!')
+            if constants.SHOW_INTERNAL_WARNINGS:
+                warnings.warn('mode provided: ' + mode + ' is not recognized; original log returned!')
             return log
     else:
         from pm4py.algo.filtering.log.timestamp import timestamp_filter
@@ -401,7 +393,8 @@ def filter_time_range(log: Union[EventLog, pd.DataFrame], dt1: str, dt2: str, mo
         elif mode == "traces_intersecting":
             return timestamp_filter.filter_traces_intersecting(log, dt1, dt2, parameters=properties)
         else:
-            warnings.warn('mode provided: ' + mode + ' is not recognized; original log returned!')
+            if constants.SHOW_INTERNAL_WARNINGS:
+                warnings.warn('mode provided: ' + mode + ' is not recognized; original log returned!')
             return log
 
 
@@ -441,7 +434,6 @@ def filter_between(log: Union[EventLog, pd.DataFrame], act1: str, act2: str, act
 
         filtered_dataframe = pm4py.filter_between(dataframe, 'A', 'D', activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -471,7 +463,6 @@ def filter_case_size(log: Union[EventLog, pd.DataFrame], min_size: int, max_size
 
         filtered_dataframe = pm4py.filter_case_size(dataframe, 5, 10, case_id_key='case:concept:name')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, case_id_key=case_id_key)
@@ -504,7 +495,6 @@ def filter_case_performance(log: Union[EventLog, pd.DataFrame], min_performance:
 
         filtered_dataframe = pm4py.filter_case_performance(dataframe, 3600.0, 86400.0, timestamp_key='time:timestamp', case_id_key='case:concept:name')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -535,7 +525,6 @@ def filter_activities_rework(log: Union[EventLog, pd.DataFrame], activity: str,
 
         filtered_dataframe = pm4py.filter_activities_rework(dataframe, 'Approve Order', 2, activity_key='concept:name', timestamp_key='time:timestamp', case_id_key='case:concept:name')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -571,7 +560,6 @@ def filter_paths_performance(log: Union[EventLog, pd.DataFrame], path: Tuple[str
 
         filtered_dataframe = pm4py.filter_paths_performance(dataframe, ('A', 'D'), 3600.0, 86400.0, activity_key='concept:name', timestamp_key='time:timestamp', case_id_key='case:concept:name')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -605,7 +593,6 @@ def filter_variants_top_k(log: Union[EventLog, pd.DataFrame], k: int, activity_k
 
         filtered_dataframe = pm4py.filter_variants_top_k(dataframe, 5, activity_key='concept:name', timestamp_key='time:timestamp', case_id_key='case:concept:name')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -638,7 +625,6 @@ def filter_variants_by_coverage_percentage(log: Union[EventLog, pd.DataFrame], m
 
         filtered_dataframe = pm4py.filter_variants_by_coverage_percentage(dataframe, 0.1, activity_key='concept:name', timestamp_key='time:timestamp', case_id_key='case:concept:name')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -651,6 +637,39 @@ def filter_variants_by_coverage_percentage(log: Union[EventLog, pd.DataFrame], m
         return variants_filter.filter_variants_by_coverage_percentage(log, min_coverage_percentage, parameters=parameters)
 
 
+def filter_variants_by_maximum_coverage_percentage(log: Union[EventLog, pd.DataFrame], max_coverage_percentage: float, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> Union[EventLog, pd.DataFrame]:
+    """
+    Filters the variants of the log by a maximum coverage percentage
+    (e.g., if max_coverage_percentage=0.4, and we have a log with 1000 cases,
+    of which 500 of the variant 1, 400 of the variant 2, and 100 of the variant 3,
+    the filter keeps only the traces of variant 2 and variant 3).
+
+    :param log: event log / Pandas dataframe
+    :param max_coverage_percentage: maximum allowed percentage of coverage
+    :param activity_key: attribute to be used for the activity
+    :param timestamp_key: attribute to be used for the timestamp
+    :param case_id_key: attribute to be used as case identifier
+    :rtype: ``Union[EventLog, pd.DataFrame]``
+
+    .. code-block:: python3
+
+        import pm4py
+
+        filtered_dataframe = pm4py.filter_variants_by_maximum_coverage_percentage(dataframe, 0.1, activity_key='concept:name', timestamp_key='time:timestamp', case_id_key='case:concept:name')
+    """
+    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+    __event_log_deprecation_warning(log)
+
+    parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
+    if check_is_pandas_dataframe(log):
+        check_pandas_dataframe_columns(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
+        from pm4py.algo.filtering.pandas.variants import variants_filter
+        return variants_filter.filter_variants_by_maximum_coverage_percentage(log, max_coverage_percentage, parameters=parameters)
+    else:
+        from pm4py.algo.filtering.log.variants import variants_filter
+        return variants_filter.filter_variants_by_maximum_coverage_percentage(log, max_coverage_percentage, parameters=parameters)
+
+
 def filter_prefixes(log: Union[EventLog, pd.DataFrame], activity: str, strict=True, first_or_last="first", activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> Union[EventLog, pd.DataFrame]:
     """
     Filters the log, keeping the prefixes to a given activity. E.g., for a log with traces:
@@ -680,7 +699,6 @@ def filter_prefixes(log: Union[EventLog, pd.DataFrame], activity: str, strict=Tr
 
         filtered_dataframe = pm4py.filter_prefixes(dataframe, 'Act. C', activity_key='concept:name', timestamp_key='time:timestamp', case_id_key='case:concept:name')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -725,7 +743,6 @@ def filter_suffixes(log: Union[EventLog, pd.DataFrame], activity: str, strict=Tr
 
         filtered_dataframe = pm4py.filter_prefixes(dataframe, 'Act. C', activity_key='concept:name', timestamp_key='time:timestamp', case_id_key='case:concept:name')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -909,7 +926,6 @@ def filter_four_eyes_principle(log: Union[EventLog, pd.DataFrame], activity1: st
 
         filtered_dataframe = pm4py.filter_four_eyes_principle(dataframe, 'Act. A', 'Act. B', activity_key='concept:name', resource_key='org:resource', timestamp_key='time:timestamp', case_id_key='case:concept:name')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key, resource_key=resource_key)
@@ -943,7 +959,6 @@ def filter_activity_done_different_resources(log: Union[EventLog, pd.DataFrame],
 
         filtered_dataframe = pm4py.filter_activity_done_different_resources(dataframe, 'Act. A', activity_key='concept:name', resource_key='org:resource', timestamp_key='time:timestamp', case_id_key='case:concept:name')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key, resource_key=resource_key)
@@ -958,6 +973,52 @@ def filter_activity_done_different_resources(log: Union[EventLog, pd.DataFrame],
         return ltl_checker.attr_value_different_persons(log, activity, parameters=properties)
 
 
+def filter_trace_segments(log: Union[EventLog, pd.DataFrame], admitted_traces: List[List[str]], positive: bool = True, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> Union[EventLog, pd.DataFrame]:
+    """
+    Filters an event log on a set of traces. A trace is a sequence of activities and "...", in which:
+    - a "..." before an activity tells that other activities can precede the given activity
+    - a "..." after an activity tells that other activities can follow the given activity
+
+    For example:
+    - pm4py.filter_trace_segments(log, [["A", "B"]]) <- filters only the cases of the event log having exactly the process variant A,B
+    - pm4py.filter_trace_segments(log, [["...", "A", "B"]]) <- filters only the cases of the event log ending with the activities A,B
+    - pm4py.filter_trace_segments(log, [["A", "B", "..."]]) <- filters only the cases of the event log starting with the activities A,B
+    - pm4py.filter_trace_segments(log, [["...", "A", "B", "C", "..."], ["...", "D", "E", "F", "..."]]
+                                <- filters only the cases of the event log in which at any point
+                                    there is A followed by B followed by C, and in which at any other point there is
+                                    D followed by E followed by F
+
+    :param log: event log / Pandas dataframe
+    :param admitted_traces: collection of traces admitted from the filter (with the aforementioned criteria)
+    :param positive: (boolean) indicates if the filter should keep/discard the cases satisfying the filter
+    :param activity_key: attribute to be used for the activity
+    :param timestamp_key: attribute to be used for the timestamp
+    :param case_id_key: attribute to be used as case identifier
+    :rtype: ``Union[EventLog, pd.DataFrame]``
+
+    .. code-block:: python3
+
+        import pm4py
+
+        log = pm4py.read_xes("tests/input_data/running-example.xes")
+
+        filtered_log = pm4py.filter_trace_segments(log, [["...", "check ticket", "decide", "reinitiate request", "..."]])
+        print(filtered_log)
+    """
+    __event_log_deprecation_warning(log)
+
+    parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
+    parameters["positive"] = positive
+
+    if check_is_pandas_dataframe(log):
+        check_pandas_dataframe_columns(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
+        from pm4py.algo.filtering.pandas.traces import trace_filter
+        return trace_filter.apply(log, admitted_traces, parameters=parameters)
+    else:
+        from pm4py.algo.filtering.log.traces import trace_filter
+        return trace_filter.apply(log, admitted_traces, parameters=parameters)
+
+
 def filter_ocel_object_types(ocel: OCEL, obj_types: Collection[str], positive: bool = True, level: int = 1) -> OCEL:
     """
     Filters the object types of an object-centric event log.
@@ -986,7 +1047,7 @@ def filter_ocel_object_types(ocel: OCEL, obj_types: Collection[str], positive: b
             filtered_ocel.objects = filtered_ocel.objects[~filtered_ocel.objects[filtered_ocel.object_type_column].isin(obj_types)]
         return filtering_utils.propagate_object_filtering(filtered_ocel)
     else:
-        object_ids = ocel.objects[ocel.objects[ocel.object_type_column].isin(obj_types)][ocel.object_id_column].unique()
+        object_ids = pandas_utils.format_unique(ocel.objects[ocel.objects[ocel.object_type_column].isin(obj_types)][ocel.object_id_column].unique())
         return filter_ocel_objects(ocel, object_ids, level=level, positive=positive)
 
 
@@ -1009,8 +1070,8 @@ def filter_ocel_objects(ocel: OCEL, object_identifiers: Collection[str], positiv
     """
     object_identifiers = set(object_identifiers)
     if level > 1:
-        ev_rel_obj = ocel.relations.groupby(ocel.event_id_column)[ocel.object_id_column].apply(list).to_dict()
-        objects_ids = set(ocel.objects[ocel.object_id_column].unique())
+        ev_rel_obj = ocel.relations.groupby(ocel.event_id_column)[ocel.object_id_column].agg(list).to_dict()
+        objects_ids = ocel.objects[ocel.object_id_column].to_numpy().tolist()
         graph = {o: set() for o in objects_ids}
         for ev in ev_rel_obj:
             rel_obj = ev_rel_obj[ev]
@@ -1060,14 +1121,16 @@ def filter_ocel_events(ocel: OCEL, event_identifiers: Collection[str], positive:
     return filtering_utils.propagate_event_filtering(filtered_ocel)
 
 
-def filter_ocel_cc_object(ocel: OCEL, object_id: str) -> OCEL:
+def filter_ocel_cc_object(ocel: OCEL, object_id: str, conn_comp: Optional[List[List[str]]] = None, return_conn_comp: bool = False) -> Union[OCEL, Tuple[OCEL, List[List[str]]]]:
     """
     Returns the connected component of the object-centric event log
     to which the object with the provided identifier belongs.
 
     :param ocel: object-centric event log
     :param object_id: object identifier
-    :rtype: ``OCEL``
+    :param conn_comp: (optional) connected components of the objects of the OCEL
+    :param return_conn_comp: if True, returns the computed connected components of the OCEL
+    :rtype: ``Union[OCEL, Tuple[OCEL, List[List[str]]]]``
 
     .. code-block:: python3
 
@@ -1076,8 +1139,139 @@ def filter_ocel_cc_object(ocel: OCEL, object_id: str) -> OCEL:
         ocel = pm4py.read_ocel('log.jsonocel')
         filtered_ocel = pm4py.filter_ocel_cc_object(ocel, 'order1')
     """
-    from pm4py.algo.transformation.ocel.split_ocel import algorithm
-    ocel_splits = algorithm.apply(ocel)
-    for cc in ocel_splits:
-        if object_id in cc.objects[ocel.object_id_column].unique():
-            return cc
+    if conn_comp is None:
+        from pm4py.algo.transformation.ocel.graphs import object_interaction_graph
+
+        g0 = object_interaction_graph.apply(ocel)
+        g = nx_utils.Graph()
+
+        for edge in g0:
+            g.add_edge(edge[0], edge[1])
+
+        conn_comp = list(nx_utils.connected_components(g))
+
+    for cc in conn_comp:
+        if object_id in cc:
+            if return_conn_comp:
+                return filter_ocel_objects(ocel, cc), conn_comp
+            else:
+                return filter_ocel_objects(ocel, cc)
+
+    if return_conn_comp:
+        return filter_ocel_objects(ocel, [object_id]), conn_comp
+    else:
+        return filter_ocel_objects(ocel, [object_id])
+
+
+def filter_ocel_cc_length(ocel: OCEL, min_cc_length: int, max_cc_length: int) -> OCEL:
+    """
+    Keeps only the objects in an OCEL belonging to a connected component with a length
+    falling in a specified range
+
+    Paper:
+    Adams, Jan Niklas, et al. "Defining cases and variants for object-centric event data." 2022 4th International Conference on Process Mining (ICPM). IEEE, 2022.
+
+    :param ocel: object-centric event log
+    :param min_cc_length: minimum allowed length for the connected component
+    :param max_cc_length: maximum allowed length for the connected component
+    :rtype: ``OCEL``
+
+    .. code-block:: python3
+
+        import pm4py
+
+        ocel = pm4py.read_ocel('log.jsonocel')
+        filtered_ocel = pm4py.filter_ocel_cc_length(ocel, 2, 10)
+    """
+    from pm4py.algo.transformation.ocel.graphs import object_interaction_graph
+
+    g0 = object_interaction_graph.apply(ocel)
+    g = nx_utils.Graph()
+
+    for edge in g0:
+        g.add_edge(edge[0], edge[1])
+
+    conn_comp = list(nx_utils.connected_components(g))
+    conn_comp = [x for x in conn_comp if min_cc_length <= len(x) <= max_cc_length]
+    objs = [y for x in conn_comp for y in x]
+
+    return filter_ocel_objects(ocel, objs)
+
+
+def filter_ocel_cc_otype(ocel: OCEL, otype: str, positive: bool = True) -> OCEL:
+    """
+    Filters the objects belonging to the connected components having at least an object
+    of the provided object type.
+
+    Paper:
+    Adams, Jan Niklas, et al. "Defining cases and variants for object-centric event data." 2022 4th International Conference on Process Mining (ICPM). IEEE, 2022.
+
+    :param ocel: object-centric event log
+    :param otype: object type
+    :param positive: boolean that keeps or discards the objects of these components
+    :rtype: ``OCEL``
+
+    .. code-block:: python3
+
+        import pm4py
+
+        ocel = pm4py.read_ocel('log.jsonocel')
+        filtered_ocel = pm4py.filter_ocel_cc_otype(ocel, 'order')
+    """
+    if positive:
+        objs = set(ocel.objects[ocel.objects[ocel.object_type_column] == otype][ocel.object_id_column])
+    else:
+        objs = set(ocel.objects[~(ocel.objects[ocel.object_type_column] == otype)][ocel.object_id_column])
+
+    from pm4py.algo.transformation.ocel.graphs import object_interaction_graph
+
+    g0 = object_interaction_graph.apply(ocel)
+    g = nx_utils.Graph()
+
+    for edge in g0:
+        g.add_edge(edge[0], edge[1])
+
+    conn_comp = list(nx_utils.connected_components(g))
+    conn_comp = [x for x in conn_comp if len(set(x).intersection(objs)) > 0]
+
+    objs = [y for x in conn_comp for y in x]
+
+    return filter_ocel_objects(ocel, objs)
+
+
+def filter_ocel_cc_activity(ocel: OCEL, activity: str) -> OCEL:
+    """
+    Filters the objects belonging to the connected components having at least an event
+    with the provided activity.
+
+    Paper:
+    Adams, Jan Niklas, et al. "Defining cases and variants for object-centric event data." 2022 4th International Conference on Process Mining (ICPM). IEEE, 2022.
+
+    :param ocel: object-centric event log
+    :param activity: activity
+    :rtype: ``OCEL``
+
+    .. code-block:: python3
+
+        import pm4py
+
+        ocel = pm4py.read_ocel('log.jsonocel')
+        filtered_ocel = pm4py.filter_ocel_cc_activity(ocel, 'Create Order')
+    """
+    evs = ocel.events[ocel.events[ocel.event_activity] == activity][ocel.event_id_column].to_numpy().tolist()
+    objs = pandas_utils.format_unique(ocel.relations[ocel.relations[ocel.event_id_column].isin(evs)][ocel.object_id_column].unique())
+
+    from pm4py.algo.transformation.ocel.graphs import object_interaction_graph
+
+    g0 = object_interaction_graph.apply(ocel)
+    g = nx_utils.Graph()
+
+    for edge in g0:
+        g.add_edge(edge[0], edge[1])
+
+    conn_comp = list(nx_utils.connected_components(g))
+    conn_comp = [x for x in conn_comp if len(set(x).intersection(objs)) > 0]
+
+    objs = [y for x in conn_comp for y in x]
+
+    return filter_ocel_objects(ocel, objs)
