@@ -14,11 +14,12 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
+
 __name__ = 'pm4py'
-VERSION = '2.7.1'
+VERSION = '2.7.11'
 __version__ = VERSION
 __doc__ = 'Process mining for Python'
-__author__ = 'Fraunhofer Institute for Applied Technology'
+__author__ = 'Fraunhofer Institute for Applied Information Technology FIT'
 __author_email__ = 'pm4py@fit.fraunhofer.de'
-__maintainer__ = 'Fraunhofer Institute for Applied Technology'
+__maintainer__ = 'Fraunhofer Institute for Applied Information Technology FIT'
 __maintainer_email__ = "pm4py@fit.fraunhofer.de"
