@@ -20,9 +20,9 @@ The ``pm4py.ml`` module contains the machine learning features offered in ``pm4p
 
 from typing import Union, Tuple, Any, List, Collection, Optional
 import pandas as pd
+import numpy as np
 from pm4py.objects.ocel.obj import OCEL
 from pm4py.objects.log.obj import EventLog, EventStream
-from pm4py.util import constants
 from pm4py.objects.conversion.log import converter as log_converter
 from pm4py.utils import __event_log_deprecation_warning
 import random
@@ -47,12 +47,11 @@ def split_train_test(log: Union[EventLog, pd.DataFrame], train_percentage: float
 
         train_df, test_df = pm4py.split_train_test(dataframe, train_percentage=0.75)
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
-        cases = set(log[case_id_key].unique())
+        cases = pandas_utils.format_unique(log[case_id_key].unique())
         train_cases = set()
         test_cases = set()
         for c in cases:
@@ -86,7 +85,6 @@ def get_prefixes_from_log(log: Union[EventLog, pd.DataFrame], length: int, case_
 
         trimmed_df = pm4py.get_prefixes_from_log(dataframe, length=5, case_id_key='case:concept:name')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     if check_is_pandas_dataframe(log):
@@ -120,8 +118,6 @@ def extract_outcome_enriched_dataframe(log: Union[EventLog, pd.DataFrame], activ
         enriched_df = pm4py.extract_outcome_enriched_dataframe(log, activity_key='concept:name', timestamp_key='time:timestamp', case_id_key='case:concept:name', start_timestamp_key='time:timestamp')
 
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception(
-        "the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     properties = get_properties(log, activity_key=activity_key, case_id_key=case_id_key, timestamp_key=timestamp_key)
@@ -130,14 +126,14 @@ def extract_outcome_enriched_dataframe(log: Union[EventLog, pd.DataFrame], activ
 
     from pm4py.util import pandas_utils
 
-    fea_df = extract_features_dataframe(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
+    fea_df = extract_features_dataframe(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key, include_case_id=True)
     log2 = pandas_utils.insert_case_arrival_finish_rate(log.copy(), timestamp_column=timestamp_key, case_id_column=case_id_key, start_timestamp_column=start_timestamp_key)
     log2 = pandas_utils.insert_case_service_waiting_time(log2.copy(), timestamp_column=timestamp_key, case_id_column=case_id_key, start_timestamp_column=start_timestamp_key)
 
     return log2.merge(fea_df, left_on=case_id_key, right_on=case_id_key)
 
 
-def extract_features_dataframe(log: Union[EventLog, pd.DataFrame], str_tr_attr=None, num_tr_attr=None, str_ev_attr=None, num_ev_attr=None, str_evsucc_attr=None, activity_key="concept:name", timestamp_key="time:timestamp", case_id_key="case:concept:name", resource_key="org:resource", **kwargs) -> pd.DataFrame:
+def extract_features_dataframe(log: Union[EventLog, pd.DataFrame], str_tr_attr=None, num_tr_attr=None, str_ev_attr=None, num_ev_attr=None, str_evsucc_attr=None, activity_key="concept:name", timestamp_key="time:timestamp", case_id_key=None, resource_key="org:resource", include_case_id: bool = False, **kwargs) -> pd.DataFrame:
     """
     Extracts a dataframe containing the features of each case of the provided log object
 
@@ -148,8 +144,9 @@ def extract_features_dataframe(log: Union[EventLog, pd.DataFrame], str_tr_attr=N
     :param num_ev_attr: (if provided) numeric attributes at the event level which should be extracted as features (last value per attribute in a case)
     :param activity_key: the attribute to be used as activity
     :param timestamp_key: the attribute to be used as timestamp
-    :param case_id_key: the attribute to be used as case identifier
+    :param case_id_key: (if provided, otherwise default) the attribute to be used as case identifier
     :param resource_key: the attribute to be used as resource
+    :param include_case_id: includes the case identifier column in the features table
     :rtype: ``pd.DataFrame``
 
     .. code-block:: python3
@@ -158,7 +155,6 @@ def extract_features_dataframe(log: Union[EventLog, pd.DataFrame], str_tr_attr=N
 
         features_df = pm4py.extract_features_dataframe(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = {}
@@ -174,6 +170,7 @@ def extract_features_dataframe(log: Union[EventLog, pd.DataFrame], str_tr_attr=N
     parameters["str_ev_attr"] = str_ev_attr
     parameters["num_ev_attr"] = num_ev_attr
     parameters["str_evsucc_attr"] = str_evsucc_attr
+    parameters["add_case_identifier_column"] = include_case_id
 
     from pm4py.algo.transformation.log_to_features import algorithm as log_to_features
 
@@ -182,7 +179,7 @@ def extract_features_dataframe(log: Union[EventLog, pd.DataFrame], str_tr_attr=N
 
     data, feature_names = log_to_features.apply(log, parameters=parameters)
 
-    return pd.DataFrame(data, columns=feature_names)
+    return pandas_utils.instantiate_dataframe(data, columns=feature_names)
 
 
 def extract_ocel_features(ocel: OCEL, obj_type: str, enable_object_lifecycle_paths: bool = True, enable_object_work_in_progress: bool = False, object_str_attributes: Optional[Collection[str]] = None, object_num_attributes: Optional[Collection[str]] = None, include_obj_id: bool = False, debug: bool = False) -> pd.DataFrame:
@@ -190,6 +187,9 @@ def extract_ocel_features(ocel: OCEL, obj_type: str, enable_object_lifecycle_pat
     Extracts from an object-centric event log a set of features (returned as dataframe) computed on the OCEL
     for the objects of a given object type.
 
+    Implements the approach described in:
+    Berti, A., Herforth, J., Qafari, M.S. et al. Graph-based feature extraction on object-centric event logs. Int J Data Sci Anal (2023). https://doi.org/10.1007/s41060-023-00428-2
+
     :param ocel: object-centric event log
     :param obj_type: object type that should be considered
     :param enable_object_lifecycle_paths: enables the "lifecycle paths" feature
@@ -227,7 +227,9 @@ def extract_ocel_features(ocel: OCEL, obj_type: str, enable_object_lifecycle_pat
 
     data, feature_names = ocel_feature_extraction.apply(ocel, parameters=parameters)
 
-    dataframe = pd.DataFrame(data, columns=feature_names)
+    dataframe = pandas_utils.instantiate_dataframe(data, columns=feature_names)
+    dataframe = dataframe.dropna(how="any", axis=1)
+    dataframe = dataframe.select_dtypes(include=np.number)
 
     if include_obj_id:
         objects_with_type = ocel.objects[[ocel.object_id_column, ocel.object_type_column]].to_dict("records")
@@ -237,19 +239,18 @@ def extract_ocel_features(ocel: OCEL, obj_type: str, enable_object_lifecycle_pat
     return dataframe
 
 
-def extract_temporal_features_dataframe(log: Union[EventLog, pd.DataFrame], grouper_freq="W", activity_key="concept:name", timestamp_key="time:timestamp", case_id_key="case:concept:name", start_timestamp_key="time:timestamp", resource_key="org:resource") -> pd.DataFrame:
+def extract_temporal_features_dataframe(log: Union[EventLog, pd.DataFrame], grouper_freq="W", activity_key="concept:name", timestamp_key="time:timestamp", case_id_key=None, start_timestamp_key="time:timestamp", resource_key="org:resource") -> pd.DataFrame:
     """
     Extracts a dataframe containing the temporal features of the provided log object
 
     Implements the approach described in the paper:
     Pourbafrani, Mahsa, Sebastiaan J. van Zelst, and Wil MP van der Aalst. "Supporting automatic system dynamics model generation for simulation in the context of process mining." International Conference on Business Information Systems. Springer, Cham, 2020.
 
-
     :param log: log object (event log / Pandas dataframe)
     :param grouper_freq: the grouping frequency (D, W, M, Y) to use
     :param activity_key: the attribute to be used as activity
     :param timestamp_key: the attribute to be used as timestamp
-    :param case_id_key: the attribute to be used as case identifier
+    :param case_id_key: (if provided, otherwise default) the attribute to be used as case identifier
     :param resource_key: the attribute to be used as resource
     :param start_timestamp_key: the attribute to be used as start timestamp
     :rtype: ``pd.DataFrame``
@@ -260,7 +261,6 @@ def extract_temporal_features_dataframe(log: Union[EventLog, pd.DataFrame], grou
 
         temporal_features_df = pm4py.extract_temporal_features_dataframe(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -270,7 +270,8 @@ def extract_temporal_features_dataframe(log: Union[EventLog, pd.DataFrame], grou
     parameters[temporal.Parameters.GROUPER_FREQ] = grouper_freq
     parameters[temporal.Parameters.ACTIVITY_COLUMN] = activity_key
     parameters[temporal.Parameters.TIMESTAMP_COLUMN] = timestamp_key
-    parameters[temporal.Parameters.CASE_ID_COLUMN] = case_id_key
+    if case_id_key is not None:
+        parameters[temporal.Parameters.CASE_ID_COLUMN] = case_id_key
     parameters[temporal.Parameters.START_TIMESTAMP_COLUMN] = start_timestamp_key
     parameters[temporal.Parameters.RESOURCE_COLUMN] = resource_key
 
@@ -298,7 +299,6 @@ def extract_target_vector(log: Union[EventLog, pd.DataFrame], variant: str, acti
         vector_rem_time, class_rem_time = pm4py.extract_target_vector(log, 'remaining_time', activity_key='concept:name', timestamp_key='time:timestamp', case_id_key='case:concept:name')
 
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
