@@ -17,9 +17,8 @@
 
 from enum import Enum
 from pm4py.objects.ocel.obj import OCEL
-import networkx as nx
 from typing import Optional, Dict, Any
-from pm4py.util import exec_utils
+from pm4py.util import exec_utils, nx_utils
 from pm4py.algo.transformation.ocel.graphs import object_interaction_graph, object_descendants_graph, object_inheritance_graph, object_cobirth_graph, object_codeath_graph
 
 
@@ -31,7 +30,7 @@ class Parameters(Enum):
     INCLUDE_OBJ_CODEATH_GRAPH = "include_obj_codeath_graph"
 
 
-def apply(ocel: OCEL, parameters: Optional[Dict[Any, Any]]=None) -> nx.DiGraph:
+def apply(ocel: OCEL, parameters: Optional[Dict[Any, Any]]=None):
     """
     Converts the graphs of features extracted from an OCEL to a NetworkX DiGraph object
 
@@ -61,7 +60,7 @@ def apply(ocel: OCEL, parameters: Optional[Dict[Any, Any]]=None) -> nx.DiGraph:
     include_obj_cobirth_graph = exec_utils.get_param_value(Parameters.INCLUDE_OBJ_COBIRTH_GRAPH, parameters, True)
     include_obj_codeath_graph = exec_utils.get_param_value(Parameters.INCLUDE_OBJ_CODEATH_GRAPH, parameters, True)
 
-    G = nx.DiGraph()
+    G = nx_utils.DiGraph()
     if include_obj_interaction_graph:
         interaction_graph = object_interaction_graph.apply(ocel, parameters=parameters)
         G.add_edges_from(interaction_graph, attr={"type": "INTERACTION"})
