@@ -251,7 +251,7 @@ def group_blocks_in_net(net, parameters=None):
     if parameters is None:
         parameters = {}
 
-    from pm4py.algo.analysis.workflow_net import evaluator as wf_eval
+    from pm4py.algo.analysis.workflow_net import algorithm as wf_eval
 
     if not wf_eval.apply(net):
         raise ValueError('The Petri net provided is not a WF-net')
@@ -301,7 +301,7 @@ def apply(net, im, fm, parameters=None):
 
     if len(grouped_net.transitions) == 1:
         pt_str = list(grouped_net.transitions)[0].label
-        pt = pt_util.parse(pt_str)
+        pt = pt_operator.ProcessTree(operator=None, label=pt_str)
         ret = pt_util.fold(pt) if fold else pt
         tree_sort(ret)
         return ret
