@@ -17,9 +17,6 @@
 from copy import deepcopy
 
 from pm4py.objects.dfg.utils import dfg_utils
-from pm4py.algo.filtering.dfg.dfg_filtering import clean_dfg_based_on_noise_thresh
-from pm4py.objects.heuristics_net import defaults
-from pm4py.objects.heuristics_net.node import Node
 
 DEFAULT_NET_NAME = ""
 
