@@ -14,10 +14,10 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-import pkgutil
 from enum import Enum
+from pm4py.util import constants
 
-from pm4py.objects.log.importer.xes.variants import iterparse, line_by_line, iterparse_mem_compressed, iterparse_20, chunk_regex
+from pm4py.objects.log.importer.xes.variants import iterparse, line_by_line, iterparse_mem_compressed, iterparse_20, chunk_regex, rustxes
 
 
 class Variants(Enum):
@@ -26,15 +26,33 @@ class Variants(Enum):
     ITERPARSE_MEM_COMPRESSED = iterparse_mem_compressed
     ITERPARSE_20 = iterparse_20
     CHUNK_REGEX = chunk_regex
+    RUSTXES = rustxes
 
 
-if pkgutil.find_loader("lxml"):
-    DEFAULT_VARIANT = Variants.ITERPARSE
-else:
-    DEFAULT_VARIANT = Variants.CHUNK_REGEX
+def __get_variant(variant_str: str):
+    variant = Variants.CHUNK_REGEX
+
+    if variant_str == 'nonstandard':
+        variant = Variants.LINE_BY_LINE
+    elif variant_str == 'iterparse':
+        variant = Variants.ITERPARSE
+    elif variant_str == 'lxml':
+        variant = Variants.ITERPARSE
+    elif variant_str == 'chunk_regex':
+        variant = Variants.CHUNK_REGEX
+    elif variant_str == "line_by_line":
+        variant = Variants.LINE_BY_LINE
+    elif variant_str == "iterparse_20":
+        variant = Variants.ITERPARSE_20
+    elif variant_str == "iterparse_mem_compressed":
+        variant = Variants.ITERPARSE_MEM_COMPRESSED
+    elif variant_str == "rustxes":
+        variant = Variants.RUSTXES
+
+    return variant
 
 
-def apply(path, parameters=None, variant=DEFAULT_VARIANT):
+def apply(path, parameters=None, variant=constants.DEFAULT_XES_PARSER):
     """
     Import a XES log into a EventLog object
 
@@ -59,22 +77,18 @@ def apply(path, parameters=None, variant=DEFAULT_VARIANT):
     log
         Trace log object
     """
-    if variant == 'nonstandard':
-        variant = Variants.LINE_BY_LINE
-    elif variant == 'iterparse':
-        variant = Variants.ITERPARSE
-    elif variant == 'chunk_regex':
-        variant = Variants.CHUNK_REGEX
+    if parameters is None:
+        parameters = {}
+
+    if type(variant) is str:
+        variant = __get_variant(variant)
 
     log = variant.value.apply(path, parameters=parameters)
 
     return log
 
-    #from pm4py.objects.conversion.log import converter as log_converter
-    #return log_converter.apply(log, variant=log_converter.Variants.TO_DATA_FRAME, parameters=parameters)
 
-
-def deserialize(log_string, parameters=None, variant=DEFAULT_VARIANT):
+def deserialize(log_string, parameters=None, variant=constants.DEFAULT_XES_PARSER):
     """
     Deserialize a text/binary string representing a XES log
 
@@ -102,4 +116,7 @@ def deserialize(log_string, parameters=None, variant=DEFAULT_VARIANT):
     if parameters is None:
         parameters = {}
 
+    if type(variant) is str:
+        variant = __get_variant(variant)
+
     return variant.value.import_from_string(log_string, parameters=parameters)
