@@ -25,6 +25,9 @@ from pm4py.util import constants
 from pm4py.util import exec_utils
 from pm4py.util import points_subset
 from pm4py.util import xes_constants, pandas_utils
+from pm4py.util.dt_parsing.variants import strpfromiso
+import numpy as np
+import traceback
 
 
 LEGACY_PARQUET_TP_REPLACER = "AAA"
@@ -47,6 +50,7 @@ class Parameters(Enum):
     INDEX_KEY = "index_key"
     CASE_INDEX_KEY = "case_index_key"
     USE_EXTREMES_TIMESTAMP = "use_extremes_timestamp"
+    ADD_CASE_IDENTIFIER_COLUMN = "add_case_identifier_column"
 
 
 def insert_partitioning(df, num_partitions, parameters=None):
@@ -167,18 +171,30 @@ def convert_timestamp_columns_in_df(df, timest_format=None, timest_columns=None)
         Dataframe with timestamp columns converted
 
     """
+    if timest_format is None:
+        timest_format = constants.DEFAULT_TIMESTAMP_PARSE_FORMAT
+
+    if timest_format is None:
+        timest_format = "mixed"
+
     for col in df.columns:
         if timest_columns is None or col in timest_columns:
             if "obj" in str(df[col].dtype) or "str" in str(df[col].dtype):
                 try:
-                    if timest_format is None:
-                        # makes operations faster if non-ISO8601 but anyhow regular dates are provided
-                        df[col] = pd.to_datetime(df[col], utc=True)
-                    else:
-                        df[col] = pd.to_datetime(df[col], utc=True, format=timest_format)
+                    df[col] = pandas_utils.dataframe_column_string_to_datetime(df[col], format=timest_format, utc=True)
                 except:
-                    # print("exception converting column: "+str(col))
-                    pass
+                    try:
+                        df[col] = pandas_utils.dataframe_column_string_to_datetime(df[col], format=timest_format, exact=False, utc=True)
+                    except:
+                        try:
+                            df[col] = pandas_utils.dataframe_column_string_to_datetime(df[col], format=timest_format)
+                        except:
+                            pass
+
+    for col in df.columns:
+        if "date" in str(df[col].dtype) or "time" in str(df[col].dtype):
+            df[col] = strpfromiso.fix_dataframe_column(df[col])
+
     return df
 
 
@@ -206,7 +222,7 @@ def sample_dataframe(df, parameters=None):
     case_id_key = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, constants.CASE_CONCEPT_NAME)
     max_no_cases = exec_utils.get_param_value(Parameters.MAX_NO_CASES, parameters, 100)
 
-    case_ids = list(df[case_id_key].unique())
+    case_ids = pandas_utils.format_unique(df[case_id_key].unique())
     case_id_to_retain = points_subset.pick_chosen_points_list(min(max_no_cases, len(case_ids)), case_ids)
 
     return df[df[case_id_key].isin(case_id_to_retain)]
@@ -295,6 +311,7 @@ def select_number_column(df: pd.DataFrame, fea_df: pd.DataFrame, col: str,
     """
     df = df.dropna(subset=[col]).groupby(case_id_key).last().reset_index()[[case_id_key, col]]
     fea_df = fea_df.merge(df, on=[case_id_key], how="left", suffixes=('', '_y'))
+    fea_df[col] = fea_df[col].astype(np.float32)
     return fea_df
 
 
@@ -319,13 +336,13 @@ def select_string_column(df: pd.DataFrame, fea_df: pd.DataFrame, col: str,
     fea_df
         Feature dataframe (desidered output)
     """
-    vals = df[col].unique()
+    vals = pandas_utils.format_unique(df[col].unique())
     for val in vals:
         if val is not None:
-            filt_df_cases = df[df[col] == val][case_id_key].unique()
+            filt_df_cases = pandas_utils.format_unique(df[df[col] == val][case_id_key].unique())
             new_col = col + "_" + val.encode('ascii', errors='ignore').decode('ascii').replace(" ", "")
             fea_df[new_col] = fea_df[case_id_key].isin(filt_df_cases)
-            fea_df[new_col] = fea_df[new_col].astype("int")
+            fea_df[new_col] = fea_df[new_col].astype(np.float32)
     return fea_df
 
 
@@ -353,14 +370,18 @@ def get_features_df(df: pd.DataFrame, list_columns: List[str],
         parameters = {}
 
     case_id_key = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, constants.CASE_CONCEPT_NAME)
+    add_case_identifier_column = exec_utils.get_param_value(Parameters.ADD_CASE_IDENTIFIER_COLUMN, parameters, False)
 
-    fea_df = pd.DataFrame({case_id_key: sorted(list(df[case_id_key].unique()))})
+    fea_df = pandas_utils.instantiate_dataframe({case_id_key: sorted(pandas_utils.format_unique(df[case_id_key].unique()))})
     for col in list_columns:
         if "obj" in str(df[col].dtype) or "str" in str(df[col].dtype):
             fea_df = select_string_column(df, fea_df, col, case_id_key=case_id_key)
         elif "float" in str(df[col].dtype) or "int" in str(df[col].dtype):
             fea_df = select_number_column(df, fea_df, col, case_id_key=case_id_key)
     fea_df = fea_df.sort_values(case_id_key)
+    if not add_case_identifier_column:
+        del fea_df[case_id_key]
+
     return fea_df
 
 
@@ -452,7 +473,7 @@ def insert_artificial_start_end(df0: pd.DataFrame, parameters: Optional[Dict[Any
     start_df[activity_key] = artificial_start_activity
     end_df[activity_key] = artificial_end_activity
 
-    df = pd.concat([start_df, df, end_df])
+    df = pandas_utils.concat([start_df, df, end_df])
     df = pandas_utils.insert_index(df, index_key)
     df = df.sort_values([case_id_key, timestamp_key, index_key])
 
