@@ -17,7 +17,8 @@
 
 from pm4py.objects.ocel.obj import OCEL
 from typing import Dict, Any, Optional
-import sqlite3
+from pm4py.objects.ocel.util import ocel_consistency
+import os
 
 
 def apply(ocel: OCEL, target_path: str, parameters: Optional[Dict[Any, Any]] = None):
@@ -36,6 +37,13 @@ def apply(ocel: OCEL, target_path: str, parameters: Optional[Dict[Any, Any]] = N
     if parameters is None:
         parameters = {}
 
+    import sqlite3
+
+    if os.path.exists(target_path):
+        os.remove(target_path)
+
+    ocel = ocel_consistency.apply(ocel, parameters=parameters)
+
     conn = sqlite3.connect(target_path)
 
     ocel.events.to_sql("EVENTS", conn, index=False)
