@@ -21,7 +21,8 @@ import pandas as pd
 
 from pm4py.objects.ocel import constants
 from pm4py.objects.ocel.obj import OCEL
-from pm4py.util import exec_utils
+from pm4py.util import exec_utils, pandas_utils, constants as pm4_constants
+from pm4py.objects.log.util import dataframe_utils
 
 
 class Parameters(Enum):
@@ -67,33 +68,38 @@ def get_ocel_from_extended_table(df: pd.DataFrame, objects_df: Optional[Dict[Any
     relations = []
     objects = {x: set() for x in object_type_columns}
 
-    for ev in stream:
+    i = 0
+    while i < len(stream):
+        ev = stream[i]
+        for ot in object_type_columns:
+            ev[ot] = parse_list(ev[ot])
         for ot in object_type_columns:
             ot_stri = ot.split(object_type_prefix)[1]
-            ev[ot] = parse_list(ev[ot])
             oot = objects[ot]
             for obj in ev[ot]:
                 oot.add(obj)
                 relations.append(
-                    {event_id: ev[event_id], event_activity: ev[event_activity], event_timestamp: ev[event_timestamp],
+                    {event_id: ev[event_id], event_activity: ev[event_activity],
+                     event_timestamp: ev[event_timestamp],
                      object_id_column: obj, object_type_column: ot_stri})
+        i = i + 1
 
-    relations = pd.DataFrame(relations)
+    relations = pandas_utils.instantiate_dataframe(relations)
 
     if objects_df is None:
         objects = [{object_type_column: x.split(object_type_prefix)[1], object_id_column: y} for x in objects for y in
                    objects[x]]
-        objects_df = pd.DataFrame(objects)
+        objects_df = pandas_utils.instantiate_dataframe(objects)
 
     del objects
 
     df = df[list(non_object_type_columns)]
-    df[event_timestamp] = pd.to_datetime(df[event_timestamp])
+    df = dataframe_utils.convert_timestamp_columns_in_df(df, timest_format=pm4_constants.DEFAULT_TIMESTAMP_PARSE_FORMAT, timest_columns=[event_timestamp])
 
-    df[internal_index] = df.index
-    relations[internal_index] = relations.index
+    df = pandas_utils.insert_index(df, internal_index, copy_dataframe=False, reset_index=False)
+    relations = pandas_utils.insert_index(relations, internal_index, reset_index=False, copy_dataframe=False)
 
-    relations[event_timestamp] = pd.to_datetime(relations[event_timestamp])
+    relations = dataframe_utils.convert_timestamp_columns_in_df(relations, timest_format=pm4_constants.DEFAULT_TIMESTAMP_PARSE_FORMAT, timest_columns=[event_timestamp])
 
     df = df.sort_values([event_timestamp, internal_index])
     relations = relations.sort_values([event_timestamp, internal_index])
