@@ -18,7 +18,7 @@ from pm4py.objects.ocel import constants
 from enum import Enum
 from pm4py.objects.ocel.obj import OCEL
 from typing import Optional, Dict, Any
-from pm4py.util import exec_utils
+from pm4py.util import exec_utils, pandas_utils
 
 
 class Parameters(Enum):
@@ -53,9 +53,9 @@ def propagate_event_filtering(ocel: OCEL, parameters: Optional[Dict[Any, Any]] =
     event_id = exec_utils.get_param_value(Parameters.EVENT_ID, parameters, ocel.event_id_column)
     object_id = exec_utils.get_param_value(Parameters.OBJECT_ID, parameters, ocel.object_id_column)
 
-    selected_event_ids = set(ocel.events[event_id].unique())
+    selected_event_ids = set(pandas_utils.format_unique(ocel.events[event_id].unique()))
     ocel.relations = ocel.relations[ocel.relations[event_id].isin(selected_event_ids)]
-    selected_object_ids = set(ocel.relations[object_id].unique())
+    selected_object_ids = set(pandas_utils.format_unique(ocel.relations[object_id].unique()))
     ocel.objects = ocel.objects[ocel.objects[object_id].isin(selected_object_ids)]
 
     ocel.e2e = ocel.e2e[(ocel.e2e[event_id].isin(selected_event_ids)) & (ocel.e2e[event_id+"_2"].isin(selected_event_ids))]
@@ -92,9 +92,9 @@ def propagate_object_filtering(ocel: OCEL, parameters: Optional[Dict[Any, Any]]
     event_id = exec_utils.get_param_value(Parameters.EVENT_ID, parameters, ocel.event_id_column)
     object_id = exec_utils.get_param_value(Parameters.OBJECT_ID, parameters, ocel.object_id_column)
 
-    selected_object_ids = set(ocel.objects[object_id].unique())
+    selected_object_ids = set(pandas_utils.format_unique(ocel.objects[object_id].unique()))
     ocel.relations = ocel.relations[ocel.relations[object_id].isin(selected_object_ids)]
-    selected_event_ids = set(ocel.relations[event_id].unique())
+    selected_event_ids = set(pandas_utils.format_unique(ocel.relations[event_id].unique()))
     ocel.events = ocel.events[ocel.events[event_id].isin(selected_event_ids)]
 
     ocel.e2e = ocel.e2e[(ocel.e2e[event_id].isin(selected_event_ids)) & (ocel.e2e[event_id+"_2"].isin(selected_event_ids))]
@@ -131,10 +131,12 @@ def propagate_relations_filtering(ocel: OCEL, parameters: Optional[Dict[Any, Any
     event_id = exec_utils.get_param_value(Parameters.EVENT_ID, parameters, ocel.event_id_column)
     object_id = exec_utils.get_param_value(Parameters.OBJECT_ID, parameters, ocel.object_id_column)
 
-    selected_event_ids = set(ocel.relations[event_id].unique())
-    selected_object_ids = set(ocel.relations[object_id].unique())
+    selected_event_ids = set(pandas_utils.format_unique(ocel.relations[event_id].unique())).intersection(set(pandas_utils.format_unique(ocel.events[event_id].unique())))
+    selected_object_ids = set(pandas_utils.format_unique(ocel.relations[object_id].unique())).intersection(set(pandas_utils.format_unique(ocel.objects[object_id].unique())))
     ocel.events = ocel.events[ocel.events[event_id].isin(selected_event_ids)]
     ocel.objects = ocel.objects[ocel.objects[object_id].isin(selected_object_ids)]
+    ocel.relations = ocel.relations[ocel.relations[event_id].isin(selected_event_ids)]
+    ocel.relations = ocel.relations[ocel.relations[object_id].isin(selected_object_ids)]
 
     ocel.e2e = ocel.e2e[(ocel.e2e[event_id].isin(selected_event_ids)) & (ocel.e2e[event_id+"_2"].isin(selected_event_ids))]
     ocel.o2o = ocel.o2o[(ocel.o2o[object_id].isin(selected_object_ids)) & (ocel.o2o[object_id+"_2"].isin(selected_object_ids))]
