@@ -14,11 +14,11 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-import pkgutil
+import importlib.util
 
 
 def apply(input_path, validation_path, parameters=None):
-    if not pkgutil.find_loader("jsonschema"):
+    if not importlib.util.find_spec("jsonschema"):
         raise Exception("please install jsonschema in order to validate a JSONOCEL file.")
 
     import json
