@@ -17,6 +17,7 @@
 from pm4py.objects.petri_net.utils.networkx_graph import create_networkx_undirected_graph
 from pm4py.objects.petri_net.utils import explore_path
 from pm4py.objects.petri_net import obj
+from pm4py.util import nx_utils
 
 
 def check_source_and_sink_reachability(net, unique_source, unique_sink):
@@ -38,14 +39,12 @@ def check_source_and_sink_reachability(net, unique_source, unique_sink):
     boolean
         Boolean value that is true if each node is in a path from the source place to the sink place
     """
-    import networkx as nx
-
     graph, unique_source_corr, unique_sink_corr, inv_dictionary = create_networkx_undirected_graph(net, unique_source,
                                                                                                    unique_sink)
     if unique_source_corr is not None and unique_sink_corr is not None:
         nodes_list = list(graph.nodes())
-        finish_to_sink = list(nx.ancestors(graph, unique_sink_corr))
-        connected_to_source = list(nx.descendants(graph, unique_source_corr))
+        finish_to_sink = list(nx_utils.ancestors(graph, unique_sink_corr))
+        connected_to_source = list(nx_utils.descendants(graph, unique_source_corr))
         if len(finish_to_sink) == len(nodes_list) - 1 and len(connected_to_source) == len(nodes_list) - 1:
             return True
     return False
