@@ -14,8 +14,8 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.objects.process_tree import process_tree, semantics, state, util as pt_util, regex, bottomup
-import pkgutil
+from pm4py.objects.process_tree import obj, semantics, state, utils
+import importlib.util
 
-if pkgutil.find_loader("lxml"):
+if importlib.util.find_spec("lxml"):
     from pm4py.objects.process_tree import importer, exporter
