@@ -15,3 +15,9 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.objects.random_variables import constant0, normal, uniform, exponential, random_variable, lognormal, gamma
+
+from pm4py.util import constants
+import warnings
+
+if constants.SHOW_INTERNAL_WARNINGS:
+    warnings.warn("The random_variables package will be removed in a future release.")
