@@ -16,6 +16,8 @@
 '''
 from pm4py.objects.stochastic_petri import tangible_reachability, utils
 
+from pm4py.util import constants
 import warnings
 
-warnings.warn("The stochastic_petri package will be removed in a future release.")
+if constants.SHOW_INTERNAL_WARNINGS:
+    warnings.warn("The stochastic_petri package will be removed in a future release.")
