@@ -14,8 +14,5 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.statistics import traces, attributes, variants, start_activities, end_activities, util, \
-    sojourn_time, concurrent_activities, eventually_follows, rework
-import pkgutil
-if pkgutil.find_loader("intervaltree"):
-    from pm4py.statistics import overlap
+from pm4py.statistics import traces, attributes, variants, start_activities, end_activities, \
+    service_time, concurrent_activities, eventually_follows, rework
