@@ -14,9 +14,4 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.statistics.attributes import common, log
-import pkgutil
-
-if pkgutil.find_loader("pandas"):
-    from pm4py.statistics.attributes import pandas
-
+from pm4py.statistics.attributes import common, log, pandas
