@@ -14,11 +14,17 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-import json, pkgutil, logging
+import json, logging
+import importlib.util
 
 from pm4py.util.points_subset import pick_chosen_points_list
-from pm4py.statistics.attributes.parameters import Parameters
-from pm4py.util import exec_utils
+from pm4py.util import exec_utils, pandas_utils, constants
+from enum import Enum
+
+
+class Parameters(Enum):
+    GRAPH_POINTS = "graph_points"
+    POINT_TO_SAMPLE = "points_to_sample"
 
 
 def get_sorted_attributes_list(attributes):
@@ -94,7 +100,7 @@ def get_kde_numeric_attribute(values, parameters=None):
     y
         Y-axis values to represent
     """
-    if pkgutil.find_loader("scipy") and pkgutil.find_loader("numpy") and pkgutil.find_loader("pandas"):
+    if importlib.util.find_spec("scipy") and importlib.util.find_spec("numpy"):
         from scipy.stats import gaussian_kde
         import numpy as np
         import pandas as pd
@@ -164,7 +170,7 @@ def get_kde_date_attribute(values, parameters=None):
     y
         Y-axis values to represent
     """
-    if pkgutil.find_loader("scipy") and pkgutil.find_loader("numpy") and pkgutil.find_loader("pandas"):
+    if importlib.util.find_spec("scipy") and importlib.util.find_spec("numpy"):
         from scipy.stats import gaussian_kde
         import numpy as np
         import pandas as pd
@@ -180,7 +186,7 @@ def get_kde_date_attribute(values, parameters=None):
             [x.replace(tzinfo=None).timestamp() for x in red_values])
         density = gaussian_kde(int_values)
         xs = np.linspace(min(int_values), max(int_values), graph_points)
-        xs_transf = pd.to_datetime(xs * 10 ** 9)
+        xs_transf = pd.to_datetime(xs * 10 ** 9, unit="ns")
 
         return [xs_transf, density(xs)]
     else:
