@@ -23,7 +23,10 @@ from pm4py.util import exec_utils
 from pm4py.util import constants
 from enum import Enum
 from collections import Counter
+from copy import copy
 from typing import Optional, Dict, Any, Union, Tuple, List, Set
+from pm4py.objects.conversion.log import converter as log_converter
+from pm4py.util.dt_parsing.variants import strpfromiso
 
 
 class Parameters(Enum):
@@ -86,6 +89,8 @@ def get_events_distribution(log: EventLog, distr_type: str = "days_month", param
     if parameters is None:
         parameters = {}
 
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
+
     timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, DEFAULT_TIMESTAMP_KEY)
 
     timestamp_values = []
@@ -143,6 +148,8 @@ def get_all_trace_attributes_from_log(log: EventLog) -> Set[str]:
     all_attributes
         All trace attributes from the log
     """
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG)
+
     all_attributes = set()
     for trace in log:
         all_attributes = all_attributes.union(set(trace.attributes.keys()))
@@ -165,6 +172,8 @@ def get_all_event_attributes_from_log(log: EventLog) -> Set[str]:
     all_attributes
         All trace attributes from the log
     """
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG)
+
     all_attributes = set()
     for trace in log:
         for event in trace:
@@ -192,6 +201,8 @@ def get_attribute_values(log: EventLog, attribute_key: str, parameters: Optional
     attributes
         Dictionary of attributes associated with their count
     """
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
+
     if parameters is None:
         parameters = {}
 
@@ -233,6 +244,8 @@ def get_trace_attribute_values(log: EventLog, attribute_key: str, parameters: Op
     if parameters is None:
         parameters = {}
 
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
+
     attributes = {}
 
     for trace in log:
@@ -268,11 +281,14 @@ def get_kde_numeric_attribute(log, attribute, parameters=None):
     y
         Y-axis values to represent
     """
+    if parameters is None:
+        parameters = {}
 
-    if type(log) is EventLog:
-        event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM, parameters={"deepcopy": False, "include_case_attributes": False})
-    else:
-        event_log = log
+    this_parameters = copy(parameters)
+    this_parameters["deepcopy"] = False
+    this_parameters["include_case_attributes"] = False
+
+    event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM, parameters=this_parameters)
 
     values = [event[attribute] for event in event_log if attribute in event]
 
@@ -302,11 +318,14 @@ def get_kde_numeric_attribute_json(log, attribute, parameters=None):
     y
         Y-axis values to represent
     """
+    if parameters is None:
+        parameters = {}
 
-    if type(log) is EventLog:
-        event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM, parameters={"deepcopy": False, "include_case_attributes": False})
-    else:
-        event_log = log
+    this_parameters = copy(parameters)
+    this_parameters["deepcopy"] = False
+    this_parameters["include_case_attributes"] = False
+
+    event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM, parameters=this_parameters)
 
     values = [event[attribute] for event in event_log if attribute in event]
 
@@ -335,13 +354,16 @@ def get_kde_date_attribute(log, attribute=DEFAULT_TIMESTAMP_KEY, parameters=None
     y
         Y-axis values to represent
     """
+    if parameters is None:
+        parameters = {}
 
-    if type(log) is EventLog:
-        event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM, parameters={"deepcopy": False, "include_case_attributes": False})
-    else:
-        event_log = log
+    this_parameters = copy(parameters)
+    this_parameters["deepcopy"] = False
+    this_parameters["include_case_attributes"] = False
 
-    values = [event[attribute].replace(tzinfo=None) for event in event_log if attribute in event]
+    event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM, parameters=this_parameters)
+
+    values = [strpfromiso.fix_naivety(event[attribute]) for event in event_log if attribute in event]
 
     return attributes_common.get_kde_date_attribute(values, parameters=parameters)
 
@@ -369,12 +391,15 @@ def get_kde_date_attribute_json(log, attribute=DEFAULT_TIMESTAMP_KEY, parameters
     y
         Y-axis values to represent
     """
+    if parameters is None:
+        parameters = {}
 
-    if type(log) is EventLog:
-        event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM, parameters={"deepcopy": False, "include_case_attributes": False})
-    else:
-        event_log = log
+    this_parameters = copy(parameters)
+    this_parameters["deepcopy"] = False
+    this_parameters["include_case_attributes"] = False
 
-    values = [event[attribute].replace(tzinfo=None) for event in event_log if attribute in event]
+    event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM, parameters=this_parameters)
+
+    values = [strpfromiso.fix_naivety(event[attribute]) for event in event_log if attribute in event]
 
     return attributes_common.get_kde_date_attribute_json(values, parameters=parameters)
