@@ -16,6 +16,8 @@
 '''
 from pm4py.statistics.overlap import cases, utils
 
+from pm4py.util import constants
 import warnings
 
-warnings.warn("The overlap package will be removed in a future release.")
+if constants.SHOW_INTERNAL_WARNINGS:
+    warnings.warn("The overlap package will be removed in a future release.")
