@@ -20,7 +20,7 @@ from pm4py.algo.discovery.dfg.adapters.pandas import df_statistics as pandas
 from pm4py.util import exec_utils
 from pm4py.util import constants
 from enum import Enum
-from typing import Optional, Dict, Any, Union, Tuple, List, Set
+from typing import Optional, Dict, Any
 import pandas as pd
 
 
