@@ -23,7 +23,7 @@ import numpy as np
 from enum import Enum
 from pm4py.util import exec_utils
 from pm4py.util import constants
-from typing import Optional, Dict, Any, Union, Tuple, List, Set
+from typing import Optional, Dict, Any, Union, List
 from pm4py.objects.log.obj import EventLog
 from pm4py.objects.conversion.log import converter as log_converter
 
@@ -146,7 +146,7 @@ def get_cases_description(log: EventLog,  parameters: Optional[Dict[Union[str, P
             st = trace[0][timestamp_key]
             et = trace[-1][timestamp_key]
             if business_hours:
-                bh = BusinessHours(st.replace(tzinfo=None), et.replace(tzinfo=None),
+                bh = BusinessHours(st, et,
                                    business_hour_slots=business_hours_slots, workcalendar=workcalendar)
                 diff = bh.get_seconds()
             else:
