@@ -21,11 +21,12 @@ import pandas as pd
 
 from pm4py.statistics.traces.generic.common import case_duration as case_duration_commons
 from pm4py.util import exec_utils, constants, pandas_utils
-from pm4py.util import variants_util
 from pm4py.util import xes_constants as xes
 from pm4py.util.business_hours import soj_time_business_hours_diff
 from pm4py.util.constants import CASE_CONCEPT_NAME
 from pm4py.util.xes_constants import DEFAULT_TIMESTAMP_KEY
+from collections import Counter
+import importlib.util
 
 
 class Parameters(Enum):
@@ -71,14 +72,22 @@ def get_variant_statistics(df: pd.DataFrame, parameters: Optional[Dict[Union[str
     if parameters is None:
         parameters = {}
     case_id_glue = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, CASE_CONCEPT_NAME)
+    activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes.DEFAULT_NAME_KEY)
 
     max_variants_to_return = exec_utils.get_param_value(Parameters.MAX_VARIANTS_TO_RETURN, parameters, None)
-    variants_df = exec_utils.get_param_value(Parameters.VARIANTS_DF, parameters, get_variants_df(df,
-                                                                                                 parameters=parameters))
 
-    variants_df = variants_df.reset_index()
-    variants_list = pandas_utils.to_dict_records(variants_df.groupby("variant").agg("count").reset_index())
+    if importlib.util.find_spec("cudf"):
+        variants_list = [tuple(x) for x in df.groupby(case_id_glue)[activity_key].agg(list).to_dict().values()]
+        variants_list = Counter(variants_list)
+        variants_list = [{"variant": x, case_id_glue: y} for x, y in variants_list.items()]
+    else:
+        variants_df = exec_utils.get_param_value(Parameters.VARIANTS_DF, parameters, get_variants_df(df,
+                                                                                                     parameters=parameters))
+        variants_df = variants_df.reset_index()
+        variants_list = pandas_utils.to_dict_records(variants_df.groupby("variant").agg("count").reset_index())
+
     variants_list = sorted(variants_list, key=lambda x: (x[case_id_glue], x["variant"]), reverse=True)
+
     if max_variants_to_return:
         variants_list = variants_list[:min(len(variants_list), max_variants_to_return)]
     return variants_list
@@ -169,7 +178,7 @@ def get_cases_description(df: pd.DataFrame, parameters: Optional[Dict[Union[str,
     last_eve_df = grouped_df.last()
     del grouped_df
     last_eve_df.columns = [str(col) + '_2' for col in first_eve_df.columns]
-    stacked_df = pd.concat([first_eve_df, last_eve_df], axis=1)
+    stacked_df = pandas_utils.concat([first_eve_df, last_eve_df], axis=1)
     del first_eve_df
     del last_eve_df
     del stacked_df[case_id_glue]
@@ -180,7 +189,7 @@ def get_cases_description(df: pd.DataFrame, parameters: Optional[Dict[Union[str,
             lambda x: soj_time_business_hours_diff(x[start_timestamp_key], x[timestamp_key + "_2"], business_hours_slots, workcalendar), axis=1)
     else:
         stacked_df['caseDuration'] = stacked_df[timestamp_key + "_2"] - stacked_df[start_timestamp_key]
-        stacked_df['caseDuration'] = stacked_df['caseDuration'].dt.total_seconds()
+        stacked_df['caseDuration'] = pandas_utils.get_total_seconds(stacked_df['caseDuration'])
 
     stacked_df[timestamp_key + "_2"] = stacked_df[timestamp_key + "_2"].astype('int64') // 10 ** 9
     stacked_df[start_timestamp_key] = stacked_df[start_timestamp_key].astype('int64') // 10 ** 9
@@ -218,7 +227,7 @@ def get_variants_df(df, parameters=None):
     case_id_glue = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, CASE_CONCEPT_NAME)
     activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes.DEFAULT_NAME_KEY)
 
-    new_df = df.groupby(case_id_glue, sort=False)[activity_key].agg(lambda col: tuple(pd.Series.to_list(col))).to_frame()
+    new_df = df.groupby(case_id_glue, sort=False)[activity_key].agg(tuple).to_frame()
 
     new_cols = list(new_df.columns)
     new_df = new_df.rename(columns={new_cols[0]: "variant"})
@@ -259,7 +268,7 @@ def get_variants_df_with_case_duration(df, parameters=None):
 
     grouped_df = df[[case_id_glue, timestamp_key, activity_key]].groupby(df[case_id_glue])
 
-    df1 = grouped_df[activity_key].agg(lambda col: tuple(pd.Series.to_list(col))).to_frame()
+    df1 = grouped_df[activity_key].agg(tuple).to_frame()
     new_cols = list(df1.columns)
     df1 = df1.rename(columns={new_cols[0]: "variant"})
 
@@ -267,20 +276,20 @@ def get_variants_df_with_case_duration(df, parameters=None):
     last_eve_df = grouped_df.last()
     del grouped_df
     last_eve_df.columns = [str(col) + '_2' for col in first_eve_df.columns]
-    stacked_df = pd.concat([first_eve_df, last_eve_df], axis=1)
+    stacked_df = pandas_utils.concat([first_eve_df, last_eve_df], axis=1)
     del first_eve_df
     del last_eve_df
     del stacked_df[case_id_glue]
     del stacked_df[case_id_glue + "_2"]
     stacked_df['caseDuration'] = stacked_df[timestamp_key + "_2"] - stacked_df[timestamp_key]
-    stacked_df['caseDuration'] = stacked_df['caseDuration'].dt.total_seconds()
+    stacked_df['caseDuration'] = pandas_utils.get_total_seconds(stacked_df['caseDuration'])
     if business_hours:
         stacked_df['caseDuration'] = stacked_df.apply(
             lambda x: soj_time_business_hours_diff(x[timestamp_key], x[timestamp_key + "_2"], business_hours_slots, workcalendar), axis=1)
     else:
         stacked_df['caseDuration'] = stacked_df[timestamp_key + "_2"] - stacked_df[timestamp_key]
-        stacked_df['caseDuration'] = stacked_df['caseDuration'].dt.total_seconds()
-    new_df = pd.concat([df1, stacked_df], axis=1)
+        stacked_df['caseDuration'] = pandas_utils.get_total_seconds(stacked_df['caseDuration'])
+    new_df = pandas_utils.concat([df1, stacked_df], axis=1)
     del df1
     del stacked_df
     return new_df
