@@ -16,6 +16,8 @@
 '''
 from pm4py.statistics.util import times_bipartite_matching
 
+from pm4py.util import constants
 import warnings
 
-warnings.warn("The statistics.util package will be removed in a future release.")
+if constants.SHOW_INTERNAL_WARNINGS:
+    warnings.warn("The statistics.util package will be removed in a future release.")
