@@ -14,8 +14,8 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-import pkgutil
-import logging
+from pm4py.util import nx_utils
+import sys
 
 
 def exact_match_minimum_average(l1, l2):
@@ -40,15 +40,7 @@ def exact_match_minimum_average(l1, l2):
         an element of the first list, and as second element
         an element of the second list)
     """
-    import sys
-    if pkgutil.find_loader("networkx"):
-        import networkx as nx
-    else:
-        msg = "networkx is not available. inductive exact_match_minimum_average cannot be used!"
-        logging.error(msg)
-        raise Exception(msg)
-
-    G = nx.Graph()
+    G = nx_utils.Graph()
     for i in range(len(l1)):
         G.add_node(i)
     for j in range(len(l2)):
@@ -59,7 +51,7 @@ def exact_match_minimum_average(l1, l2):
                 G.add_edge(i, len(l1) + j, weight=(l2[j] - l1[i]))
             else:
                 G.add_edge(i, len(l1) + j, weight=sys.maxsize)
-    matching0 = {x: y for x, y in nx.bipartite.minimum_weight_full_matching(G).items() if x < len(l1)}
+    matching0 = {x: y for x, y in nx_utils.minimum_weight_full_matching(G).items() if x < len(l1)}
     matching = []
     for k1, k2 in matching0.items():
         v1 = l1[k1]
