@@ -18,8 +18,9 @@ __doc__ = """
 The ``pm4py.stats`` module contains the statistics offered in ``pm4py``
 """
 
-from typing import Dict, Union, List, Tuple, Collection
+from typing import Dict, Union, List, Tuple, Collection, Iterator
 from typing import Set, Optional
+from typing import Counter as TCounter
 from collections import Counter
 
 import pandas as pd
@@ -27,10 +28,9 @@ import pandas as pd
 from pm4py.objects.log.obj import EventLog, Trace, EventStream
 from pm4py.util.pandas_utils import check_is_pandas_dataframe, check_pandas_dataframe_columns, insert_ev_in_tr_index
 from pm4py.utils import get_properties, __event_log_deprecation_warning
-from pm4py.util import xes_constants, constants
+from pm4py.util import constants, pandas_utils
 from pm4py.objects.petri_net.obj import PetriNet
 from pm4py.objects.process_tree.obj import ProcessTree
-from copy import copy
 import deprecation
 
 
@@ -50,7 +50,6 @@ def get_start_activities(log: Union[EventLog, pd.DataFrame], activity_key: str =
 
         start_activities = pm4py.get_start_activities(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -80,7 +79,6 @@ def get_end_activities(log: Union[EventLog, pd.DataFrame], activity_key: str = "
 
         end_activities = pm4py.get_end_activities(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -107,7 +105,6 @@ def get_event_attributes(log: Union[EventLog, pd.DataFrame]) -> List[str]:
 
         event_attributes = pm4py.get_event_attributes(dataframe)
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     if check_is_pandas_dataframe(log):
@@ -131,7 +128,6 @@ def get_trace_attributes(log: Union[EventLog, pd.DataFrame]) -> List[str]:
 
         trace_attributes = pm4py.get_trace_attributes(dataframe)
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     from pm4py.util import constants
@@ -159,7 +155,6 @@ def get_event_attribute_values(log: Union[EventLog, pd.DataFrame], attribute: st
 
         activities = pm4py.get_event_attribute_values(dataframe, 'concept:name', case_id_key='case:concept:name')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, case_id_key=case_id_key)
@@ -188,7 +183,6 @@ def get_trace_attribute_values(log: Union[EventLog, pd.DataFrame], attribute: st
 
         tr_attr_values = pm4py.get_trace_attribute_values(dataframe, 'case:attribute', case_id_key='case:concept:name')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     parameters = get_properties(log, case_id_key=case_id_key)
@@ -196,13 +190,26 @@ def get_trace_attribute_values(log: Union[EventLog, pd.DataFrame], attribute: st
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log, case_id_key=case_id_key)
         from pm4py.statistics.attributes.pandas import get
-        return get.get_attribute_values(log, attribute, parameters=parameters)
+        if attribute not in log and constants.CASE_ATTRIBUTE_PREFIX + attribute in log:
+            # if "attribute" does not exist as column, but "case:attribute" exists, then use that
+            attribute = constants.CASE_ATTRIBUTE_PREFIX + attribute
+        ret = get.get_attribute_values(log, attribute, parameters=parameters)
+        return ret
     else:
         from pm4py.statistics.attributes.log import get
-        return get.get_trace_attribute_values(log, attribute, parameters=parameters)
+        ret = get.get_trace_attribute_values(log, attribute, parameters=parameters)
+
+        if not ret:
+            # if the provided attribute does not exist, but starts with "case:", try to get the attribute values
+            # removing the "case:" at the beginning
+            if attribute.startswith(constants.CASE_ATTRIBUTE_PREFIX):
+                attribute = attribute.split(constants.CASE_ATTRIBUTE_PREFIX)[-1]
+            ret = get.get_trace_attribute_values(log, attribute, parameters=parameters)
+
+        return ret
 
 
-def get_variants(log: Union[EventLog, pd.DataFrame], activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> Dict[Tuple[str], List[Trace]]:
+def get_variants(log: Union[EventLog, pd.DataFrame], activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> Union[Dict[Tuple[str], List[Trace]], Dict[Tuple[str], int]]:
     """
     Gets the variants from the log
 
@@ -221,7 +228,7 @@ def get_variants(log: Union[EventLog, pd.DataFrame], activity_key: str = "concep
     return get_variants_as_tuples(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
 
 
-def get_variants_as_tuples(log: Union[EventLog, pd.DataFrame], activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> Dict[Tuple[str], List[Trace]]:
+def get_variants_as_tuples(log: Union[EventLog, pd.DataFrame], activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> Union[Dict[Tuple[str], List[Trace]], Dict[Tuple[str], int]]:
     """
     Gets the variants from the log (where the keys are tuples and not strings)
 
@@ -237,7 +244,6 @@ def get_variants_as_tuples(log: Union[EventLog, pd.DataFrame], activity_key: str
 
         variants = pm4py.get_variants_as_tuples(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -251,6 +257,128 @@ def get_variants_as_tuples(log: Union[EventLog, pd.DataFrame], activity_key: str
         return get.get_variants(log, parameters=properties)
 
 
+def split_by_process_variant(log: Union[EventLog, pd.DataFrame], activity_key: str = "concept:name",
+                             timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name",
+                             variant_column: str = "@@variant_column",
+                             index_in_trace_column: str = "@@index_in_trace") -> Iterator[
+    Tuple[Collection[str], pd.DataFrame]]:
+    """
+    Splits an event log into sub-dataframes for each process variant.
+    The result is an iterator over the variants along with the sub-dataframes.
+
+    :param log: Event log
+    :param activity_key: attribute to be used for the activity
+    :param timestamp_key: attribute to be used for the timestamp
+    :param case_id_key: attribute to be used as case identifier
+    :param variant_column: name of the utility column that stores the variant's tuple
+    :param index_in_trace_column: name of the utility column that stores the index of the event in the case
+    :rtype: ``Iterator[Tuple[Collection[str], pd.DataFrame]]``
+
+    .. code-block:: python3
+
+        import pandas as pd
+        import pm4py
+
+        dataframe = pd.read_csv('tests/input_data/receipt.csv')
+        dataframe = pm4py.format_dataframe(dataframe)
+        for variant, subdf in pm4py.split_by_process_variant(dataframe):
+            print(variant)
+            print(subdf)
+    """
+    __event_log_deprecation_warning(log)
+
+    import pm4py
+    log = pm4py.convert_to_dataframe(log)
+    check_pandas_dataframe_columns(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
+
+    from pm4py.util import pandas_utils
+    log = pandas_utils.insert_ev_in_tr_index(log, case_id=case_id_key, column_name=index_in_trace_column)
+    properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
+
+    from pm4py.objects.log.util import pandas_numpy_variants
+    variants_dict, case_variant = pandas_numpy_variants.apply(log, parameters=properties)
+
+    log[variant_column] = log[case_id_key].map(case_variant)
+
+    for variant, filtered_log in log.groupby(variant_column, sort=False):
+        yield variant, filtered_log
+
+
+def get_variants_paths_duration(log: Union[EventLog, pd.DataFrame], activity_key: str = "concept:name",
+                                timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name",
+                                variant_column: str = "@@variant_column",
+                                variant_count: str = "@@variant_count",
+                                index_in_trace_column: str = "@@index_in_trace",
+                                cumulative_occ_path_column: str = "@@cumulative_occ_path_column",
+                                times_agg: str = "mean") -> pd.DataFrame:
+    """
+    Method that associates to a log object a Pandas dataframe aggregated by variants and positions (inside the variant).
+    Each row is associated to different columns:
+    - The variant
+    - The position (in the variant)
+    - The source activity (of the path)
+    - The target activity (of the path)
+    - An aggregation of the times between the two activities (for example, the mean over all the cases of the same variant)
+    - The cumulative occurrences of the path inside the case (for example, the first A->B would be associated to 0,
+                                                            and the second A->B would be associated to 1)
+
+    :param log: Event log
+    :param activity_key: attribute to be used for the activity
+    :param timestamp_key: attribute to be used for the timestamp
+    :param case_id_key: attribute to be used as case identifier
+    :param variant_column: name of the utility column that stores the variant's tuple
+    :param variant_count: name of the utility column that stores the variant's number of occurrences
+    :param index_in_trace_column: name of the utility column that stores the index of the event in the case
+    :param cumulative_occ_path_column: name of the column that stores the cumulative occurrences of the path inside the case
+    :param times_agg: aggregation (mean, median) to be used
+    :rtype: ``pd.DataFrame``
+
+    .. code-block:: python3
+
+        import pandas as pd
+        import pm4py
+
+        dataframe = pd.read_csv('tests/input_data/receipt.csv')
+        dataframe = pm4py.format_dataframe(dataframe)
+
+        var_paths_durs = pm4py.get_variants_paths_duration(dataframe)
+        print(var_paths_durs)
+    """
+    __event_log_deprecation_warning(log)
+    check_pandas_dataframe_columns(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
+
+    list_to_concat = []
+    for variant, filtered_log in split_by_process_variant(log, activity_key=activity_key, timestamp_key=timestamp_key,
+                                                          case_id_key=case_id_key, variant_column=variant_column,
+                                                          index_in_trace_column=index_in_trace_column):
+        from pm4py.statistics.eventually_follows.pandas import get as eventually_follows
+        dir_follo_dataframe = eventually_follows.get_partial_order_dataframe(filtered_log.copy(), activity_key=activity_key,
+                                                                             timestamp_key=timestamp_key,
+                                                                             case_id_glue=case_id_key,
+                                                                             sort_caseid_required=False,
+                                                                             sort_timestamp_along_case_id=False,
+                                                                             reduce_dataframe=False)
+        dir_follo_dataframe[cumulative_occ_path_column] = dir_follo_dataframe.groupby(
+            [case_id_key, activity_key, activity_key + "_2"]).cumcount()
+        dir_follo_dataframe = dir_follo_dataframe[
+            [index_in_trace_column, constants.DEFAULT_FLOW_TIME, cumulative_occ_path_column]].groupby(
+            index_in_trace_column).agg(
+            {constants.DEFAULT_FLOW_TIME: times_agg, cumulative_occ_path_column: 'min'}).reset_index()
+        dir_follo_dataframe[activity_key] = dir_follo_dataframe[index_in_trace_column].apply(lambda x: variant[x])
+        dir_follo_dataframe[activity_key + "_2"] = dir_follo_dataframe[index_in_trace_column].apply(
+            lambda x: variant[x + 1])
+        dir_follo_dataframe[variant_column] = dir_follo_dataframe[index_in_trace_column].apply(lambda x: variant)
+        dir_follo_dataframe[variant_count] = filtered_log[case_id_key].nunique()
+
+        list_to_concat.append(dir_follo_dataframe)
+
+    dataframe = pandas_utils.concat(list_to_concat)
+    dataframe[index_in_trace_column] = -dataframe[index_in_trace_column]
+    dataframe = dataframe.sort_values([variant_count, variant_column, index_in_trace_column], ascending=False)
+    dataframe[index_in_trace_column] = -dataframe[index_in_trace_column]
+
+    return dataframe
+
 def get_stochastic_language(*args, **kwargs) -> Dict[List[str], float]:
     """
     Gets the stochastic language from the provided object
@@ -271,7 +399,7 @@ def get_stochastic_language(*args, **kwargs) -> Dict[List[str], float]:
         print(language_model)
     """
     from pm4py.statistics.variants.log import get
-    if isinstance(args[0], EventLog) or isinstance(args[0], EventStream) or isinstance(args[0], pd.DataFrame):
+    if isinstance(args[0], EventLog) or isinstance(args[0], EventStream) or pandas_utils.check_is_pandas_dataframe(args[0]):
         from pm4py.objects.conversion.log import converter as log_converter
         log = log_converter.apply(args[0])
         return get.get_language(log)
@@ -301,7 +429,6 @@ def get_minimum_self_distances(log: Union[EventLog, pd.DataFrame], activity_key:
 
         msd = pm4py.get_minimum_self_distances(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     '''
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     if check_is_pandas_dataframe(log):
@@ -334,7 +461,6 @@ def get_minimum_self_distance_witnesses(log: Union[EventLog, pd.DataFrame], acti
 
         msd_wit = pm4py.get_minimum_self_distance_witnesses(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     if check_is_pandas_dataframe(log):
@@ -361,7 +487,6 @@ def get_case_arrival_average(log: Union[EventLog, pd.DataFrame], activity_key: s
 
         case_arr_avg = pm4py.get_case_arrival_average(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -394,7 +519,6 @@ def get_rework_cases_per_activity(log: Union[EventLog, pd.DataFrame], activity_k
 
         rework = pm4py.get_rework_cases_per_activity(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -425,7 +549,6 @@ def get_case_overlap(log: Union[EventLog, pd.DataFrame], activity_key: str = "co
 
         overlap = pm4py.get_case_overlap(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -466,7 +589,6 @@ def get_cycle_time(log: Union[EventLog, pd.DataFrame], activity_key: str = "conc
 
         cycle_time = pm4py.get_cycle_time(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -480,6 +602,42 @@ def get_cycle_time(log: Union[EventLog, pd.DataFrame], activity_key: str = "conc
         return cycle_time.apply(log, parameters=properties)
 
 
+def get_service_time(log: Union[EventLog, pd.DataFrame], aggregation_measure: str = "mean", activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", start_timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> Dict[str, float]:
+    """
+    Gets the activities' (average/median/...) service time in the provided event log
+
+    :param log: event log
+    :param aggregation_measure: the aggregation to be used (mean, median, min, max, sum)
+    :param activity_key: attribute to be used for the activity
+    :param timestamp_key: attribute to be used for the timestamp
+    :param start_timestamp_key: attribute to be used for the start timestamp
+    :param case_id_key: attribute to be used as case identifier
+    :rtype: ``Dict[str, float]``
+
+    .. code-block:: python3
+
+        import pm4py
+
+        log = pm4py.read_xes('tests/input_data/interval_event_log.xes')
+        mean_serv_time = pm4py.get_service_time(log, start_timestamp_key='start_timestamp', aggregation_measure='mean')
+        print(mean_serv_time)
+        median_serv_time = pm4py.get_service_time(log, start_timestamp_key='start_timestamp', aggregation_measure='median')
+        print(median_serv_time)
+    """
+    __event_log_deprecation_warning(log)
+
+    properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key, start_timestamp_key=start_timestamp_key)
+    properties["aggregationMeasure"] = aggregation_measure
+
+    if check_is_pandas_dataframe(log):
+        check_pandas_dataframe_columns(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key, start_timestamp_key=start_timestamp_key)
+        from pm4py.statistics.service_time.pandas import get as serv_time_get
+        return serv_time_get.apply(log, parameters=properties)
+    else:
+        from pm4py.statistics.service_time.log import get as serv_time_get
+        return serv_time_get.apply(log, parameters=properties)
+
+
 def get_all_case_durations(log: Union[EventLog, pd.DataFrame], business_hours: bool = False, business_hour_slots=constants.DEFAULT_BUSINESS_HOUR_SLOTS, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> List[float]:
     """
     Gets the durations of the cases in the event log
@@ -498,7 +656,6 @@ def get_all_case_durations(log: Union[EventLog, pd.DataFrame], business_hours: b
 
         case_durations = pm4py.get_all_case_durations(dataframe, activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -533,7 +690,6 @@ def get_case_duration(log: Union[EventLog, pd.DataFrame], case_id: str, business
 
         duration = pm4py.get_case_duration(dataframe, 'case 1', activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     properties = get_properties(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
@@ -550,6 +706,52 @@ def get_case_duration(log: Union[EventLog, pd.DataFrame], case_id: str, business
         return cd[case_id]["caseDuration"]
 
 
+def get_frequent_trace_segments(log: Union[EventLog, pd.DataFrame], min_occ: int, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> TCounter:
+    """
+    Get the traces (segments of activities) from an event log object.
+    Each trace is preceded and followed by "...", reminding that the trace/segment
+    can be preceded and followed by any other set of activities.
+
+    :param log: event log
+    :param min_occ: minimum number of occurrence of a trace in order to be included
+    :param activity_key: the attribute to be used as activity
+    :param timestamp_key: the attribute to be used as timestamp
+    :param case_id_key: the attribute to be used as case identifier (for Pandas dataframes)
+    :rtype: ``TCounter``
+
+    .. code-block:: python3
+
+        import pm4py
+
+        log = pm4py.read_xes("tests/input_data/receipt.xes")
+        traces = pm4py.get_frequent_trace_segments(log, min_occ=100)
+        print(traces)
+    """
+    __event_log_deprecation_warning(log)
+
+    if check_is_pandas_dataframe(log):
+        check_pandas_dataframe_columns(log, activity_key=activity_key, timestamp_key=timestamp_key, case_id_key=case_id_key)
+
+    import pm4py.utils
+    from prefixspan import PrefixSpan
+
+    projection = pm4py.utils.project_on_event_attribute(log, attribute_key=activity_key, case_id_key=case_id_key)
+    traces0 = PrefixSpan(projection).frequent(min_occ)
+    traces = {}
+    for x in traces0:
+        trace = ["..."]
+        for i in range(len(x[1])):
+            if i > 0:
+                trace.append("...")
+            trace.append(x[1][i])
+        trace.append("...")
+        trace = tuple(trace)
+        traces[trace] = x[0]
+    traces = Counter(traces)
+
+    return traces
+
+
 def get_activity_position_summary(log: Union[EventLog, pd.DataFrame], activity: str, activity_key: str = "concept:name", timestamp_key: str = "time:timestamp", case_id_key: str = "case:concept:name") -> Dict[int, int]:
     """
     Given an event log, returns a dictionary which summarize the positions
@@ -571,7 +773,6 @@ def get_activity_position_summary(log: Union[EventLog, pd.DataFrame], activity:
 
         act_pos = pm4py.get_activity_position_summary(dataframe, 'Act. A', activity_key='concept:name', case_id_key='case:concept:name', timestamp_key='time:timestamp')
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
     __event_log_deprecation_warning(log)
 
     if check_is_pandas_dataframe(log):
