@@ -14,6 +14,5 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-
-from pm4py.util import variants_util, lp, constants, points_subset, business_hours, regex, xes_constants, vis_utils, \
-    dt_parsing, colors, exec_utils, pandas_utils, typing
+from pm4py.util import exec_utils, constants, xes_constants, pandas_utils, nx_utils, lp, variants_util, points_subset, business_hours, vis_utils, \
+    dt_parsing, colors, typing, compression
