@@ -14,9 +14,31 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from datetime import datetime
+from datetime import datetime, timezone
+from pm4py.util import constants
 
-# NB: Compatible only from Python 3.7 onwards!!!
+
+def fix_dataframe_column(serie):
+    if constants.ENABLE_DATETIME_COLUMNS_AWARE:
+        # Convert to UTC if the datetime is naive
+        if serie.dt.tz is None:
+            serie = serie.dt.tz_localize('UTC')
+        else:
+            # Convert to UTC if it's not already in UTC
+            serie = serie.dt.tz_convert('UTC')
+    else:
+        serie = serie.dt.tz_localize(None)
+
+    return serie
+
+
+def fix_naivety(dt):
+    if constants.ENABLE_DATETIME_COLUMNS_AWARE:
+        dt = dt.replace(tzinfo=timezone.utc)
+    else:
+        dt = dt.replace(tzinfo=None)
+
+    return dt
 
 
 def apply(dt):
@@ -37,4 +59,6 @@ def apply(dt):
         # Z at the end of date means UTC, but that is not ISO format.
         # Replace "Z" with "+00:00" that is also UTC
         dt = dt[:-1] + "+00:00"
-    return datetime.fromisoformat(dt)
+    dt = datetime.fromisoformat(dt)
+
+    return fix_naivety(dt)
