@@ -14,14 +14,25 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-import pkgutil
-
 import pandas as pd
+import importlib.util
 
 from pm4py.util import constants, xes_constants
 import numpy as np
 
 
+def get_default_dataframe_environment():
+    if importlib.util.find_spec("cudf"):
+        #import cudf; return cudf
+        import cudf.pandas
+        cudf.pandas.install()
+    import pandas as pd
+    return pd
+
+
+DATAFRAME = get_default_dataframe_environment()
+
+
 def to_dict_records(df):
     """
     Pandas dataframe to dictionary (records method)
@@ -56,7 +67,7 @@ def to_dict_index(df):
     return df.to_dict('index')
 
 
-def insert_index(df, column_name=constants.DEFAULT_INDEX_KEY, copy_dataframe=True):
+def insert_index(df, column_name=constants.DEFAULT_INDEX_KEY, copy_dataframe=True, reset_index=True):
     """
     Inserts the dataframe index in the specified column
 
@@ -76,7 +87,10 @@ def insert_index(df, column_name=constants.DEFAULT_INDEX_KEY, copy_dataframe=Tru
     """
     if copy_dataframe:
         df = df.copy()
-    df = df.reset_index(drop=True)
+
+    if reset_index:
+        df = df.reset_index(drop=True)
+
     df[column_name] = df.index
     return df
 
@@ -103,12 +117,13 @@ def insert_case_index(df, column_name=constants.DEFAULT_CASE_INDEX_KEY, case_id=
     """
     if copy_dataframe:
         df = df.copy()
+
     df[column_name] = df.groupby(case_id).ngroup()
     return df
 
 
 def insert_ev_in_tr_index(df: pd.DataFrame, case_id: str = constants.CASE_CONCEPT_NAME,
-                          column_name: str = constants.DEFAULT_INDEX_IN_TRACE_KEY) -> pd.DataFrame:
+                          column_name: str = constants.DEFAULT_INDEX_IN_TRACE_KEY, copy_dataframe=True) -> pd.DataFrame:
     """
     Inserts a column that specify the index of the event inside the case
 
@@ -126,12 +141,24 @@ def insert_ev_in_tr_index(df: pd.DataFrame, case_id: str = constants.CASE_CONCEP
     df
         Dataframe with index
     """
-    df = df.copy()
+    if copy_dataframe:
+        df = df.copy()
+
     df_trace_idx = df.groupby(case_id).cumcount()
     df[column_name] = df_trace_idx
     return df
 
 
+def format_unique(values):
+    try:
+        values = values.to_numpy()
+    except:
+        pass
+
+    values = values.tolist()
+    return values
+
+
 def insert_feature_activity_position_in_trace(df: pd.DataFrame, case_id: str = constants.CASE_CONCEPT_NAME,
                                       activity_key: str = xes_constants.DEFAULT_NAME_KEY, prefix="@@position_"):
     """
@@ -156,7 +183,7 @@ def insert_feature_activity_position_in_trace(df: pd.DataFrame, case_id: str = c
         Pandas dataframe
     """
     df = insert_ev_in_tr_index(df, case_id=case_id)
-    activities = set(df[activity_key].unique())
+    activities = format_unique(df[activity_key].unique())
     for act in activities:
         df[prefix + act] = df[activity_key].apply(lambda x: np.nan if x == act else -1)
         df[prefix + act] = df[prefix + act].fillna(df[constants.DEFAULT_INDEX_IN_TRACE_KEY])
@@ -181,11 +208,11 @@ def insert_case_arrival_finish_rate(log: pd.DataFrame, case_id_column=constants.
     if start_timestamp_column is None:
         start_timestamp_column = timestamp_column
 
-    case_arrival = log.groupby(case_id_column)[start_timestamp_column].agg(min).to_dict()
+    case_arrival = log.groupby(case_id_column)[start_timestamp_column].agg("min").to_dict()
     case_arrival = [[x, y.timestamp()] for x, y in case_arrival.items()]
     case_arrival.sort(key=lambda x: (x[1], x[0]))
 
-    case_finish = log.groupby(case_id_column)[timestamp_column].agg(max).to_dict()
+    case_finish = log.groupby(case_id_column)[timestamp_column].agg("max").to_dict()
     case_finish = [[x, y.timestamp()] for x, y in case_finish.items()]
     case_finish.sort(key=lambda x: (x[1], x[0]))
 
@@ -228,12 +255,12 @@ def insert_case_service_waiting_time(log: pd.DataFrame, case_id_column=constants
     if start_timestamp_column is None:
         start_timestamp_column = timestamp_column
 
-    log[diff_start_end_column] = (log[timestamp_column] - log[start_timestamp_column]).dt.total_seconds()
+    log[diff_start_end_column] = get_total_seconds(log[timestamp_column] - log[start_timestamp_column])
     service_times = log.groupby(case_id_column)[diff_start_end_column].sum().to_dict()
     log[service_time_column] = log[case_id_column].map(service_times)
 
-    start_timestamps = log.groupby(case_id_column)[start_timestamp_column].agg(min).to_dict()
-    complete_timestamps = log.groupby(case_id_column)[timestamp_column].agg(max).to_dict()
+    start_timestamps = log.groupby(case_id_column)[start_timestamp_column].agg("min").to_dict()
+    complete_timestamps = log.groupby(case_id_column)[timestamp_column].agg("max").to_dict()
     sojourn_time_cases = {x: complete_timestamps[x].timestamp() - start_timestamps[x].timestamp() for x in start_timestamps}
 
     log[sojourn_time_column] = log[case_id_column].map(sojourn_time_cases)
@@ -256,13 +283,67 @@ def check_is_pandas_dataframe(log):
     boolean
         Is dataframe?
     """
-    if pkgutil.find_loader("pandas"):
-        import pandas as pd
-        return type(log) is pd.DataFrame
-    return False
+    log_type = str(type(log)).lower()
+    return "dataframe" in log_type
 
 
-def check_pandas_dataframe_columns(df, activity_key=None, case_id_key=None, timestamp_key=None):
+def instantiate_dataframe(*args, **kwargs):
+    return DATAFRAME.DataFrame(*args, **kwargs)
+
+
+def instantiate_dataframe_from_dict(*args, **kwargs):
+    return DATAFRAME.DataFrame.from_dict(*args, **kwargs)
+
+
+def instantiate_dataframe_from_records(*args, **kwargs):
+    return DATAFRAME.DataFrame.from_records(*args, **kwargs)
+
+
+def get_grouper(*args, **kwargs):
+    return DATAFRAME.Grouper(*args, **kwargs)
+
+
+def get_total_seconds(difference):
+    return 86400 * difference.dt.days + difference.dt.seconds + 10**-6 * difference.dt.microseconds + 10**-9 * difference.dt.nanoseconds
+
+
+def convert_to_seconds(dt_column):
+    try:
+        # Pandas
+        return dt_column.values.astype(np.int64) / 10**9
+    except:
+        # CUDF
+        return [x/10**9 for x in dt_column.to_numpy().tolist()]
+
+
+def dataframe_column_string_to_datetime(*args, **kwargs):
+    if importlib.util.find_spec("cudf") or constants.TEST_CUDF_DATAFRAMES_ENVIRONMENT:
+        pass
+        """if DATAFRAME == pd:
+            format = kwargs["format"] if "format" in kwargs else None
+            if format not in [None, 'mixed', 'ISO8601']:
+                kwargs["exact"] = False"""
+
+    return DATAFRAME.to_datetime(*args, **kwargs)
+
+
+def read_csv(*args, **kwargs):
+    if importlib.util.find_spec("cudf") or constants.TEST_CUDF_DATAFRAMES_ENVIRONMENT:
+        if kwargs and "encoding" in kwargs:
+            del kwargs["encoding"]
+
+    return DATAFRAME.read_csv(*args, **kwargs)
+
+
+def concat(*args, **kwargs):
+    return DATAFRAME.concat(*args, **kwargs)
+
+
+def merge(*args, **kwargs):
+    return DATAFRAME.merge(*args, **kwargs)
+
+
+def check_pandas_dataframe_columns(df, activity_key=None, case_id_key=None, timestamp_key=None, start_timestamp_key=None):
     """
     Checks if the dataframe contains all the required columns.
     If not, raise an exception
@@ -314,6 +395,16 @@ def check_pandas_dataframe_columns(df, activity_key=None, case_id_key=None, time
         if df[timestamp_key].isnull().values.any():
             raise Exception("the timestamp column should not contain any empty value.")
 
+    if start_timestamp_key is not None:
+        if start_timestamp_key not in df.columns:
+            raise Exception("the specified start timestamp column is not contained in the dataframe. Available columns: "+str(sorted(list(df.columns))))
+
+        if start_timestamp_key not in timest_columns:
+            raise Exception("the start timestamp column should be of time datetime. Use the function pandas.to_datetime")
+
+        if df[start_timestamp_key].isnull().values.any():
+            raise Exception("the start timestamp column should not contain any empty value.")
+
     """if len(set(df.columns).intersection(
             set([constants.CASE_CONCEPT_NAME, xes_constants.DEFAULT_NAME_KEY,
                  xes_constants.DEFAULT_TIMESTAMP_KEY]))) < 3:
