@@ -14,20 +14,18 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.visualization.bpmn.variants import classic
+from pm4py.visualization.bpmn.variants import classic, dagrejs
 from pm4py.util import exec_utils
 from enum import Enum
-from pm4py.visualization.common import gview
-from pm4py.visualization.common import save as gsave
 from pm4py.visualization.common.gview import serialize, serialize_dot
-from typing import Optional, Dict, Any, Union, Tuple
+from typing import Optional, Dict, Any
 from pm4py.objects.bpmn.obj import BPMN
-from pm4py.util import typing
 import graphviz
 
 
 class Variants(Enum):
     CLASSIC = classic
+    DAGREJS = dagrejs
 
 
 DEFAULT_VARIANT = Variants.CLASSIC
@@ -55,7 +53,7 @@ def apply(bpmn_graph: BPMN, variant=DEFAULT_VARIANT, parameters: Optional[Dict[A
     return exec_utils.get_variant(variant).apply(bpmn_graph, parameters=parameters)
 
 
-def save(gviz: graphviz.Digraph, output_file_path: str):
+def save(gviz: graphviz.Digraph, output_file_path: str, variant=DEFAULT_VARIANT, parameters=None):
     """
     Save the diagram
 
@@ -66,10 +64,10 @@ def save(gviz: graphviz.Digraph, output_file_path: str):
     output_file_path
         Path where the GraphViz output should be saved
     """
-    gsave.save(gviz, output_file_path)
+    return exec_utils.get_variant(variant).save(gviz, output_file_path, parameters=parameters)
 
 
-def view(gviz: graphviz.Digraph):
+def view(gviz: graphviz.Digraph, variant=DEFAULT_VARIANT, parameters=None):
     """
     View the diagram
 
@@ -78,10 +76,10 @@ def view(gviz: graphviz.Digraph):
     gviz
         GraphViz diagram
     """
-    return gview.view(gviz)
+    return exec_utils.get_variant(variant).view(gviz, parameters=parameters)
 
 
-def matplotlib_view(gviz: graphviz.Digraph):
+def matplotlib_view(gviz: graphviz.Digraph, variant=DEFAULT_VARIANT, parameters=None):
     """
     Views the diagram using Matplotlib
 
@@ -90,5 +88,4 @@ def matplotlib_view(gviz: graphviz.Digraph):
     gviz
         Graphviz
     """
-
-    return gview.matplotlib_view(gviz)
+    return exec_utils.get_variant(variant).matplotlib_view(gviz, parameters=parameters)
