@@ -16,6 +16,8 @@
 '''
 from pm4py.visualization.decisiontree import variants, visualizer
 
+from pm4py.util import constants
 import warnings
 
-warnings.warn("The decisiontree visualizer will be removed in a future release (use Scikit Learn instead).")
+if constants.SHOW_INTERNAL_WARNINGS:
+    warnings.warn("The decisiontree visualizer will be removed in a future release (use Scikit Learn instead).")
