@@ -14,17 +14,20 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-import graphviz
 import tempfile
 from pm4py.util import exec_utils
 from enum import Enum
+from sklearn.tree import DecisionTreeClassifier
+from sklearn.tree import export_graphviz
+from typing import Optional, Dict, Any, Union, List
+import graphviz
 
 
 class Parameters(Enum):
     FORMAT = "format"
 
 
-def apply(clf, feature_names, classes, parameters=None):
+def apply(clf: DecisionTreeClassifier, feature_names: List[str], classes: List[str], parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> graphviz.Source:
     """
     Apply the visualization of the decision tree
 
@@ -45,15 +48,14 @@ def apply(clf, feature_names, classes, parameters=None):
     gviz
         GraphViz object
     """
-    from sklearn import tree
-
     if parameters is None:
         parameters = {}
 
     format = exec_utils.get_param_value(Parameters.FORMAT, parameters, "png")
     filename = tempfile.NamedTemporaryFile(suffix='.gv')
+    filename.close()
 
-    dot_data = tree.export_graphviz(clf, out_file=None,
+    dot_data = export_graphviz(clf, out_file=None,
                                     feature_names=feature_names,
                                     class_names=classes,
                                     filled=True, rounded=True,
