@@ -18,7 +18,7 @@ from graphviz import Source
 import tempfile
 from pm4py.util import exec_utils
 from enum import Enum
-from typing import Optional, Dict, Any, Union, Tuple
+from typing import Optional, Dict, Any, Union
 
 
 class Parameters(Enum):
@@ -74,6 +74,7 @@ def apply(fp: Dict[str, Any], parameters: Optional[Dict[Union[str, Parameters],
     image_format = exec_utils.get_param_value(Parameters.FORMAT, parameters, "png")
 
     filename = tempfile.NamedTemporaryFile(suffix='.gv')
+    filename.close()
 
     footprints_table = ["digraph {\n", "tbl [\n", "shape=plaintext\n", "label=<\n"]
     footprints_table.append("<table border='0' cellborder='1' color='blue' cellspacing='0'>\n")
