@@ -21,7 +21,7 @@ from pm4py.visualization.common import gview
 from pm4py.visualization.common import save as gsave
 from pm4py.visualization.common.gview import serialize, serialize_dot
 import graphviz
-from typing import Optional, Dict, Any, Union, Tuple
+from typing import Optional, Dict, Any
 
 
 class Variants(Enum):
@@ -78,6 +78,7 @@ def save(gviz, output_file_path, parameters=None):
         Path where the GraphViz output should be saved
     """
     gsave.save(gviz, output_file_path, parameters=parameters)
+    return ""
 
 
 def view(gviz, parameters=None):
