@@ -20,7 +20,7 @@ from copy import copy
 from pm4py.visualization.graphs.util import common
 from pm4py.util import exec_utils, constants
 from enum import Enum
-from typing import Optional, Dict, Any, Union, Tuple, List
+from typing import Optional, Dict, Any, Union, List
 
 
 class Parameters(Enum):
