@@ -22,7 +22,8 @@ from pm4py.util import exec_utils, vis_utils
 from pm4py.visualization.heuristics_net.variants import pydotplus_vis
 import tempfile
 from pm4py.objects.heuristics_net.obj import HeuristicsNet
-from typing import Optional, Dict, Any, Union, Tuple
+from typing import Optional, Dict, Any
+from pm4py.util import constants
 
 
 class Variants(Enum):
@@ -94,6 +95,16 @@ def view(figure):
         # continue without problems, a proper path has been provided
         pass
 
+    if constants.DEFAULT_GVIZ_VIEW == "matplotlib_view":
+        import matplotlib.pyplot as plt
+        import matplotlib.image as mpimg
+        img = mpimg.imread(figure)
+        plt.axis('off')
+        plt.tight_layout(pad=0, w_pad=0, h_pad=0)
+        plt.imshow(img)
+        plt.show()
+        return
+
     if vis_utils.check_visualization_inside_jupyter():
         vis_utils.view_image_in_jupyter(figure)
     else:
@@ -119,6 +130,7 @@ def save(figure, output_file_path):
         pass
 
     shutil.copyfile(figure, output_file_path)
+    return ""
 
 
 def serialize(figure: tempfile._TemporaryFileWrapper) -> bytes:
