@@ -60,6 +60,8 @@ def apply(network_analysis_edges: Dict[Tuple[str, str], Dict[str, int]], paramet
     edge_threshold = exec_utils.get_param_value(Parameters.EDGE_THRESHOLD, parameters, 1)
 
     filename = tempfile.NamedTemporaryFile(suffix='.gv')
+    filename.close()
+
     viz = Digraph("pt", filename=filename.name, engine='dot', graph_attr={'bgcolor': bgcolor})
     viz.attr('node', shape='ellipse', fixedsize='false')
 
@@ -105,6 +107,6 @@ def apply(network_analysis_edges: Dict[Tuple[str, str], Dict[str, int]], paramet
                 if network_analysis_edges[edge][edge_value] >= edge_threshold:
                     viz.edge(nodes_dict[edge[0]], nodes_dict[edge[1]], label=edge_value+"\n"+str(network_analysis_edges[edge][edge_value])+"", penwidth=str(vis_utils.get_arc_penwidth(network_analysis_edges[edge][edge_value], min_edge_value, max_edge_value)))
 
-    viz.format = image_format
+    viz.format = image_format.replace("html", "plain-ext")
 
     return viz
