@@ -20,9 +20,12 @@ from copy import copy
 from enum import Enum
 
 import matplotlib
-import numpy as np
 
 from pm4py.util import exec_utils, vis_utils
+from pm4py.objects.org.sna.obj import SNA
+from pm4py.util import constants
+from pm4py.util import nx_utils
+import networkx as nx
 
 
 class Parameters(Enum):
@@ -40,18 +43,19 @@ def get_temp_file_name(format):
         Format of the target image
     """
     filename = tempfile.NamedTemporaryFile(suffix='.' + format)
+    filename.close()
 
     return filename.name
 
 
-def apply(metric_values, parameters=None):
+def apply(sna: SNA, parameters=None):
     """
     Perform SNA visualization starting from the Matrix Container object
     and the Resource-Resource matrix
 
     Parameters
     -------------
-    metric_values
+    sna
         Value of the metrics
     parameters
         Possible parameters of the algorithm, including:
@@ -63,41 +67,31 @@ def apply(metric_values, parameters=None):
     temp_file_name
         Name of a temporary file where the visualization is placed
     """
-    import networkx as nx
-
     if parameters is None:
         parameters = {}
 
     weight_threshold = exec_utils.get_param_value(Parameters.WEIGHT_THRESHOLD, parameters, 0)
     format = exec_utils.get_param_value(Parameters.FORMAT, parameters, "png")
 
-    directed = metric_values[2]
+    directed = sna.is_directed
 
     temp_file_name = get_temp_file_name(format)
 
-    rows, cols = np.where(metric_values[0] > weight_threshold)
-    edges = zip(rows.tolist(), cols.tolist())
-
     if directed:
-        graph = nx.DiGraph()
+        graph = nx_utils.DiGraph()
     else:
-        graph = nx.Graph()
+        graph = nx_utils.Graph()
 
-    labels = {}
-    nodes = []
-    for index, item in enumerate(metric_values[1]):
-        labels[index] = item
-        nodes.append(index)
+    connections = {x for x, y in sna.connections.items() if y >= weight_threshold}
 
-    graph.add_nodes_from(nodes)
-    graph.add_edges_from(edges)
+    graph.add_edges_from(connections)
 
     current_backend = copy(matplotlib.get_backend())
     matplotlib.use('Agg')
     from matplotlib import pyplot
 
     pyplot.clf()
-    nx.draw(graph, with_labels=True, labels=labels, node_size=500, pos=nx.circular_layout(graph))
+    nx.draw(graph, node_size=500, with_labels=True, pos=nx.circular_layout(graph))
     pyplot.savefig(temp_file_name, bbox_inches="tight")
     pyplot.clf()
 
@@ -120,6 +114,16 @@ def view(temp_file_name, parameters=None):
     if parameters is None:
         parameters = {}
 
+    if constants.DEFAULT_GVIZ_VIEW == "matplotlib_view":
+        import matplotlib.pyplot as plt
+        import matplotlib.image as mpimg
+        img = mpimg.imread(temp_file_name)
+        plt.axis('off')
+        plt.tight_layout(pad=0, w_pad=0, h_pad=0)
+        plt.imshow(img)
+        plt.show()
+        return
+
     if vis_utils.check_visualization_inside_jupyter():
         vis_utils.view_image_in_jupyter(temp_file_name)
     else:
