@@ -20,7 +20,7 @@ from pm4py.visualization.transition_system.variants import view_based, trans_fre
 from enum import Enum
 from pm4py.util import exec_utils
 from pm4py.visualization.common.gview import serialize, serialize_dot
-from typing import Optional, Dict, Any, Union, Tuple
+from typing import Optional, Dict, Any
 from pm4py.objects.transition_system.obj import TransitionSystem
 import graphviz
 
@@ -67,6 +67,7 @@ def save(gviz: graphviz.Digraph, output_file_path: str, parameters=None):
         Path where the GraphViz output should be saved
     """
     gsave.save(gviz, output_file_path, parameters=parameters)
+    return ""
 
 
 def view(gviz: graphviz.Digraph, parameters=None):
