@@ -75,6 +75,8 @@ def apply(trie: Trie, parameters: Optional[Dict[Union[str, Parameters], Any]] =
     bgcolor = exec_utils.get_param_value(Parameters.BGCOLOR, parameters, constants.DEFAULT_BGCOLOR)
 
     filename = tempfile.NamedTemporaryFile(suffix='.gv')
+    filename.close()
+    
     viz = Graph("pt", filename=filename.name, engine='dot', graph_attr={'bgcolor': bgcolor})
     viz.attr('node', shape='ellipse', fixedsize='false')
 
@@ -83,6 +85,6 @@ def apply(trie: Trie, parameters: Optional[Dict[Union[str, Parameters], Any]] =
     viz.attr(overlap='false')
     viz.attr(splines='false')
     viz.attr(rankdir='LR')
-    viz.format = image_format
+    viz.format = image_format.replace("html", "plain-ext")
 
     return viz
